@@ -17,3 +17,17 @@
 #undef WITH_TARTY_WARP
 
 #undef WITH_ZOOM
+
+#undef ENABLE_NLS
+
+#undef HAVE_CATGETS
+
+#undef HAVE_GETTEXT
+
+#undef HAVE_LC_MESSAGES
+
+#undef HAVE_STPCPY
+
+#undef PACKAGE
+
+#undef HAS_XINERAMA
