@@ -2,20 +2,20 @@
 /* Enlightenment - The Window Manager that dares to do what others don't     */
 /*****************************************************************************/
 /*
-  Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
-  *
+  Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+  
   Permission is hereby granted, free of charge, to any person obtaining a copy
   of this software and associated documentation files (the "Software"), to
   deal in the Software without restriction, including without limitation the
   rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
   sell copies of the Software, and to permit persons to whom the Software is
- furnished to do so, subject to the following conditions:
-  *
+  furnished to do so, subject to the following conditions:
+ 
   The above copyright notice and this permission notice shall be included in
   all copies of the Software, its documentation and marketing & publicity
   materials, and acknowledgment shall be given in the documentation, materials
   and software packages that this Software was used.
-  *
+
   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -53,7 +53,12 @@
 #include <sys/resource.h>
 #include <sys/ipc.h>
 #include <sys/shm.h>
+#ifdef HAVE_FREETYPE_FREETYPE_H
+#include <freetype/freetype.h>
+#else
 #include <freetype.h>
+#endif
+
 
 #define FILEPATH_LEN_MAX 4096
 
@@ -212,6 +217,7 @@ char               *atword(char *s, int num);
 char               *atchar(char *s, char c);
 char               *getword(char *s, int num);
 void                word(char *s, int num, char *wd);
+void                word_mb(char *s, int num, char *wd, int *spaceflag);
 int                 canread(char *s);
 int                 canwrite(char *s);
 int                 canexec(char *s);
@@ -219,6 +225,7 @@ char               *fileof(char *s);
 char               *fullfileof(char *s);
 char               *pathtoexec(char *file);
 char               *pathtofile(char *file);
+int                 findLocalizedFile(char *fname);
 
 void                AddPage(Object * obj);
 void                AddObject(Object * obj);
