@@ -1,18 +1,18 @@
 /*
- Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
- *
+ Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to
  deal in the Software without restriction, including without limitation the
  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  sell copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:
- *
+
  The above copyright notice and this permission notice shall be included in
  all copies of the Software, its documentation and marketing & publicity
  materials, and acknowledgment shall be given in the documentation, materials
  and software packages that this Software was used.
- *
+
  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -20,6 +20,7 @@
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
+
 #include "E.h"
 
 void
@@ -229,8 +230,7 @@ cp(char *s, char *ss)
    EDBUG_RETURN_;
 }
 
-time_t
-moddate(char *s)
+time_t moddate(char *s)
 {
    struct stat         st;
 
@@ -326,7 +326,8 @@ char               *
 username(int uid)
 {
    char               *s;
-#ifndef __EMX__   
+
+#ifndef __EMX__
    struct passwd      *pwd;
 
    EDBUG(9, "username");
@@ -338,8 +339,8 @@ username(int uid)
 	EDBUG_RETURN(s);
      }
 #else
-  if ((s = getenv("USER")) != NULL)
-    EDBUG_RETURN(duplicate(s));
+   if ((s = getenv("USER")) != NULL)
+      EDBUG_RETURN(duplicate(s));
 #endif
    EDBUG_RETURN(duplicate("unknown"));
 }
@@ -348,7 +349,8 @@ char               *
 homedir(int uid)
 {
    char               *s;
-#ifndef __EMX__   
+
+#ifndef __EMX__
    struct passwd      *pwd;
 
    EDBUG(9, "homedir");
@@ -360,10 +362,10 @@ homedir(int uid)
 	EDBUG_RETURN(s);
      }
 #else
-  if ((s = getenv("HOME")) != NULL)
-    EDBUG_RETURN(duplicate(s));
-  if ((s = getenv("TMP")) != NULL)
-    EDBUG_RETURN(duplicate(s));
+   if ((s = getenv("HOME")) != NULL)
+      EDBUG_RETURN(duplicate(s));
+   if ((s = getenv("TMP")) != NULL)
+      EDBUG_RETURN(duplicate(s));
 #endif
    EDBUG_RETURN(duplicate("/tmp"));
 }
@@ -371,7 +373,7 @@ homedir(int uid)
 char               *
 usershell(int uid)
 {
-#ifndef __EMX__   
+#ifndef __EMX__
    char               *s;
    struct passwd      *pwd;
 
@@ -385,7 +387,7 @@ usershell(int uid)
      }
    EDBUG_RETURN(duplicate("/bin/sh"));
 #else
-  EDBUG_RETURN(duplicate("sh.exe"));
+   EDBUG_RETURN(duplicate("sh.exe"));
 #endif
 }
 
@@ -611,9 +613,9 @@ pathtoexec(char *file)
 	     s[len] = 0;
 	     s = Erealloc(s, len + 2 + exelen);
 #ifdef __EMX__
-	  if (s[len-1] != '/')
+	     if (s[len - 1] != '/')
 #endif
-	     strcat(s, "/");
+		strcat(s, "/");
 	     strcat(s, file);
 	     if (canexec(s))
 		EDBUG_RETURN(s);
@@ -629,9 +631,9 @@ pathtoexec(char *file)
 	s[len] = 0;
 	s = Erealloc(s, len + 2 + exelen);
 #ifdef __EMX__
-      if (s[len-1] != '/')
+	if (s[len - 1] != '/')
 #endif
-	strcat(s, "/");
+	   strcat(s, "/");
 	strcat(s, file);
 	if (canexec(s))
 	   EDBUG_RETURN(s);
@@ -651,7 +653,7 @@ pathtofile(char *file)
 #ifndef __EMX__
    if (file[0] == '/')
 #else
-  if (_fnisabs(file))
+   if (_fnisabs(file))
 #endif
      {
 	if (exists(file))
@@ -678,9 +680,9 @@ pathtofile(char *file)
 	     s[len] = 0;
 	     s = Erealloc(s, len + 2 + exelen);
 #ifdef __EMX__
-	  if (s[len-1] != '/')
+	     if (s[len - 1] != '/')
 #endif
-	     strcat(s, "/");
+		strcat(s, "/");
 	     strcat(s, file);
 	     if (exists(s))
 		EDBUG_RETURN(s);
@@ -696,9 +698,9 @@ pathtofile(char *file)
 	s[len] = 0;
 	s = Erealloc(s, len + 2 + exelen);
 #ifdef __EMX__
-      if (s[len-1] != '/')
+	if (s[len - 1] != '/')
 #endif
-	strcat(s, "/");
+	   strcat(s, "/");
 	strcat(s, file);
 	if (exists(s))
 	   EDBUG_RETURN(s);
