@@ -71,8 +71,9 @@ GrabButtonGrabs(EWin * ewin)
    int                 j;
    Action             *a;
 
-   ac = (ActionClass *) FindItem("BUTTONBINDINGS", 0,
-				 LIST_FINDBY_NAME, LIST_TYPE_ACLASS);
+   ac =
+      (ActionClass *) FindItem("BUTTONBINDINGS", 0, LIST_FINDBY_NAME,
+			       LIST_TYPE_ACLASS);
 
    if (ac)
      {
@@ -80,9 +81,9 @@ GrabButtonGrabs(EWin * ewin)
 	for (j = 0; j < ac->num; j++)
 	  {
 	     a = ac->list[j];
-	     if ((a) &&
-		 ((a->event == EVENT_MOUSE_DOWN) ||
-		  (a->event == EVENT_MOUSE_UP)))
+	     if ((a)
+		 && ((a->event == EVENT_MOUSE_DOWN)
+		     || (a->event == EVENT_MOUSE_UP)))
 	       {
 		  unsigned int        mod, button, mask;
 		  int                 i;
@@ -134,8 +135,9 @@ UnGrabButtonGrabs(EWin * ewin)
    int                 j;
    Action             *a;
 
-   ac = (ActionClass *) FindItem("BUTTONBINDINGS", 0,
-				 LIST_FINDBY_NAME, LIST_TYPE_ACLASS);
+   ac =
+      (ActionClass *) FindItem("BUTTONBINDINGS", 0, LIST_FINDBY_NAME,
+			       LIST_TYPE_ACLASS);
 
    if (ac)
      {
@@ -143,9 +145,9 @@ UnGrabButtonGrabs(EWin * ewin)
 	for (j = 0; j < ac->num; j++)
 	  {
 	     a = ac->list[j];
-	     if ((a) &&
-		 ((a->event == EVENT_MOUSE_DOWN) ||
-		  (a->event == EVENT_MOUSE_UP)))
+	     if ((a)
+		 && ((a->event == EVENT_MOUSE_DOWN)
+		     || (a->event == EVENT_MOUSE_UP)))
 	       {
 		  unsigned int        mod, button;
 
@@ -241,8 +243,8 @@ RemoveAction(Action * ActionToRemove)
    if (!ActionToRemove)
       EDBUG_RETURN_;
 
-   if ((ActionToRemove->event == EVENT_KEY_DOWN) ||
-       (ActionToRemove->event == EVENT_KEY_UP))
+   if ((ActionToRemove->event == EVENT_KEY_DOWN)
+       || (ActionToRemove->event == EVENT_KEY_UP))
       UnGrabActionKey(ActionToRemove);
    if (ActionToRemove->action)
       RemoveActionType(ActionToRemove->action);
@@ -357,9 +359,9 @@ EventAclass(XEvent * ev, ActionClass * a)
 	 DetermineEwinFloat(ewin, 0, 0);
    }
 
-   mask = (ShiftMask | ControlMask | Mod1Mask | Mod2Mask
-	   | Mod3Mask | Mod4Mask |
-	   Mod5Mask) & (~(numlock_mask | scrollock_mask | LockMask));
+   mask =
+      (ShiftMask | ControlMask | Mod1Mask | Mod2Mask | Mod3Mask | Mod4Mask |
+       Mod5Mask) & (~(numlock_mask | scrollock_mask | LockMask));
 
    switch (ev->type)
      {
@@ -589,8 +591,8 @@ spawnMenu(void *params)
 	     HideMenuMasker();
 	  }
      }
-   if (((ewin) && (ewin->win == mode.context_win)) ||
-       (ewin = FindEwinByChildren(mode.context_win)))
+   if (((ewin) && (ewin->win == mode.context_win))
+       || (ewin = FindEwinByChildren(mode.context_win)))
      {
 	if ((ewin) && (mode.cur_menu_depth > 0) && (mode.cur_menu[0]))
 	   ewin->shownmenu = mode.cur_menu[0]->win;
@@ -660,23 +662,25 @@ runApp(char *exe, char *params)
 #else
 		  if (_fnisabs((char *)exe))
 #endif
-		     DialogAlertOK(_("There was an error running the program:\n"
-				     "%s\n"
-				     "This program could not be executed.\n"
-				     "This is because the file does not exist.\n"),
-				   (char *)exe);
+		     DialogAlertOK(_
+				   ("There was an error running the program:\n"
+				    "%s\n"
+				    "This program could not be executed.\n"
+				    "This is because the file does not exist.\n"),
+(char *)exe);
 		  /* relative path */
 		  else
-		     DialogAlertOK(_("There was an error running the program:\n"
-				     "%s\n"
-				     "This program could not be executed.\n"
-				     "This is most probably because this "
-				     "program is not in the\n"
-				     "path for your shell which is %s. "
-				     "I suggest you read the manual\n"
-				     "page for that shell and read up how to "
-				     "change or add to your\n"
-				     "execution path.\n"), (char *)exe, sh);
+		     DialogAlertOK(_
+				   ("There was an error running the program:\n"
+				    "%s\n"
+				    "This program could not be executed.\n"
+				    "This is most probably because this "
+				    "program is not in the\n"
+				    "path for your shell which is %s. "
+				    "I suggest you read the manual\n"
+				    "page for that shell and read up how to "
+				    "change or add to your\n"
+				    "execution path.\n"), (char *)exe, sh);
 	       }
 	     else
 		/* it is a node on the filing sys */
@@ -807,8 +811,8 @@ alert(void *params)
    EDBUG(6, "alert");
    if (InZoom())
       Zoom(NULL);
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
    pp = duplicate((char *)params);
    i = 1;
@@ -834,8 +838,8 @@ int
 doExit(void *params)
 {
    EDBUG(6, "doExit");
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
    /* This function is now handled in session.c */
    if (InZoom())
@@ -853,8 +857,8 @@ doResize(void *params)
    EDBUG(6, "doResize");
    if (InZoom())
       EDBUG_RETURN(0);
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
    if (mode.slideout)
       HideSlideout(mode.slideout, mode.context_win);
@@ -908,8 +912,8 @@ doResizeH(void *params)
    EDBUG(6, "doResizeH");
    if (InZoom())
       EDBUG_RETURN(0);
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
    if (mode.slideout)
       HideSlideout(mode.slideout, mode.context_win);
@@ -957,8 +961,8 @@ doResizeV(void *params)
    EDBUG(6, "doResizeV");
    if (InZoom())
       EDBUG_RETURN(0);
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
    if (mode.slideout)
       HideSlideout(mode.slideout, mode.context_win);
@@ -1054,8 +1058,8 @@ doMoveImpl(void *params, char constrained)
    EDBUG(6, "doMove");
    if (InZoom())
       EDBUG_RETURN(0);
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
    if (mode.slideout)
       HideSlideout(mode.slideout, mode.context_win);
@@ -1089,7 +1093,8 @@ doMoveImpl(void *params, char constrained)
    xo = desks.desk[ewin->desktop].x;
    yo = desks.desk[ewin->desktop].y;
 
-   gwins = ListWinGroupMembersForEwin(ewin, ACTION_MOVE, mode.nogroup, &num);
+   gwins = ListWinGroupMembersForEwin(ewin, ACTION_MOVE, mode.nogroup
+				      || mode.swapmovemode, &num);
    for (i = 0; i < num; i++)
      {
 	FloatEwinAt(gwins[i], gwins[i]->x, gwins[i]->y);
@@ -1101,8 +1106,8 @@ doMoveImpl(void *params, char constrained)
    Efree(gwins);
    mode.firstlast = 1;
    params = NULL;
-   start_move_x = ewin->x;
-   start_move_y = ewin->y;
+   mode.swapcoord_x = start_move_x = ewin->x;
+   mode.swapcoord_y = start_move_y = ewin->y;
    EDBUG_RETURN(0);
 }
 
@@ -1125,6 +1130,13 @@ doMoveNoGroup(void *params)
    return doMoveImpl(params, 0);
 }
 
+int
+doSwapMove(void *params)
+{
+   mode.swapmovemode = 1;
+   return doMoveImpl(params, 0);
+}
+
 int
 doMoveConstrainedNoGroup(void *params)
 {
@@ -1159,7 +1171,8 @@ doMoveEnd(void *params)
    mode.firstlast = 2;
    d = DesktopAt(mode.x, mode.y);
 
-   gwins = ListWinGroupMembersForEwin(ewin, ACTION_MOVE, mode.nogroup, &num);
+   gwins = ListWinGroupMembersForEwin(ewin, ACTION_MOVE, mode.nogroup
+				      || mode.swapmovemode, &num);
 
    if (!mode.moveresize_pending_ewin)
      {
@@ -1179,11 +1192,11 @@ doMoveEnd(void *params)
 	     if (gwins[i]->floating)
 		MoveEwinToDesktopAt(gwins[i], d,
 				    gwins[i]->x - (desks.desk[d].x -
-						   desks.desk[gwins[i]->
-							      desktop].x),
+						   desks.
+						   desk[gwins[i]->desktop].x),
 				    gwins[i]->y - (desks.desk[d].y -
-						   desks.desk[gwins[i]->
-							      desktop].y));
+						   desks.
+						   desk[gwins[i]->desktop].y));
 	     else
 		MoveEwinToDesktopAt(gwins[i], d, gwins[i]->x, gwins[i]->y);
 	     gwins[i]->floating = 0;
@@ -1223,6 +1236,7 @@ doMoveEnd(void *params)
    mode.movemode = real_move_mode;
    params = NULL;
    mode.nogroup = 0;
+   mode.swapmovemode = 0;
    EDBUG_RETURN(0);
 }
 
@@ -1238,8 +1252,8 @@ doRaise(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
    if (!ewin)
@@ -1277,8 +1291,8 @@ doLower(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
 
@@ -1321,8 +1335,8 @@ doCleanup(void *params)
 
    if (InZoom())
       EDBUG_RETURN(0);
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
 
    type = (char *)params;
@@ -1351,8 +1365,9 @@ doCleanup(void *params)
 	k = 0;
 	for (i = 0; i < num; i++)
 	  {
-	     if ((((EWin *) lst[i])->desktop == desks.current) &&
-		 (!((EWin *) lst[i])->sticky) && (!((EWin *) lst[i])->floating)
+	     if ((((EWin *) lst[i])->desktop == desks.current)
+		 && (!((EWin *) lst[i])->sticky)
+		 && (!((EWin *) lst[i])->floating)
 		 && (!((EWin *) lst[i])->iconified)
 		 && (!((EWin *) lst[i])->ignorearrange)
 		 && (!((EWin *) lst[i])->menu)
@@ -1368,12 +1383,11 @@ doCleanup(void *params)
 		  floating[j].p = ((EWin *) lst[i])->layer;
 		  floating[j++].h = ((EWin *) lst[i])->h;
 	       }
-	     else if (
-		      (
-		       (((EWin *) lst[i])->desktop == desks.current) ||
-		       (((EWin *) lst[i])->sticky)) &&
-(((EWin *) lst[i])->layer != 4) &&
-(((EWin *) lst[i])->layer != 0) && (!((EWin *) lst[i])->menu))
+	     else if (((((EWin *) lst[i])->desktop == desks.current)
+		       || (((EWin *) lst[i])->sticky))
+		      && (((EWin *) lst[i])->layer != 4)
+		      && (((EWin *) lst[i])->layer != 0)
+		      && (!((EWin *) lst[i])->menu))
 	       {
 		  fixed = Erealloc(fixed, sizeof(RectBox) * (k + 1));
 		  fixed[k].data = lst[i];
@@ -1413,9 +1427,9 @@ doCleanup(void *params)
 	     ret = Erealloc(ret, sizeof(RectBox) * ((num + j) + 1 + k));
 	     for (i = 0; i < num; i++)
 	       {
-		  if (((blst[i]->desktop == desks.current) ||
-		       ((blst[i]->desktop == 0) && (blst[i]->sticky))) &&
-		      (blst[i]->visible))
+		  if (((blst[i]->desktop == desks.current)
+		       || ((blst[i]->desktop == 0) && (blst[i]->sticky)))
+		      && (blst[i]->visible))
 		    {
 		       fixed[k].data = NULL;
 		       fixed[k].x = blst[i]->x;
@@ -1508,8 +1522,8 @@ doCleanup(void *params)
 			 {
 			    if ((ewin->x != ret[i].x) || (ewin->y != ret[i].y))
 			      {
-				 SlideEwinTo(ewin, ewin->x, ewin->y,
-					     ret[i].x, ret[i].y, speed);
+				 SlideEwinTo(ewin, ewin->x, ewin->y, ret[i].x,
+					     ret[i].y, speed);
 				 ICCCM_Configure(ewin);
 			      }
 			 }
@@ -1547,8 +1561,8 @@ doKill(void *params)
    EDBUG(6, "doKill");
    if (params)
      {
-	ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-			LIST_TYPE_EWIN);
+	ewin =
+	   FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
      }
    else
      {
@@ -1579,8 +1593,8 @@ doKillNasty(void *params)
    EDBUG(6, "doKillNasty");
 
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
    if (!ewin)
@@ -1636,8 +1650,8 @@ doRaiseDesktop(void *params)
 
    if (InZoom())
       EDBUG_RETURN(0);
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
 
    if (!params)
@@ -1658,8 +1672,8 @@ doLowerDesktop(void *params)
 
    if (InZoom())
       EDBUG_RETURN(0);
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
 
    if (!params)
@@ -1680,8 +1694,8 @@ doDragDesktop(void *params)
 
    if (InZoom())
       EDBUG_RETURN(0);
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
 
    if (!params)
@@ -1711,8 +1725,8 @@ doStick(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
    if (!ewin)
@@ -1760,8 +1774,8 @@ doSkipLists(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
    if (!ewin)
@@ -1791,8 +1805,8 @@ doSkipTask(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
    if (!ewin)
@@ -1820,8 +1834,8 @@ doSkipFocus(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
    if (!ewin)
@@ -1848,8 +1862,8 @@ doSkipWinList(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
    if (!ewin)
@@ -1875,8 +1889,8 @@ doNeverFocus(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
    if (!ewin)
@@ -1924,8 +1938,8 @@ doDragButtonStart(void *params)
 
    if (InZoom())
       EDBUG_RETURN(0);
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
 
    button = mode.button;
@@ -2010,8 +2024,8 @@ int
 doMoveModeSet(void *params)
 {
    EDBUG(6, "doMoveModeSet");
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
    if (params)
      {
@@ -2033,8 +2047,8 @@ int
 doResizeModeSet(void *params)
 {
    EDBUG(6, "doResizeModeSet");
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
    if (params)
      {
@@ -2211,12 +2225,14 @@ doDragdirSet(void *params)
 	GotoDesktop(desks.current);
 	for (i = 0; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; i++)
 	   MoveDesktop(i, 0, 0);
-	while ((b = RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
-			       LIST_TYPE_BUTTON)))
-	   DestroyButton(b);
-	while ((b = RemoveItem("_DESKTOP_DESKRAY_DRAG_CONTROL",
-			       0, LIST_FINDBY_NAME, LIST_TYPE_BUTTON)))
-	   DestroyButton(b);
+	while (
+	       (b =
+		RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_BUTTON))) DestroyButton(b);
+	while (
+	       (b =
+		RemoveItem("_DESKTOP_DESKRAY_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_BUTTON))) DestroyButton(b);
 	InitDesktopControls();
 	ShowDesktopControls();
      }
@@ -2242,9 +2258,10 @@ doDragbarOrderSet(void *params)
      }
    if (pd != desks.dragbar_ordering)
      {
-	while ((b = RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
-			       LIST_TYPE_BUTTON)))
-	   DestroyButton(b);
+	while (
+	       (b =
+		RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_BUTTON))) DestroyButton(b);
 	InitDesktopControls();
 	ShowDesktopControls();
      }
@@ -2264,9 +2281,10 @@ doDragbarWidthSet(void *params)
       desks.dragbar_width = atoi((char *)params);
    if (pd != desks.dragbar_width)
      {
-	while ((b = RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
-			       LIST_TYPE_BUTTON)))
-	   DestroyButton(b);
+	while (
+	       (b =
+		RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_BUTTON))) DestroyButton(b);
 	InitDesktopControls();
 	ShowDesktopControls();
      }
@@ -2286,9 +2304,10 @@ doDragbarLengthSet(void *params)
       desks.dragbar_length = atoi((char *)params);
    if (pd != desks.dragbar_length)
      {
-	while ((b = RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
-			       LIST_TYPE_BUTTON)))
-	   DestroyButton(b);
+	while (
+	       (b =
+		RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_BUTTON))) DestroyButton(b);
 	InitDesktopControls();
 	ShowDesktopControls();
      }
@@ -2377,8 +2396,8 @@ doDeskray(void *params)
    EDBUG(6, "doDeskray");
    if (InZoom())
       EDBUG_RETURN(0);
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
    if (params)
      {
@@ -2438,8 +2457,8 @@ doHideShowButton(void *params)
    EDBUG(6, "doHideButtons");
    if (InZoom())
       EDBUG_RETURN(0);
-   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H) ||
-       (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
+   if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
 
    if (params)
@@ -2473,9 +2492,11 @@ doHideShowButton(void *params)
 			 {
 			    if (matchregexp(ss, lst[i]->name))
 			      {
-				 if ((strcmp(lst[i]->name,
-					     "_DESKTOP_DESKRAY_DRAG_CONTROL") &&
-				      (!lst[i]->used)))
+				 if (
+				     (strcmp
+				      (lst[i]->name,
+				       "_DESKTOP_DESKRAY_DRAG_CONTROL")
+				      && (!lst[i]->used)))
 				   {
 				      if (!(lst[i]->visible))
 					{
@@ -2503,9 +2524,11 @@ doHideShowButton(void *params)
 			 {
 			    if (!matchregexp(ss, lst[i]->name))
 			      {
-				 if ((strcmp(lst[i]->name,
-					     "_DESKTOP_DESKRAY_DRAG_CONTROL") &&
-				      (!lst[i]->used)))
+				 if (
+				     (strcmp
+				      (lst[i]->name,
+				       "_DESKTOP_DESKRAY_DRAG_CONTROL")
+				      && (!lst[i]->used)))
 				   {
 				      if (!(lst[i]->visible))
 					{
@@ -2528,9 +2551,10 @@ doHideShowButton(void *params)
 	       {
 		  for (i = 0; i < num; i++)
 		    {
-		       if ((strcmp(lst[i]->name,
-				   "_DESKTOP_DESKRAY_DRAG_CONTROL") &&
-			    (!lst[i]->used)))
+		       if (
+			   (strcmp
+			    (lst[i]->name, "_DESKTOP_DESKRAY_DRAG_CONTROL")
+			    && (!lst[i]->used)))
 			 {
 			    if (!(lst[i]->visible))
 			      {
@@ -2586,11 +2610,13 @@ doIconifyWindow(void *params)
    if (params)
      {
 	windowid = (char *)params;
-	ewin = FindItem("ICON", atoi(windowid), LIST_FINDBY_BOTH,
-			LIST_TYPE_ICONIFIEDS);
+	ewin =
+	   FindItem("ICON", atoi(windowid), LIST_FINDBY_BOTH,
+		    LIST_TYPE_ICONIFIEDS);
 	if (!ewin)
-	   ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-			   LIST_TYPE_EWIN);
+	   ewin =
+	      FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
+		       LIST_TYPE_EWIN);
      }
    else
       ewin = GetFocusEwin();
@@ -2677,9 +2703,8 @@ doScrollWindows(void *params)
      {
 	for (i = 0; i < num; i++)
 	  {
-	     if ((lst[i]->desktop == desks.current) &&
-		 (!lst[i]->sticky) && (!lst[i]->floating)
-		 && (!lst[i]->fixedpos))
+	     if ((lst[i]->desktop == desks.current) && (!lst[i]->sticky)
+		 && (!lst[i]->floating) && (!lst[i]->fixedpos))
 		MoveEwin(lst[i], lst[i]->x + x, lst[i]->y + y);
 	  }
 	Efree(lst);
@@ -2700,8 +2725,8 @@ doShade(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params),
-		      LIST_FINDBY_ID, LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
 
@@ -2953,8 +2978,8 @@ doFocusSet(void *params)
 	if (mode.raise_on_next_focus || mode.raise_after_next_focus)
 	   RaiseEwin(ewin);
 	if (mode.warp_on_next_focus)
-	   XWarpPointer(disp, None, ewin->win, 0, 0, 0, 0,
-			ewin->w / 2, ewin->h / 2);
+	   XWarpPointer(disp, None, ewin->win, 0, 0, 0, 0, ewin->w / 2,
+			ewin->h / 2);
 	FocusToEWin(ewin);
      }
    EDBUG_RETURN(0);
@@ -3185,9 +3210,8 @@ doSetWinBorder(void *params)
      }
    if (has_shaded)
      {
-	if ((b->border.left == 0) &&
-	    (b->border.right == 0) &&
-	    (b->border.top == 0) && (b->border.bottom == 0))
+	if ((b->border.left == 0) && (b->border.right == 0)
+	    && (b->border.top == 0) && (b->border.bottom == 0))
 	   EDBUG_RETURN(0);
      }
    for (i = 0; i < num; i++)
@@ -3267,8 +3291,9 @@ doAbout(void *params)
    EDBUG(6, "doAbout");
    if (InZoom())
       EDBUG_RETURN(0);
-   if ((d = FindItem("ABOUT_ENLIGHTENMENT", 0,
-		     LIST_FINDBY_NAME, LIST_TYPE_DIALOG)))
+   if (
+       (d =
+	FindItem("ABOUT_ENLIGHTENMENT", 0, LIST_FINDBY_NAME, LIST_TYPE_DIALOG)))
      {
 	ShowDialog(d);
 	EDBUG_RETURN(0);
@@ -3293,9 +3318,7 @@ doAbout(void *params)
    DialogItemSetPadding(di, 2, 2, 2, 2);
    DialogItemSetFill(di, 1, 0);
    DialogItemTextSetText(di,
-			 _("Welcome to the "
-			   ENLIGHTENMENT_VERSION
-			   " version\n"
+			 _("Welcome to the " ENLIGHTENMENT_VERSION " version\n"
 			   "of the Enlightenment "
 			   "window manager.\n Enlightenment is still under "
 			   "development, but\n"
@@ -3304,15 +3327,10 @@ doAbout(void *params)
 			   "you find a bug in the software,\n please do "
 			   "not hesitate to send "
 			   "in a bug report.\nSee \"Help\" for information "
-			   "on joining the\n"
-			   "mailing list.\n"
-			   "\n"
-			   "This code last updated on:\n"
-			   E_CHECKOUT_DATE "\n"
-			   "\n"
-			   "Good luck. We hope you enjoy the software.\n"
-			   "\n"
-			   "The Rasterman - raster@rasterman.com\n"
+			   "on joining the\n" "mailing list.\n" "\n"
+			   "This code last updated on:\n" E_CHECKOUT_DATE "\n"
+			   "\n" "Good luck. We hope you enjoy the software.\n"
+			   "\n" "The Rasterman - raster@rasterman.com\n"
 			   "Mandrake - mandrake@mandrake.net\n"));
 
    DialogAddButton(d, _("OK"), NULL, 1);
@@ -3621,7 +3639,6 @@ doInsertKeys(void *params)
 		  for (j = 0; j < (int)(sizeof(ks) / sizeof(struct _keyset));
 
 		       j++)
-
 		    {
 		       if (!strncmp(ks[j].ch, &(s[i]), strlen(ks[j].ch)))
 			 {
@@ -3703,8 +3720,8 @@ doRaiseLower(void *params)
       EDBUG_RETURN(0);
 
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
    if (!ewin)
@@ -3719,10 +3736,10 @@ doRaiseLower(void *params)
 	  {
 	     for (i = 0; i < desks.desk[ewin->desktop].num - 1; i++)
 	       {
-		  if (desks.desk[ewin->desktop].list[i]->layer == ewin->layer &&
-		      (desks.desk[ewin->desktop].list[i] == ewin ||
-		       !FindEwinInList(desks.desk[ewin->desktop].list[i], gwins,
-				       num)))
+		  if (desks.desk[ewin->desktop].list[i]->layer == ewin->layer
+		      && (desks.desk[ewin->desktop].list[i] == ewin
+			  || !FindEwinInList(desks.desk[ewin->desktop].list[i],
+					     gwins, num)))
 		    {
 		       if (desks.desk[ewin->desktop].list[i] != ewin)
 			  raise = 1;
@@ -3772,8 +3789,8 @@ doShowHideGroup(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
 
@@ -3793,8 +3810,8 @@ doStartGroup(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
 
@@ -3816,8 +3833,8 @@ doAddToGroup(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
 
@@ -3850,8 +3867,8 @@ doRemoveFromGroup(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
 
@@ -3875,16 +3892,15 @@ doBreakGroup(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      ewin = FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID,
-		      LIST_TYPE_EWIN);
+      ewin =
+	 FindItem(NULL, atoi((char *)params), LIST_FINDBY_ID, LIST_TYPE_EWIN);
    else
       ewin = GetFocusEwin();
 
    if (!ewin)
       EDBUG_RETURN(0);
 
-   ChooseGroupDialog(ewin,
-		     _("  Select the group to break  "),
+   ChooseGroupDialog(ewin, _("  Select the group to break  "),
 		     GROUP_SELECT_EWIN_ONLY, ACTION_BREAK_GROUP);
 
    SaveGroups();
@@ -4073,6 +4089,7 @@ initFunctionArray(void)
    ActionFunctions[ACTION_SKIPWINLIST] = (int (*)(void *))(doSkipWinList);
    ActionFunctions[ACTION_NEVERFOCUS] = (int (*)(void *))(doNeverFocus);
    ActionFunctions[ACTION_SKIPLISTS] = (int (*)(void *))(doSkipLists);
+   ActionFunctions[ACTION_SWAPMOVE] = (int (*)(void *))(doSwapMove);
 
    EDBUG_RETURN(0);
 }
