@@ -1,3 +1,4 @@
+
 /*
  * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
  *
@@ -102,8 +103,8 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	     int                 num;
 	     XineramaScreenInfo *screens;
 
-	     XQueryPointer(disp, root.win, &rt, &ch, &pointer_x, &pointer_y,
-			   &d, &d, &ud);
+	     XQueryPointer(disp, root.win, &rt, &ch, &pointer_x, &pointer_y, &d,
+			   &d, &ud);
 
 	     screens = XineramaQueryScreens(disp, &num);
 	     for (i = 0; i < num; i++)
@@ -114,8 +115,8 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 			 {
 			    if (pointer_y >= screens[i].y_org)
 			      {
-				 if (pointer_y <= (screens[i].height +
-						   screens[i].y_org))
+				 if (pointer_y <=
+				     (screens[i].height + screens[i].y_org))
 				   {
 				      if (screens[i].x_org > startx)
 					 startx = screens[i].x_org;
@@ -172,7 +173,8 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	     for (i = 0; i < floating_count - 1; i++)
 	       {
 		  a1 = floating[i].x + floating[i].y;
-		  a2 = (floating[i + 1].x + (floating[i + 1].w >> 1)) +
+		  a2 =
+		     (floating[i + 1].x + (floating[i + 1].w >> 1)) +
 		     (floating[i + 1].y + (floating[i + 1].h >> 1));
 		  if (a2 < a1)
 		    {
@@ -374,8 +376,8 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	sort = 0x7fffffff;
 	for (j = 0; j < num_spaces; j++)
 	  {
-	     if ((spaces[j].w >= floating[i].w) &&
-		 (spaces[j].h >= floating[i].h))
+	     if ((spaces[j].w >= floating[i].w)
+		 && (spaces[j].h >= floating[i].h))
 	       {
 		  if (spaces[j].x >= startx)
 		    {
@@ -422,10 +424,14 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	  {
 	     if (policy == ARRANGE_BY_POSITION)
 	       {
-		  a1 = (spaces[k].x + (spaces[k].w >> 1)) -
-		     (floating[i].x + (floating[i].w >> 1));
-		  a2 = (spaces[k].y + (spaces[k].h >> 1)) -
-		     (floating[i].y + (floating[i].h >> 1));
+		  a1 =
+		     (spaces[k].x + (spaces[k].w >> 1)) - (floating[i].x +
+							   (floating[i].w >>
+							    1));
+		  a2 =
+		     (spaces[k].y + (spaces[k].h >> 1)) - (floating[i].y +
+							   (floating[i].h >>
+							    1));
 		  if (a1 >= 0)
 		    {
 		       sorted[num_sorted].x = spaces[k].x;
@@ -691,8 +697,8 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
    top_bound = 0;
    bottom_bound = root.h;
 
-   screen_snap_dist = mode.constrained ? (root.w + root.h)
-      : mode.screen_snap_dist;
+   screen_snap_dist =
+      mode.constrained ? (root.w + root.h) : mode.screen_snap_dist;
 
 #ifdef HAS_XINERAMA
 
@@ -731,7 +737,8 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 #endif
 
    lst = (EWin **) ListItemType(&num, LIST_TYPE_EWIN);
-   gwins = ListWinGroupMembersForEwin(ewin, ACTION_MOVE, mode.nogroup, &gnum);
+   gwins = ListWinGroupMembersForEwin(ewin, ACTION_MOVE, mode.nogroup
+				      || mode.swapmovemode, &gnum);
    if (gwins)
      {
 	for (i = 0; i < gnum; i++)
@@ -759,10 +766,10 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 	       {
 		  if (lst[i])
 		    {
-		       if (((ewin->desktop == lst[i]->desktop) ||
-			    (lst[i]->sticky)) &&
-			   (!(lst[i]->floating)) &&
-			   (!(lst[i]->iconified)) && (!(lst[i]->ignorearrange)))
+		       if (((ewin->desktop == lst[i]->desktop)
+			    || (lst[i]->sticky)) && (!(lst[i]->floating))
+			   && (!(lst[i]->iconified))
+			   && (!(lst[i]->ignorearrange)))
 			 {
 			    if (IN_BELOW
 				(ewin->x + dx, lst[i]->x + lst[i]->w - 1,
@@ -794,15 +801,16 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 	       {
 		  if (lst[i])
 		    {
-		       if (((ewin->desktop == lst[i]->desktop) ||
-			    (lst[i]->sticky)) &&
-			   (!(lst[i]->floating)) &&
-			   (!(lst[i]->iconified)) && (!(lst[i]->ignorearrange)))
+		       if (((ewin->desktop == lst[i]->desktop)
+			    || (lst[i]->sticky)) && (!(lst[i]->floating))
+			   && (!(lst[i]->iconified))
+			   && (!(lst[i]->ignorearrange)))
 			 {
-			    if (IN_ABOVE(ewin->x + ewin->w + dx - 1, lst[i]->x,
-					 mode.edge_snap_dist) &&
-				SPANS_COMMON(ewin->y, ewin->h, lst[i]->y,
-					     lst[i]->h)
+			    if (IN_ABOVE
+				(ewin->x + ewin->w + dx - 1, lst[i]->x,
+				 mode.edge_snap_dist)
+				&& SPANS_COMMON(ewin->y, ewin->h, lst[i]->y,
+						lst[i]->h)
 				&& ((ewin->x + ewin->w) <= lst[i]->x))
 			      {
 				 dx = lst[i]->x - (ewin->x + ewin->w);
@@ -828,10 +836,10 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 	       {
 		  if (lst[i])
 		    {
-		       if (((ewin->desktop == lst[i]->desktop) ||
-			    (lst[i]->sticky)) &&
-			   (!(lst[i]->floating)) &&
-			   (!(lst[i]->iconified)) && (!(lst[i]->ignorearrange)))
+		       if (((ewin->desktop == lst[i]->desktop)
+			    || (lst[i]->sticky)) && (!(lst[i]->floating))
+			   && (!(lst[i]->iconified))
+			   && (!(lst[i]->ignorearrange)))
 			 {
 			    if (IN_BELOW
 				(ewin->y + dy, lst[i]->y + lst[i]->h - 1,
@@ -863,15 +871,16 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 	       {
 		  if (lst[i])
 		    {
-		       if (((ewin->desktop == lst[i]->desktop) ||
-			    (lst[i]->sticky)) &&
-			   (!(lst[i]->floating)) &&
-			   (!(lst[i]->iconified)) && (!(lst[i]->ignorearrange)))
+		       if (((ewin->desktop == lst[i]->desktop)
+			    || (lst[i]->sticky)) && (!(lst[i]->floating))
+			   && (!(lst[i]->iconified))
+			   && (!(lst[i]->ignorearrange)))
 			 {
-			    if (IN_ABOVE(ewin->y + ewin->h + dy - 1, lst[i]->y,
-					 mode.edge_snap_dist) &&
-				SPANS_COMMON(ewin->x, ewin->w, lst[i]->x,
-					     lst[i]->w)
+			    if (IN_ABOVE
+				(ewin->y + ewin->h + dy - 1, lst[i]->y,
+				 mode.edge_snap_dist)
+				&& SPANS_COMMON(ewin->x, ewin->w, lst[i]->x,
+						lst[i]->w)
 				&& ((ewin->y + ewin->h) <= lst[i]->y))
 			      {
 				 dy = lst[i]->y - (ewin->y + ewin->h);
@@ -922,9 +931,11 @@ ArrangeEwin(EWin * ewin)
 	j = 0;
 	for (i = 0; i < num; i++)
 	  {
-	     if ((lst[i] != ewin) && (!lst[i]->iconified) &&
-		 (!lst[i]->ignorearrange) && (lst[i]->layer != 0) &&
-		 (((lst[i]->area_x == desks.desk[ewin->desktop].current_area_x)
+	     if ((lst[i] != ewin) && (!lst[i]->iconified)
+		 && (!lst[i]->ignorearrange) && (lst[i]->layer != 0)
+		 &&
+		 (((lst
+		    [i]->area_x == desks.desk[ewin->desktop].current_area_x)
 		   && (lst[i]->area_y ==
 		       desks.desk[ewin->desktop].current_area_y)
 		   && (lst[i]->desktop == ewin->desktop)) || (lst[i]->sticky)))
@@ -969,9 +980,9 @@ ArrangeEwin(EWin * ewin)
 	     ret = Erealloc(ret, sizeof(RectBox) * ((num + j) + 1));
 	     for (i = 0; i < num; i++)
 	       {
-		  if (((blst[i]->desktop == ewin->desktop) ||
-		       ((blst[i]->desktop == 0) && (blst[i]->sticky))) &&
-		      (blst[i]->visible))
+		  if (((blst[i]->desktop == ewin->desktop)
+		       || ((blst[i]->desktop == 0) && (blst[i]->sticky)))
+		      && (blst[i]->visible))
 		    {
 		       fixed[j].data = NULL;
 		       fixed[j].x = blst[i]->x;
@@ -1051,8 +1062,8 @@ ArrangeEwin(EWin * ewin)
 	     int                 d;
 	     unsigned int        ud;
 
-	     XQueryPointer(disp, root.win, &rt, &ch, &pointer_x, &pointer_y,
-			   &d, &d, &ud);
+	     XQueryPointer(disp, root.win, &rt, &ch, &pointer_x, &pointer_y, &d,
+			   &d, &ud);
 	     screens = XineramaQueryScreens(disp, &num);
 	     for (i = 0; i < num; i++)
 	       {
@@ -1062,15 +1073,15 @@ ArrangeEwin(EWin * ewin)
 			 {
 			    if (pointer_y >= screens[i].y_org)
 			      {
-				 if (pointer_y <= (screens[i].height +
-						   screens[i].y_org))
+				 if (pointer_y <=
+				     (screens[i].height + screens[i].y_org))
 				   {
 				      ewin->x =
-					 ((screens[i].width - ewin->w) /
-					  2) + screens[i].x_org;
+					 ((screens[i].width - ewin->w) / 2) +
+					 screens[i].x_org;
 				      ewin->y =
-					 ((screens[i].height - ewin->h) /
-					  2) + screens[i].y_org;
+					 ((screens[i].height - ewin->h) / 2) +
+					 screens[i].y_org;
 				   }
 			      }
 			 }
