@@ -36,10 +36,8 @@ AtomGet(Window win, Atom to_get, Atom type, int *size)
 
    retval = NULL;
    length = 0x7fffffff;
-   XGetWindowProperty(disp, win, to_get, 0,
-		      length,
-		      False, type,
-		      &type_ret, &format_ret, &num_ret, &bytes_after, &retval);
+   XGetWindowProperty(disp, win, to_get, 0, length, False, type, &type_ret,
+		      &format_ret, &num_ret, &bytes_after, &retval);
    if ((retval) && (num_ret > 0) && (format_ret > 0))
      {
 	if (format_ret == 32)
@@ -105,9 +103,9 @@ getSimpleHint(Window win, Atom atom)
    if (!atom)
       EDBUG_RETURN(NULL);
 
-   if (XGetWindowProperty(disp, win, atom, 0, 1, False, atom,
-			  &type_ret, &fmt_ret, &nitems_ret, &bytes_after_ret,
-			  (unsigned char **)&data) != Success || !data)
+   if (XGetWindowProperty
+       (disp, win, atom, 0, 1, False, atom, &type_ret, &fmt_ret, &nitems_ret,
+	&bytes_after_ret, (unsigned char **)&data) != Success || !data)
      {
 	EDBUG_RETURN(NULL);
      }
