@@ -40,8 +40,8 @@ CreateButton(char *name, ImageClass * iclass, ActionClass * aclass,
 
    b->iclass = iclass;
    if (!b->iclass)
-      b->iclass = FindItem("__FALLBACK_ICLASS", 0, LIST_FINDBY_NAME,
-			   LIST_TYPE_ICLASS);
+      b->iclass =
+	 FindItem("__FALLBACK_ICLASS", 0, LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
    if (b->iclass)
       b->iclass->ref_count++;
 
@@ -53,8 +53,8 @@ CreateButton(char *name, ImageClass * iclass, ActionClass * aclass,
 
    if ((!b->tclass) && (b->label))
      {
-	b->tclass = FindItem("__FALLBACK_TCLASS", 0, LIST_FINDBY_NAME,
-			     LIST_TYPE_TCLASS);
+	b->tclass =
+	   FindItem("__FALLBACK_TCLASS", 0, LIST_FINDBY_NAME, LIST_TYPE_TCLASS);
      }
    if (b->tclass)
       b->tclass->ref_count++;
@@ -186,8 +186,9 @@ CalcButton(Button * b)
 	else
 	  {
 	     if (!b->iclass)
-		b->iclass = FindItem("__FALLBACK_ICLASS", 0,
-				     LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+		b->iclass =
+		   FindItem("__FALLBACK_ICLASS", 0, LIST_FINDBY_NAME,
+			    LIST_TYPE_ICLASS);
 	     w = 32;
 	     h = 32;
 	  }
@@ -339,8 +340,8 @@ DrawButton(Button * b)
    IclassApply(b->iclass, b->win, b->w, b->h, 0, 0, b->state, 0);
 
    if (b->label)
-      TclassApply(b->iclass, b->win, b->w, b->h, 0, 0, b->state, 0,
-		  b->tclass, b->label);
+      TclassApply(b->iclass, b->win, b->w, b->h, 0, 0, b->state, 0, b->tclass,
+		  b->label);
    EDBUG_RETURN_;
 }
 
@@ -419,9 +420,9 @@ EmbedWindowIntoButton(Button * ButtonToUse, Window WindowToEmbed)
 	       (ButtonToUse->h - h) >> 1);
    ButtonToUse->event_win = ECreateEventWindow(ButtonToUse->win, 0, 0, w, h);
 
-   XSelectInput(disp, ButtonToUse->event_win, ButtonPressMask |
-		ButtonReleaseMask | EnterWindowMask | LeaveWindowMask |
-		ButtonMotionMask);
+   XSelectInput(disp, ButtonToUse->event_win,
+		ButtonPressMask | ButtonReleaseMask | EnterWindowMask |
+		LeaveWindowMask | ButtonMotionMask);
 
    EMoveWindow(disp, ButtonToUse->event_win, (ButtonToUse->w - w) >> 1,
 	       (ButtonToUse->h - h) >> 1);
