@@ -48,12 +48,12 @@ CloneEwin(EWin * ewin)
    attr.background_pixel = 0;
    attr.background_pixmap = None;
    attr.save_under = False;
-   c->win = XCreateWindow(disp, ewin->parent, ewin->x, ewin->y,
-			  ewin->w, ewin->h, 0, root.depth,
-			  InputOutput, root.vis,
-			  CWOverrideRedirect | CWSaveUnder |
-			  CWBackingStore | CWColormap |
-			  CWBackPixmap | CWBackPixel | CWBorderPixel, &attr);
+   c->win =
+      XCreateWindow(disp, ewin->parent, ewin->x, ewin->y, ewin->w, ewin->h, 0,
+		    root.depth, InputOutput, root.vis,
+		    CWOverrideRedirect | CWSaveUnder | CWBackingStore |
+		    CWColormap | CWBackPixmap | CWBackPixel | CWBorderPixel,
+		    &attr);
    pmap = XCreatePixmap(disp, c->win, ewin->w, ewin->h, root.depth);
    XSetWindowBackgroundPixmap(disp, c->win, pmap);
    XCopyArea(disp, ewin->win, pmap, gc, 0, 0, ewin->w, ewin->h, 0, 0);
@@ -101,8 +101,8 @@ CloneDesktop(int d)
 	ewin = desks.desk[d].list[i];
 	if ((ewin) && (ewin->sticky) && (!ewin->iconified))
 	  {
-	     if (!FindItem("CLONE", ewin->client.win, LIST_FINDBY_ID,
-			   LIST_TYPE_CLONE))
+	     if (!FindItem
+		 ("CLONE", ewin->client.win, LIST_FINDBY_ID, LIST_TYPE_CLONE))
 	       {
 		  c = CloneEwin(ewin);
 		  AddItem(c, "CLONE", ewin->client.win, LIST_TYPE_CLONE);
