@@ -72,9 +72,9 @@ CommsFindCommsWindow()
 	  }
 	if (comms_win)
 	  {
-	     if (!EGetGeometry(disp, comms_win, &rt, &dint, &dint,
-			       &duint, &duint, &duint, &duint))
-		comms_win = 0;
+	     if (!EGetGeometry
+		 (disp, comms_win, &rt, &dint, &dint, &duint, &duint, &duint,
+		  &duint)) comms_win = 0;
 	     s = NULL;
 	     if (comms_win)
 	       {
@@ -190,8 +190,8 @@ CommsBroadcastToSlaveWMs(char *s)
    Atom                a = 0;
 
    EDBUG(5, "CommsBroadcastToSlaveWMs");
-   if (root.scr != master_screen || master_pid != getpid() ||
-       display_screens < 2 || single_screen_mode != 0)
+   if (root.scr != master_screen || master_pid != getpid()
+       || display_screens < 2 || single_screen_mode != 0)
       EDBUG_RETURN_;
 
    if (!s)
@@ -531,8 +531,9 @@ HandleComms(XEvent * ev)
 	char                dodel = 1;
 
 	sscanf(s, "%*s %1000s", w);
-	bg = (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
-				     LIST_TYPE_BACKGROUND);
+	bg =
+	   (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
+				   LIST_TYPE_BACKGROUND);
 	if (bg)
 	  {
 	     /* check for desktops referencing this bg - if there are - don't */
@@ -544,8 +545,9 @@ HandleComms(XEvent * ev)
 	       }
 	     if (dodel)
 	       {
-		  bg = (Background *) RemoveItem(w, 0, LIST_FINDBY_NAME,
-						 LIST_TYPE_BACKGROUND);
+		  bg =
+		     (Background *) RemoveItem(w, 0, LIST_FINDBY_NAME,
+					       LIST_TYPE_BACKGROUND);
 		  if (bg->name)
 		     Efree(bg->name);
 		  if (bg->bg.file)
@@ -565,8 +567,9 @@ HandleComms(XEvent * ev)
 	char                view;
 
 	sscanf(s, "%*s %1000s", w);
-	bg = (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
-				     LIST_TYPE_BACKGROUND);
+	bg =
+	   (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
+				   LIST_TYPE_BACKGROUND);
 	if (bg)
 	  {
 	     wd = 3;
@@ -650,8 +653,9 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX], buf2[FILEPATH_LEN_MAX];
 
 	sscanf(s, "%*s %1000s", w);
-	bg = (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
-				     LIST_TYPE_BACKGROUND);
+	bg =
+	   (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
+				   LIST_TYPE_BACKGROUND);
 	buf[0] = 0;
 	if (bg)
 	  {
@@ -673,9 +677,9 @@ HandleComms(XEvent * ev)
 	int                 i, mod;
 	char               *buf = NULL, buf2[FILEPATH_LEN_MAX];
 
-	ac = (ActionClass *) FindItem("KEYBINDINGS", 0,
-				      LIST_FINDBY_NAME,
-				      LIST_TYPE_ACLASS_GLOBAL);
+	ac =
+	   (ActionClass *) FindItem("KEYBINDINGS", 0, LIST_FINDBY_NAME,
+				    LIST_TYPE_ACLASS_GLOBAL);
 	if (ac)
 	  {
 	     for (i = 0; i < ac->num; i++)
@@ -702,8 +706,8 @@ HandleComms(XEvent * ev)
 			    else if (a->modifiers == (ShiftMask | Mod1Mask))
 			       mod = 6;
 			    else if (a->modifiers ==
-				     (ShiftMask | ControlMask | Mod1Mask))
-			       mod = 7;
+				     (ShiftMask | ControlMask | Mod1Mask)) mod =
+				  7;
 			    else if (a->modifiers == (Mod2Mask))
 			       mod = 8;
 			    else if (a->modifiers == (Mod3Mask))
@@ -723,23 +727,22 @@ HandleComms(XEvent * ev)
 			    else if (a->modifiers == (Mod4Mask | ControlMask))
 			       mod = 16;
 			    else if (a->modifiers ==
-				     (Mod4Mask | ControlMask | ShiftMask))
-			       mod = 17;
+				     (Mod4Mask | ControlMask | ShiftMask)) mod =
+				  17;
 			    else if (a->modifiers == (Mod5Mask | ShiftMask))
 			       mod = 18;
 			    else if (a->modifiers == (Mod5Mask | ControlMask))
 			       mod = 19;
 			    else if (a->modifiers ==
-				     (Mod5Mask | ControlMask | ShiftMask))
-			       mod = 20;
+				     (Mod5Mask | ControlMask | ShiftMask)) mod =
+				  20;
 			    if (a->action->params)
-			       Esnprintf(buf2, sizeof(buf2),
-					 "%s %i %i %s\n", key, mod,
-					 a->action->Type, a->action->params);
+			       Esnprintf(buf2, sizeof(buf2), "%s %i %i %s\n",
+					 key, mod, a->action->Type,
+					 a->action->params);
 			    else
-			       Esnprintf(buf2, sizeof(buf2),
-					 "%s %i %i\n", key, mod,
-					 a->action->Type);
+			       Esnprintf(buf2, sizeof(buf2), "%s %i %i\n", key,
+					 mod, a->action->Type);
 			    if (buf)
 			      {
 				 buf =
@@ -771,9 +774,9 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX], *sp, *ss;
 
 	mode.keybinds_changed = 1;
-	ac = (ActionClass *) RemoveItem("KEYBINDINGS", 0,
-					LIST_FINDBY_NAME,
-					LIST_TYPE_ACLASS_GLOBAL);
+	ac =
+	   (ActionClass *) RemoveItem("KEYBINDINGS", 0, LIST_FINDBY_NAME,
+				      LIST_TYPE_ACLASS_GLOBAL);
 	if (ac)
 	   RemoveActionClass(ac);
 	ac = CreateAclass("KEYBINDINGS");
@@ -863,10 +866,12 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX], buf2[FILEPATH_LEN_MAX];
 
 	sscanf(s, "%*s %1000s %1000s", buf, buf2);
-	bg = (Background *) FindItem(buf, 0, LIST_FINDBY_NAME,
-				     LIST_TYPE_BACKGROUND);
-	cm = (ColorModifierClass *) FindItem(buf2, 0, LIST_FINDBY_NAME,
-					     LIST_TYPE_COLORMODIFIER);
+	bg =
+	   (Background *) FindItem(buf, 0, LIST_FINDBY_NAME,
+				   LIST_TYPE_BACKGROUND);
+	cm =
+	   (ColorModifierClass *) FindItem(buf2, 0, LIST_FINDBY_NAME,
+					   LIST_TYPE_COLORMODIFIER);
 	if ((bg) && (bg->cmclass != cm))
 	  {
 	     if (!strcmp(buf, "(null)"))
@@ -895,8 +900,9 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX];
 
 	sscanf(s, "%*s %1000s", w);
-	bg = (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
-				     LIST_TYPE_BACKGROUND);
+	bg =
+	   (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
+				   LIST_TYPE_BACKGROUND);
 	Esnprintf(buf, sizeof(buf), "(null)");
 	if ((bg) && (bg->cmclass))
 	   Esnprintf(buf, sizeof(buf), "%s", bg->cmclass->name);
@@ -908,8 +914,9 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX];
 
 	sscanf(s, "%*s %1000s", w);
-	cm = (ColorModifierClass *) FindItem(w, 0, LIST_FINDBY_NAME,
-					     LIST_TYPE_COLORMODIFIER);
+	cm =
+	   (ColorModifierClass *) FindItem(w, 0, LIST_FINDBY_NAME,
+					   LIST_TYPE_COLORMODIFIER);
 	Esnprintf(buf, sizeof(buf), "(null)");
 	if (cm)
 	   FreeCMClass(cm);
@@ -921,8 +928,9 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX], buf2[FILEPATH_LEN_MAX];
 
 	sscanf(s, "%*s %1000s", w);
-	cm = (ColorModifierClass *) FindItem(w, 0, LIST_FINDBY_NAME,
-					     LIST_TYPE_COLORMODIFIER);
+	cm =
+	   (ColorModifierClass *) FindItem(w, 0, LIST_FINDBY_NAME,
+					   LIST_TYPE_COLORMODIFIER);
 	Esnprintf(buf, sizeof(buf), "(null)");
 	if (cm)
 	  {
@@ -966,8 +974,9 @@ HandleComms(XEvent * ev)
 	unsigned char      *bpx = NULL, *bpy = NULL;
 
 	sscanf(s, "%*s %1000s", w);
-	cm = (ColorModifierClass *) FindItem(w, 0, LIST_FINDBY_NAME,
-					     LIST_TYPE_COLORMODIFIER);
+	cm =
+	   (ColorModifierClass *) FindItem(w, 0, LIST_FINDBY_NAME,
+					   LIST_TYPE_COLORMODIFIER);
 	name = duplicate(w);
 	i = 3;
 	word(s, i++, w);
@@ -1050,43 +1059,39 @@ HandleComms(XEvent * ev)
 	     if ((bg->bg.file) && (bg->top.file))
 		Esnprintf(buf, sizeof(buf),
 			  "%s %i %i %i %s %i %i %i %i %i %i %s %i %i %i %i %i",
-			  bg->name,
-			  bg->bg.solid.r, bg->bg.solid.g, bg->bg.solid.b,
-			  bg->bg.file, bg->bg.tile, bg->bg.keep_aspect,
-			  bg->bg.xjust, bg->bg.yjust, bg->bg.xperc,
-			  bg->bg.yperc, bg->top.file, bg->top.keep_aspect,
-			  bg->top.xjust, bg->top.yjust, bg->top.xperc,
-			  bg->top.yperc);
+			  bg->name, bg->bg.solid.r, bg->bg.solid.g,
+			  bg->bg.solid.b, bg->bg.file, bg->bg.tile,
+			  bg->bg.keep_aspect, bg->bg.xjust, bg->bg.yjust,
+			  bg->bg.xperc, bg->bg.yperc, bg->top.file,
+			  bg->top.keep_aspect, bg->top.xjust, bg->top.yjust,
+			  bg->top.xperc, bg->top.yperc);
 	     else if ((!(bg->bg.file)) && (bg->top.file))
 		Esnprintf(buf, sizeof(buf),
 			  "%s %i %i %i %s %i %i %i %i %i %i %s %i %i %i %i %i",
-			  bg->name,
-			  bg->bg.solid.r, bg->bg.solid.g, bg->bg.solid.b,
-			  "(null)", bg->bg.tile, bg->bg.keep_aspect,
-			  bg->bg.xjust, bg->bg.yjust, bg->bg.xperc,
-			  bg->bg.yperc, bg->top.file, bg->top.keep_aspect,
-			  bg->top.xjust, bg->top.yjust, bg->top.xperc,
-			  bg->top.yperc);
+			  bg->name, bg->bg.solid.r, bg->bg.solid.g,
+			  bg->bg.solid.b, "(null)", bg->bg.tile,
+			  bg->bg.keep_aspect, bg->bg.xjust, bg->bg.yjust,
+			  bg->bg.xperc, bg->bg.yperc, bg->top.file,
+			  bg->top.keep_aspect, bg->top.xjust, bg->top.yjust,
+			  bg->top.xperc, bg->top.yperc);
 	     else if ((bg->bg.file) && (!(bg->top.file)))
 		Esnprintf(buf, sizeof(buf),
 			  "%s %i %i %i %s %i %i %i %i %i %i %s %i %i %i %i %i",
-			  bg->name,
-			  bg->bg.solid.r, bg->bg.solid.g, bg->bg.solid.b,
-			  bg->bg.file, bg->bg.tile, bg->bg.keep_aspect,
-			  bg->bg.xjust, bg->bg.yjust, bg->bg.xperc,
-			  bg->bg.yperc, "(null)", bg->top.keep_aspect,
-			  bg->top.xjust, bg->top.yjust, bg->top.xperc,
-			  bg->top.yperc);
+			  bg->name, bg->bg.solid.r, bg->bg.solid.g,
+			  bg->bg.solid.b, bg->bg.file, bg->bg.tile,
+			  bg->bg.keep_aspect, bg->bg.xjust, bg->bg.yjust,
+			  bg->bg.xperc, bg->bg.yperc, "(null)",
+			  bg->top.keep_aspect, bg->top.xjust, bg->top.yjust,
+			  bg->top.xperc, bg->top.yperc);
 	     else if ((!(bg->bg.file)) && (!(bg->top.file)))
 		Esnprintf(buf, sizeof(buf),
 			  "%s %i %i %i %s %i %i %i %i %i %i %s %i %i %i %i %i",
-			  bg->name,
-			  bg->bg.solid.r, bg->bg.solid.g, bg->bg.solid.b,
-			  "(null)", bg->bg.tile, bg->bg.keep_aspect,
-			  bg->bg.xjust, bg->bg.yjust, bg->bg.xperc,
-			  bg->bg.yperc, "(null)", bg->top.keep_aspect,
-			  bg->top.xjust, bg->top.yjust, bg->top.xperc,
-			  bg->top.yperc);
+			  bg->name, bg->bg.solid.r, bg->bg.solid.g,
+			  bg->bg.solid.b, "(null)", bg->bg.tile,
+			  bg->bg.keep_aspect, bg->bg.xjust, bg->bg.yjust,
+			  bg->bg.xperc, bg->bg.yperc, "(null)",
+			  bg->top.keep_aspect, bg->top.xjust, bg->top.yjust,
+			  bg->top.xperc, bg->top.yperc);
 	  }
 	CommsSend(c, buf);
      }
@@ -1215,9 +1220,10 @@ HandleComms(XEvent * ev)
 	     word(s, 13, w);
 	     if (strcmp("(null)", w))
 		topf = duplicate(w);
-	     bg = CreateDesktopBG(name, &icl, bgf, tile, keep_aspect, xjust,
-				  yjust, xperc, yperc, topf, tkeep_aspect,
-				  txjust, tyjust, txperc, typerc);
+	     bg =
+		CreateDesktopBG(name, &icl, bgf, tile, keep_aspect, xjust,
+				yjust, xperc, yperc, topf, tkeep_aspect, txjust,
+				tyjust, txperc, typerc);
 	     if (name)
 		Efree(name);
 	     if (bgf)
@@ -1259,11 +1265,16 @@ HandleComms(XEvent * ev)
 		  word(s, wd, w);
 		  mode.focusmode = atoi(w);
 	       }
-	     else if (!strcmp(w, "DOCKDIRMODE:"))
+	     else if (!strcmp(w, "DOCKAPP_SUPPORT:"))
 	       {
 		  word(s, wd, w);
 		  mode.dockdirmode = atoi(w);
 	       }
+	     else if (!strcmp(w, "DOCKDIRMODE:"))
+	       {
+		  word(s, wd, w);
+		  mode.dockapp_support = atoi(w);
+	       }
 	     else if (!strcmp(w, "ICONDIRMODE:"))
 	       {
 		  word(s, wd, w);
@@ -1467,6 +1478,11 @@ HandleComms(XEvent * ev)
 		  word(s, wd, w);
 		  mode.manual_placement = atoi(w);
 	       }
+	     else if (!strcmp(w, "MANUAL_PLACEMENT_MOUSE_POINTER:"))
+	       {
+		  word(s, wd, w);
+		  mode.manual_placement_mouse_pointer = atoi(w);
+	       }
 	     else if (!strcmp(w, "RAISE_ON_NEXT_FOCUS:"))
 	       {
 		  word(s, wd, w);
@@ -1525,8 +1541,7 @@ HandleComms(XEvent * ev)
 	     while (
 		    (b =
 		     RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
-				LIST_TYPE_BUTTON)))
-		DestroyButton(b);
+				LIST_TYPE_BUTTON))) DestroyButton(b);
 	     InitDesktopControls();
 	     ShowDesktopControls();
 	  }
@@ -1565,75 +1580,47 @@ HandleComms(XEvent * ev)
 
 	GetAreaSize(&a, &b);
 	Esnprintf(buf, sizeof(buf),
-		  "FOCUSMODE: %i\n"
-		  "DOCKDIRMODE: %i\n"
-		  "ICONDIRMODE: %i\n"
-		  "MOVEMODE: %i\n"
-		  "RESIZEMODE: %i\n"
-		  "SLIDEMODE: %i\n"
-		  "CLEANUPSLIDE: %i\n"
-		  "MAPSLIDE: %i\n"
-		  "SLIDESPEEDMAP: %i\n"
-		  "SLIDESPEEDCLEANUP: %i\n"
-		  "SHADESPEED: %i\n"
-		  "DESKTOPBGTIMEOUT: %i\n"
-		  "SOUND: %i\n"
-		  "BUTTONMOVERESISTANCE: %i\n"
-		  "AUTOSAVE: %i\n"
-		  "MEMORYPARANOIA: %i\n"
-		  "TOOLTIPS: %i\n"
-		  "TIPTIME: %f\n"
-		  "AUTORAISE: %i\n"
-		  "AUTORAISETIME: %f\n"
-		  "DOCKSTARTX: %i\n"
-		  "DOCKSTARTY: %i\n"
-		  "SAVEUNDER: %i\n"
-		  "MENUSLIDE: %i\n"
-		  "NUMDESKTOPS: %i\n"
-		  "DRAGDIR: %i\n"
-		  "DRAGBARWIDTH: %i\n"
-		  "DRAGBARORDERING: %i\n"
-		  "DRAGBARLENGTH: %i\n"
-		  "DESKSLIDEIN: %i\n"
-		  "DESKSLIDESPEED: %i\n"
-		  "HIQUALITYBG: %i\n"
-		  "TRANSIENTSFOLLOWLEADER: %i\n"
-		  "SWITCHFORTRANSIENTMAP: %i\n"
-		  "SHOWICONS: %i\n"
-		  "AREA_SIZE: %i %i\n"
+		  "FOCUSMODE: %i\n" "DOCKAPP_SUPPORT: %i\n" "DOCKDIRMODE: %i\n"
+		  "ICONDIRMODE: %i\n" "MOVEMODE: %i\n" "RESIZEMODE: %i\n"
+		  "SLIDEMODE: %i\n" "CLEANUPSLIDE: %i\n" "MAPSLIDE: %i\n"
+		  "SLIDESPEEDMAP: %i\n" "SLIDESPEEDCLEANUP: %i\n"
+		  "SHADESPEED: %i\n" "DESKTOPBGTIMEOUT: %i\n" "SOUND: %i\n"
+		  "BUTTONMOVERESISTANCE: %i\n" "AUTOSAVE: %i\n"
+		  "MEMORYPARANOIA: %i\n" "TOOLTIPS: %i\n" "TIPTIME: %f\n"
+		  "AUTORAISE: %i\n" "AUTORAISETIME: %f\n" "DOCKSTARTX: %i\n"
+		  "DOCKSTARTY: %i\n" "SAVEUNDER: %i\n" "MENUSLIDE: %i\n"
+		  "NUMDESKTOPS: %i\n" "DRAGDIR: %i\n" "DRAGBARWIDTH: %i\n"
+		  "DRAGBARORDERING: %i\n" "DRAGBARLENGTH: %i\n"
+		  "DESKSLIDEIN: %i\n" "DESKSLIDESPEED: %i\n" "HIQUALITYBG: %i\n"
+		  "TRANSIENTSFOLLOWLEADER: %i\n" "SWITCHFORTRANSIENTMAP: %i\n"
+		  "SHOWICONS: %i\n" "AREA_SIZE: %i %i\n"
 		  "ALL_NEW_WINDOWS_GET_FOCUS: %i\n"
 		  "NEW_TRANSIENTS_GET_FOCUS: %i\n"
 		  "NEW_TRANSIENTS_GET_FOCUS_IF_GROUP_FOCUSED: %i\n"
 		  "MANUAL_PLACEMENT: %i\n"
-		  "RAISE_ON_NEXT_FOCUS: %i\n"
-		  "RAISE_AFTER_NEXT_FOCUS: %i\n"
-		  "DISPLAY_WARP: %i\n"
-		  "WARP_ON_NEXT_FOCUS: %i\n"
-		  "WARP_AFTER_NEXT_FOCUS: %i\n"
-		  "EDGE_FLIP_RESISTANCE: %i\n",
-		  mode.focusmode, mode.dockdirmode, mode.primaryicondir,
-		  mode.movemode, mode.resizemode, mode.slidemode,
-		  mode.cleanupslide, mode.mapslide, mode.slidespeedmap,
-		  mode.slidespeedcleanup, mode.shadespeed,
+		  "MANUAL_PLACEMENT_MOUSE_POINTER: %i\n"
+		  "RAISE_ON_NEXT_FOCUS: %i\n" "RAISE_AFTER_NEXT_FOCUS: %i\n"
+		  "DISPLAY_WARP: %i\n" "WARP_ON_NEXT_FOCUS: %i\n"
+		  "WARP_AFTER_NEXT_FOCUS: %i\n" "EDGE_FLIP_RESISTANCE: %i\n",
+		  mode.focusmode, mode.dockapp_support, mode.dockdirmode,
+		  mode.primaryicondir, mode.movemode, mode.resizemode,
+		  mode.slidemode, mode.cleanupslide, mode.mapslide,
+		  mode.slidespeedmap, mode.slidespeedcleanup, mode.shadespeed,
 		  mode.desktop_bg_timeout, mode.sound,
 		  mode.button_move_resistance, mode.autosave,
 		  mode.memory_paranoia, mode.tooltips, mode.tiptime,
-		  mode.autoraise, mode.autoraisetime,
-		  mode.dockstartx, mode.dockstarty, mode.save_under,
-		  mode.menuslide, mode.numdesktops,
-		  desks.dragdir, desks.dragbar_width,
+		  mode.autoraise, mode.autoraisetime, mode.dockstartx,
+		  mode.dockstarty, mode.save_under, mode.menuslide,
+		  mode.numdesktops, desks.dragdir, desks.dragbar_width,
 		  desks.dragbar_ordering, desks.dragbar_length, desks.slidein,
 		  desks.slidespeed, desks.hiqualitybg,
 		  mode.transientsfollowleader, mode.switchfortransientmap,
-		  mode.showicons, a, b,
-		  mode.all_new_windows_get_focus,
+		  mode.showicons, a, b, mode.all_new_windows_get_focus,
 		  mode.new_transients_get_focus,
 		  mode.new_transients_get_focus_if_group_focused,
-		  mode.manual_placement,
-		  mode.raise_on_next_focus,
-		  mode.raise_after_next_focus,
-		  mode.display_warp,
-		  mode.warp_on_next_focus,
+		  mode.manual_placement, mode.manual_placement_mouse_pointer,
+		  mode.raise_on_next_focus, mode.raise_after_next_focus,
+		  mode.display_warp, mode.warp_on_next_focus,
 		  mode.warp_after_next_focus, mode.edge_flip_resistance);
 	CommsSend(c, buf);
      }
@@ -1709,8 +1696,7 @@ HandleComms(XEvent * ev)
 	     if (ewin->border)
 	       {
 		  Esnprintf(buf, sizeof(buf),
-			    "***CLIENT***\n"
-			    "CLIENT_WIN_ID:          %8x\n"
+			    "***CLIENT***\n" "CLIENT_WIN_ID:          %8x\n"
 			    "FRAME_WIN_ID:           %8x\n"
 			    "FRAME_X,Y:              %5i , %5i\n"
 			    "FRAME_WIDTH,HEIGHT:     %5i , %5i\n"
@@ -1789,8 +1775,7 @@ HandleComms(XEvent * ev)
 	     else
 	       {
 		  Esnprintf(buf, sizeof(buf),
-			    "***CLIENT***\n"
-			    "CLIENT_WIN_ID:          %8x\n"
+			    "***CLIENT***\n" "CLIENT_WIN_ID:          %8x\n"
 			    "FRAME_WIN_ID:           %8x\n"
 			    "FRAME_X,Y:              %5i , %5i\n"
 			    "FRAME_WIDTH,HEIGHT:     %5i , %5i\n"
@@ -1919,8 +1904,8 @@ HandleComms(XEvent * ev)
 	  }
 	if (mode.context_ewin)
 	  {
-	     Esnprintf(buf5, sizeof(buf5),
-		       "context_ewin - %8x\n", mode.context_ewin->client.win);
+	     Esnprintf(buf5, sizeof(buf5), "context_ewin - %8x\n",
+		       mode.context_ewin->client.win);
 	     strcat(buf, buf5);
 	  }
 	CommsSend(c, buf);
@@ -1951,8 +1936,7 @@ HandleComms(XEvent * ev)
 	     if (lst[i]->border)
 	       {
 		  Esnprintf(buf, sizeof(buf),
-			    "***CLIENT***\n"
-			    "CLIENT_WIN_ID:          %8x\n"
+			    "***CLIENT***\n" "CLIENT_WIN_ID:          %8x\n"
 			    "FRAME_WIN_ID:           %8x\n"
 			    "FRAME_X,Y:              %5i , %5i\n"
 			    "FRAME_WIDTH,HEIGHT:     %5i , %5i\n"
@@ -1996,55 +1980,31 @@ HandleComms(XEvent * ev)
 			    "MWM_MENU:               %5i\n"
 			    "MWM_MINIMIZE:           %5i\n"
 			    "MWM_MAXIMIZE:           %5i\n"
-			    "APP_STATE:              %5i\n",
-			    lst[i]->client.win,
-			    lst[i]->win,
-			    lst[i]->x,
-			    lst[i]->y,
-			    lst[i]->w,
-			    lst[i]->h,
-			    lst[i]->border->name,
+			    "APP_STATE:              %5i\n", lst[i]->client.win,
+			    lst[i]->win, lst[i]->x, lst[i]->y, lst[i]->w,
+			    lst[i]->h, lst[i]->border->name,
 			    lst[i]->border->border.left,
 			    lst[i]->border->border.right,
 			    lst[i]->border->border.top,
-			    lst[i]->border->border.bottom,
-			    lst[i]->desktop,
-			    lst[i]->num_groups,
-			    lst[i]->docked,
-			    lst[i]->sticky,
-			    lst[i]->visible,
-			    lst[i]->iconified,
-			    lst[i]->shaded,
-			    lst[i]->active,
-			    lst[i]->layer,
-			    lst[i]->never_use_area,
-			    lst[i]->floating,
-			    lst[i]->client.w,
-			    lst[i]->client.h,
-			    lst[i]->client.icon_win,
-			    lst[i]->client.icon_pmap,
-			    lst[i]->client.icon_mask,
-			    lst[i]->client.group,
-			    lst[i]->client.need_input,
-			    lst[i]->client.transient,
-			    lst[i]->client.title,
-			    lst[i]->client.class,
-			    lst[i]->client.name,
-			    lst[i]->client.command,
-			    lst[i]->client.machine,
-			    lst[i]->client.icon_name,
+			    lst[i]->border->border.bottom, lst[i]->desktop,
+			    lst[i]->num_groups, lst[i]->docked, lst[i]->sticky,
+			    lst[i]->visible, lst[i]->iconified, lst[i]->shaded,
+			    lst[i]->active, lst[i]->layer,
+			    lst[i]->never_use_area, lst[i]->floating,
+			    lst[i]->client.w, lst[i]->client.h,
+			    lst[i]->client.icon_win, lst[i]->client.icon_pmap,
+			    lst[i]->client.icon_mask, lst[i]->client.group,
+			    lst[i]->client.need_input, lst[i]->client.transient,
+			    lst[i]->client.title, lst[i]->client.class,
+			    lst[i]->client.name, lst[i]->client.command,
+			    lst[i]->client.machine, lst[i]->client.icon_name,
 			    lst[i]->client.is_group_leader,
 			    lst[i]->client.no_resize_h,
-			    lst[i]->client.no_resize_v,
-			    lst[i]->client.shaped,
-			    lst[i]->client.width.min,
-			    lst[i]->client.height.min,
-			    lst[i]->client.width.max,
-			    lst[i]->client.height.max,
-			    lst[i]->client.base_w,
-			    lst[i]->client.base_h,
-			    lst[i]->client.w_inc,
-			    lst[i]->client.h_inc,
+			    lst[i]->client.no_resize_v, lst[i]->client.shaped,
+			    lst[i]->client.width.min, lst[i]->client.height.min,
+			    lst[i]->client.width.max, lst[i]->client.height.max,
+			    lst[i]->client.base_w, lst[i]->client.base_h,
+			    lst[i]->client.w_inc, lst[i]->client.h_inc,
 			    lst[i]->client.aspect_min,
 			    lst[i]->client.aspect_max,
 			    lst[i]->client.mwm_decor_border,
@@ -2058,8 +2018,7 @@ HandleComms(XEvent * ev)
 	     else
 	       {
 		  Esnprintf(buf, sizeof(buf),
-			    "***CLIENT***\n"
-			    "CLIENT_WIN_ID:          %8x\n"
+			    "***CLIENT***\n" "CLIENT_WIN_ID:          %8x\n"
 			    "FRAME_WIN_ID:           %8x\n"
 			    "FRAME_X,Y:              %5i , %5i\n"
 			    "FRAME_WIDTH,HEIGHT:     %5i , %5i\n"
@@ -2103,55 +2062,27 @@ HandleComms(XEvent * ev)
 			    "MWM_MENU:               %5i\n"
 			    "MWM_MINIMIZE:           %5i\n"
 			    "MWM_MAXIMIZE:           %5i\n"
-			    "APP_STATE:              %5i\n",
-			    lst[i]->client.win,
-			    lst[i]->win,
-			    lst[i]->x,
-			    lst[i]->y,
-			    lst[i]->w,
-			    lst[i]->h,
-			    none,
-			    0,
-			    0,
-			    0,
-			    0,
-			    lst[i]->desktop,
-			    lst[i]->num_groups,
-			    lst[i]->docked,
-			    lst[i]->sticky,
-			    lst[i]->visible,
-			    lst[i]->iconified,
-			    lst[i]->shaded,
-			    lst[i]->active,
-			    lst[i]->layer,
-			    lst[i]->never_use_area,
-			    lst[i]->floating,
-			    lst[i]->client.w,
-			    lst[i]->client.h,
-			    lst[i]->client.icon_win,
-			    lst[i]->client.icon_pmap,
-			    lst[i]->client.icon_mask,
-			    lst[i]->client.group,
-			    lst[i]->client.need_input,
-			    lst[i]->client.transient,
-			    lst[i]->client.title,
-			    lst[i]->client.class,
-			    lst[i]->client.name,
-			    lst[i]->client.command,
-			    lst[i]->client.machine,
-			    lst[i]->client.icon_name,
+			    "APP_STATE:              %5i\n", lst[i]->client.win,
+			    lst[i]->win, lst[i]->x, lst[i]->y, lst[i]->w,
+			    lst[i]->h, none, 0, 0, 0, 0, lst[i]->desktop,
+			    lst[i]->num_groups, lst[i]->docked, lst[i]->sticky,
+			    lst[i]->visible, lst[i]->iconified, lst[i]->shaded,
+			    lst[i]->active, lst[i]->layer,
+			    lst[i]->never_use_area, lst[i]->floating,
+			    lst[i]->client.w, lst[i]->client.h,
+			    lst[i]->client.icon_win, lst[i]->client.icon_pmap,
+			    lst[i]->client.icon_mask, lst[i]->client.group,
+			    lst[i]->client.need_input, lst[i]->client.transient,
+			    lst[i]->client.title, lst[i]->client.class,
+			    lst[i]->client.name, lst[i]->client.command,
+			    lst[i]->client.machine, lst[i]->client.icon_name,
 			    lst[i]->client.is_group_leader,
 			    lst[i]->client.no_resize_h,
-			    lst[i]->client.no_resize_v,
-			    lst[i]->client.shaped,
-			    lst[i]->client.width.min,
-			    lst[i]->client.height.min,
-			    lst[i]->client.width.max,
-			    lst[i]->client.height.max,
-			    lst[i]->client.base_w,
-			    lst[i]->client.base_h,
-			    lst[i]->client.w_inc,
-			    lst[i]->client.h_inc,
+			    lst[i]->client.no_resize_v, lst[i]->client.shaped,
+			    lst[i]->client.width.min, lst[i]->client.height.min,
+			    lst[i]->client.width.max, lst[i]->client.height.max,
+			    lst[i]->client.base_w, lst[i]->client.base_h,
+			    lst[i]->client.w_inc, lst[i]->client.h_inc,
 			    lst[i]->client.aspect_min,
 			    lst[i]->client.aspect_max,
 			    lst[i]->client.mwm_decor_border,
