@@ -37,9 +37,11 @@ GetUniqueBGString(Background * bg)
 #endif
    int                 n1, n2, n3, n4, n5, f1, f2, f3, f4, f5, f6;
 
-   n1 = (bg->bg.solid.r << 24) | (bg->bg.solid.g << 16) |
-      (bg->bg.solid.b << 8) | (bg->bg.tile << 7) | (bg->bg.keep_aspect << 6) |
-      (bg->top.keep_aspect << 5);
+   n1 =
+      (bg->bg.solid.r << 24) | (bg->bg.solid.g << 16) | (bg->bg.solid.
+							 b << 8) | (bg->bg.
+								    tile << 7) |
+      (bg->bg.keep_aspect << 6) | (bg->top.keep_aspect << 5);
    n2 = (bg->bg.xjust << 16) | (bg->bg.yjust);
    n3 = (bg->bg.xperc << 16) | (bg->bg.yperc);
    n4 = (bg->top.xjust << 16) | (bg->top.yjust);
@@ -77,81 +79,41 @@ GetUniqueBGString(Background * bg)
 	  }
      }
    Esnprintf(s, sizeof(s),
-	     "%c%c%c%c%c%c"
-	     "%c%c%c%c%c%c"
-	     "%c%c%c%c%c%c"
-	     "%c%c%c%c%c%c"
-	     "%c%c%c%c%c%c"
-	     "%c%c%c%c%c%c"
-	     "%c%c%c%c%c%c"
-	     "%c%c%c%c%c%c"
-	     "%c%c%c%c%c%c"
-	     "%c%c%c%c%c%c"
-	     "%c%c%c%c%c%c",
-	     chmap[(n1 >> 0) & 0x3f],
-	     chmap[(n1 >> 6) & 0x3f],
-	     chmap[(n1 >> 12) & 0x3f],
-	     chmap[(n1 >> 18) & 0x3f],
-	     chmap[(n1 >> 24) & 0x3f],
-	     chmap[(n1 >> 28) & 0x3f],
-	     chmap[(n2 >> 0) & 0x3f],
-	     chmap[(n2 >> 6) & 0x3f],
-	     chmap[(n2 >> 12) & 0x3f],
-	     chmap[(n2 >> 18) & 0x3f],
-	     chmap[(n2 >> 24) & 0x3f],
-	     chmap[(n2 >> 28) & 0x3f],
-	     chmap[(n3 >> 0) & 0x3f],
-	     chmap[(n3 >> 6) & 0x3f],
-	     chmap[(n3 >> 12) & 0x3f],
-	     chmap[(n3 >> 18) & 0x3f],
-	     chmap[(n3 >> 24) & 0x3f],
-	     chmap[(n3 >> 28) & 0x3f],
-	     chmap[(n4 >> 0) & 0x3f],
-	     chmap[(n4 >> 6) & 0x3f],
-	     chmap[(n4 >> 12) & 0x3f],
-	     chmap[(n4 >> 18) & 0x3f],
-	     chmap[(n4 >> 24) & 0x3f],
-	     chmap[(n4 >> 28) & 0x3f],
-	     chmap[(n5 >> 0) & 0x3f],
-	     chmap[(n5 >> 6) & 0x3f],
-	     chmap[(n5 >> 12) & 0x3f],
-	     chmap[(n5 >> 18) & 0x3f],
-	     chmap[(n5 >> 24) & 0x3f],
-	     chmap[(n5 >> 28) & 0x3f],
-	     chmap[(f1 >> 0) & 0x3f],
-	     chmap[(f1 >> 6) & 0x3f],
-	     chmap[(f1 >> 12) & 0x3f],
-	     chmap[(f1 >> 18) & 0x3f],
-	     chmap[(f1 >> 24) & 0x3f],
-	     chmap[(f1 >> 28) & 0x3f],
-	     chmap[(f2 >> 0) & 0x3f],
-	     chmap[(f2 >> 6) & 0x3f],
-	     chmap[(f2 >> 12) & 0x3f],
-	     chmap[(f2 >> 18) & 0x3f],
-	     chmap[(f2 >> 24) & 0x3f],
-	     chmap[(f2 >> 28) & 0x3f],
-	     chmap[(f3 >> 0) & 0x3f],
-	     chmap[(f3 >> 6) & 0x3f],
-	     chmap[(f3 >> 12) & 0x3f],
-	     chmap[(f3 >> 18) & 0x3f],
-	     chmap[(f3 >> 24) & 0x3f],
-	     chmap[(f3 >> 28) & 0x3f],
-	     chmap[(f4 >> 0) & 0x3f],
-	     chmap[(f4 >> 6) & 0x3f],
-	     chmap[(f4 >> 12) & 0x3f],
-	     chmap[(f4 >> 18) & 0x3f],
-	     chmap[(f4 >> 24) & 0x3f],
-	     chmap[(f4 >> 28) & 0x3f],
-	     chmap[(f5 >> 0) & 0x3f],
-	     chmap[(f5 >> 6) & 0x3f],
-	     chmap[(f5 >> 12) & 0x3f],
-	     chmap[(f5 >> 18) & 0x3f],
-	     chmap[(f5 >> 24) & 0x3f],
-	     chmap[(f5 >> 28) & 0x3f],
-	     chmap[(f6 >> 0) & 0x3f],
-	     chmap[(f6 >> 6) & 0x3f],
-	     chmap[(f6 >> 12) & 0x3f],
-	     chmap[(f6 >> 18) & 0x3f],
+	     "%c%c%c%c%c%c" "%c%c%c%c%c%c" "%c%c%c%c%c%c" "%c%c%c%c%c%c"
+	     "%c%c%c%c%c%c" "%c%c%c%c%c%c" "%c%c%c%c%c%c" "%c%c%c%c%c%c"
+	     "%c%c%c%c%c%c" "%c%c%c%c%c%c" "%c%c%c%c%c%c",
+	     chmap[(n1 >> 0) & 0x3f], chmap[(n1 >> 6) & 0x3f],
+	     chmap[(n1 >> 12) & 0x3f], chmap[(n1 >> 18) & 0x3f],
+	     chmap[(n1 >> 24) & 0x3f], chmap[(n1 >> 28) & 0x3f],
+	     chmap[(n2 >> 0) & 0x3f], chmap[(n2 >> 6) & 0x3f],
+	     chmap[(n2 >> 12) & 0x3f], chmap[(n2 >> 18) & 0x3f],
+	     chmap[(n2 >> 24) & 0x3f], chmap[(n2 >> 28) & 0x3f],
+	     chmap[(n3 >> 0) & 0x3f], chmap[(n3 >> 6) & 0x3f],
+	     chmap[(n3 >> 12) & 0x3f], chmap[(n3 >> 18) & 0x3f],
+	     chmap[(n3 >> 24) & 0x3f], chmap[(n3 >> 28) & 0x3f],
+	     chmap[(n4 >> 0) & 0x3f], chmap[(n4 >> 6) & 0x3f],
+	     chmap[(n4 >> 12) & 0x3f], chmap[(n4 >> 18) & 0x3f],
+	     chmap[(n4 >> 24) & 0x3f], chmap[(n4 >> 28) & 0x3f],
+	     chmap[(n5 >> 0) & 0x3f], chmap[(n5 >> 6) & 0x3f],
+	     chmap[(n5 >> 12) & 0x3f], chmap[(n5 >> 18) & 0x3f],
+	     chmap[(n5 >> 24) & 0x3f], chmap[(n5 >> 28) & 0x3f],
+	     chmap[(f1 >> 0) & 0x3f], chmap[(f1 >> 6) & 0x3f],
+	     chmap[(f1 >> 12) & 0x3f], chmap[(f1 >> 18) & 0x3f],
+	     chmap[(f1 >> 24) & 0x3f], chmap[(f1 >> 28) & 0x3f],
+	     chmap[(f2 >> 0) & 0x3f], chmap[(f2 >> 6) & 0x3f],
+	     chmap[(f2 >> 12) & 0x3f], chmap[(f2 >> 18) & 0x3f],
+	     chmap[(f2 >> 24) & 0x3f], chmap[(f2 >> 28) & 0x3f],
+	     chmap[(f3 >> 0) & 0x3f], chmap[(f3 >> 6) & 0x3f],
+	     chmap[(f3 >> 12) & 0x3f], chmap[(f3 >> 18) & 0x3f],
+	     chmap[(f3 >> 24) & 0x3f], chmap[(f3 >> 28) & 0x3f],
+	     chmap[(f4 >> 0) & 0x3f], chmap[(f4 >> 6) & 0x3f],
+	     chmap[(f4 >> 12) & 0x3f], chmap[(f4 >> 18) & 0x3f],
+	     chmap[(f4 >> 24) & 0x3f], chmap[(f4 >> 28) & 0x3f],
+	     chmap[(f5 >> 0) & 0x3f], chmap[(f5 >> 6) & 0x3f],
+	     chmap[(f5 >> 12) & 0x3f], chmap[(f5 >> 18) & 0x3f],
+	     chmap[(f5 >> 24) & 0x3f], chmap[(f5 >> 28) & 0x3f],
+	     chmap[(f6 >> 0) & 0x3f], chmap[(f6 >> 6) & 0x3f],
+	     chmap[(f6 >> 12) & 0x3f], chmap[(f6 >> 18) & 0x3f],
 	     chmap[(f6 >> 24) & 0x3f], chmap[(f6 >> 28) & 0x3f]);
    return duplicate(s);
 }
@@ -449,11 +411,10 @@ FreeDesktopBG(Background * bg)
 }
 
 Background         *
-CreateDesktopBG(char *name, ImlibColor * solid,
-		char *bg, char tile, char keep_aspect,
-		int xjust, int yjust, int xperc, int yperc,
-		char *top, char tkeep_aspect,
-		int txjust, int tyjust, int txperc, int typerc)
+CreateDesktopBG(char *name, ImlibColor * solid, char *bg, char tile,
+		char keep_aspect, int xjust, int yjust, int xperc,
+		int yperc, char *top, char tkeep_aspect, int txjust,
+		int tyjust, int txperc, int typerc)
 {
    ImlibData          *imd;
    Background         *d;
@@ -602,9 +563,10 @@ SetBackgroundTo(ImlibData * imd, Window win, Background * dsk, char setbg)
 	  }
 	else
 	  {
-	     cm = (ColorModifierClass *) FindItem("BACKGROUND", 0,
-						  LIST_FINDBY_NAME,
-						  LIST_TYPE_COLORMODIFIER);
+	     cm =
+		(ColorModifierClass *) FindItem("BACKGROUND", 0,
+						LIST_FINDBY_NAME,
+						LIST_TYPE_COLORMODIFIER);
 	  }
 
 	if (dsk->bg.file)
@@ -1107,23 +1069,25 @@ InitDesktopControls()
 	     if (i > 0)
 	       {
 		  ac->tooltipstring =
-		     duplicate(_("Hold down the mouse button and drag\n"
-				 "the mouse to be able to drag the desktop\n"
-				 "back and forth.\n"
-				 "Click right mouse button for a list of all\n"
-				 "Desktops and their applications.\n"
-				 "Click middle mouse button for a list of all\n"
-				 "applications currently running.\n"));
+		     duplicate(_
+			       ("Hold down the mouse button and drag\n"
+				"the mouse to be able to drag the desktop\n"
+				"back and forth.\n"
+				"Click right mouse button for a list of all\n"
+				"Desktops and their applications.\n"
+				"Click middle mouse button for a list of all\n"
+				"applications currently running.\n"));
 	       }
 	     else
 	       {
 		  ac->tooltipstring =
-		     duplicate(_("This is the Root desktop.\n"
-				 "You cannot drag the root desktop around.\n"
-				 "Click right mouse button for a list of all\n"
-				 "Desktops and their applications.\n"
-				 "Click middle mouse button for a list of all\n"
-				 "applications currently running.\n"));
+		     duplicate(_
+			       ("This is the Root desktop.\n"
+				"You cannot drag the root desktop around.\n"
+				"Click right mouse button for a list of all\n"
+				"Desktops and their applications.\n"
+				"Click middle mouse button for a list of all\n"
+				"applications currently running.\n"));
 	       }
 	  }
 	Esnprintf(s, sizeof(s), "RAISEBUTTON_DESKTOP_%i", i);
@@ -1138,8 +1102,9 @@ InitDesktopControls()
 	     Esnprintf(param, 3, "%i", i);
 	     AddToAction(a, ACTION_DESKTOP_RAISE, param);
 	     ac2->tooltipstring =
-		duplicate(_("Click here to raise this desktop\n"
-			    "to the top.\n"));
+		duplicate(_
+			  ("Click here to raise this desktop\n"
+			   "to the top.\n"));
 	  }
 	Esnprintf(s, sizeof(s), "LOWERBUTTON_DESKTOP_%i", i);
 	ac3 = FindItem(s, 0, LIST_FINDBY_NAME, LIST_TYPE_ACLASS);
@@ -1153,32 +1118,41 @@ InitDesktopControls()
 	     Esnprintf(param, 3, "%i", i);
 	     AddToAction(a, ACTION_DESKTOP_LOWER, param);
 	     ac3->tooltipstring =
-		duplicate(_("Click here to lower this desktop\n"
-			    "to the bottom.\n"));
+		duplicate(_
+			  ("Click here to lower this desktop\n"
+			   "to the bottom.\n"));
 	  }
 	b = NULL;
 
 	if (desks.dragdir < 2)
 	  {
-	     ic = FindItem("DESKTOP_DRAGBUTTON_VERT", 0, LIST_FINDBY_NAME,
-			   LIST_TYPE_ICLASS);
-	     ic2 = FindItem("DESKTOP_RAISEBUTTON_VERT", 0, LIST_FINDBY_NAME,
-			    LIST_TYPE_ICLASS);
-	     ic3 = FindItem("DESKTOP_LOWERBUTTON_VERT", 0, LIST_FINDBY_NAME,
-			    LIST_TYPE_ICLASS);
-	     ic4 = FindItem("DESKTOP_DESKRAY_VERT", 0, LIST_FINDBY_NAME,
-			    LIST_TYPE_ICLASS);
+	     ic =
+		FindItem("DESKTOP_DRAGBUTTON_VERT", 0, LIST_FINDBY_NAME,
+			 LIST_TYPE_ICLASS);
+	     ic2 =
+		FindItem("DESKTOP_RAISEBUTTON_VERT", 0, LIST_FINDBY_NAME,
+			 LIST_TYPE_ICLASS);
+	     ic3 =
+		FindItem("DESKTOP_LOWERBUTTON_VERT", 0, LIST_FINDBY_NAME,
+			 LIST_TYPE_ICLASS);
+	     ic4 =
+		FindItem("DESKTOP_DESKRAY_VERT", 0, LIST_FINDBY_NAME,
+			 LIST_TYPE_ICLASS);
 	  }
 	else
 	  {
-	     ic = FindItem("DESKTOP_DRAGBUTTON_HORIZ", 0, LIST_FINDBY_NAME,
-			   LIST_TYPE_ICLASS);
-	     ic2 = FindItem("DESKTOP_RAISEBUTTON_HORIZ", 0, LIST_FINDBY_NAME,
-			    LIST_TYPE_ICLASS);
-	     ic3 = FindItem("DESKTOP_LOWERBUTTON_HORIZ", 0, LIST_FINDBY_NAME,
-			    LIST_TYPE_ICLASS);
-	     ic4 = FindItem("DESKTOP_DESKRAY_HORIZ", 0, LIST_FINDBY_NAME,
-			    LIST_TYPE_ICLASS);
+	     ic =
+		FindItem("DESKTOP_DRAGBUTTON_HORIZ", 0, LIST_FINDBY_NAME,
+			 LIST_TYPE_ICLASS);
+	     ic2 =
+		FindItem("DESKTOP_RAISEBUTTON_HORIZ", 0, LIST_FINDBY_NAME,
+			 LIST_TYPE_ICLASS);
+	     ic3 =
+		FindItem("DESKTOP_LOWERBUTTON_HORIZ", 0, LIST_FINDBY_NAME,
+			 LIST_TYPE_ICLASS);
+	     ic4 =
+		FindItem("DESKTOP_DESKRAY_HORIZ", 0, LIST_FINDBY_NAME,
+			 LIST_TYPE_ICLASS);
 	  }
 
 	switch (desks.dragbar_ordering)
@@ -1272,51 +1246,58 @@ InitDesktopControls()
 
 	if (desks.dragbar_width > 0)
 	  {
-	     b = CreateButton("_DESKTOP_DRAG_CONTROL", ic2, ac2, NULL, NULL, -1,
-			      FLAG_FIXED, 1, 99999, 1, 99999, 0, 0, x[0], 0,
-			      y[0], 0, 0, w[0], 0, h[0], 0, i, 0);
+	     b =
+		CreateButton("_DESKTOP_DRAG_CONTROL", ic2, ac2, NULL, NULL, -1,
+			     FLAG_FIXED, 1, 99999, 1, 99999, 0, 0, x[0], 0,
+			     y[0], 0, 0, w[0], 0, h[0], 0, i, 0);
 	     AddItem(b, b->name, 1, LIST_TYPE_BUTTON);
-	     b = CreateButton("_DESKTOP_DRAG_CONTROL", ic3, ac3, NULL, NULL, -1,
-			      FLAG_FIXED, 1, 99999, 1, 99999, 0, 0, x[1], 0,
-			      y[1], 0, 0, w[1], 0, h[1], 0, i, 0);
+	     b =
+		CreateButton("_DESKTOP_DRAG_CONTROL", ic3, ac3, NULL, NULL, -1,
+			     FLAG_FIXED, 1, 99999, 1, 99999, 0, 0, x[1], 0,
+			     y[1], 0, 0, w[1], 0, h[1], 0, i, 0);
 	     AddItem(b, b->name, 1, LIST_TYPE_BUTTON);
-	     b = CreateButton("_DESKTOP_DRAG_CONTROL", ic, ac, NULL, NULL, -1,
-			      FLAG_FIXED, 1, 99999, 1, 99999, 0, 0, x[2],
-			      0, y[2], 0, 0, w[2], 0, h[2], 0, i, 0);
+	     b =
+		CreateButton("_DESKTOP_DRAG_CONTROL", ic, ac, NULL, NULL, -1,
+			     FLAG_FIXED, 1, 99999, 1, 99999, 0, 0, x[2], 0,
+			     y[2], 0, 0, w[2], 0, h[2], 0, i, 0);
 	     AddItem(b, b->name, 1, LIST_TYPE_BUTTON);
 	  }
 	if (i > 0)
 	  {
 	     if (desks.dragdir == 0)
 	       {
-		  b = CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
-				   NULL, NULL, 1, FLAG_FIXED_VERT, 1, 99999, 1,
-				   99999, 0, 0, desks.desk[i].x, 0,
-				   desks.desk[i].y, 0, 0, 0, 0, 0, 1, 0, 1);
+		  b =
+		     CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
+				  NULL, NULL, 1, FLAG_FIXED_VERT, 1, 99999, 1,
+				  99999, 0, 0, desks.desk[i].x, 0,
+				  desks.desk[i].y, 0, 0, 0, 0, 0, 1, 0, 1);
 	       }
 	     else if (desks.dragdir == 1)
 	       {
-		  b = CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
-				   NULL, NULL, 1, FLAG_FIXED_VERT, 1,
-				   99999, 1, 99999, 0, 0,
-				   desks.desk[i].x + root.w
-				   - desks.dragbar_width,
-				   0, desks.desk[i].y, 0, 0, 0, 0, 0, 1, 0, 1);
+		  b =
+		     CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
+				  NULL, NULL, 1, FLAG_FIXED_VERT, 1, 99999, 1,
+				  99999, 0, 0,
+				  desks.desk[i].x + root.w -
+				  desks.dragbar_width, 0, desks.desk[i].y, 0, 0,
+				  0, 0, 0, 1, 0, 1);
 	       }
 	     else if (desks.dragdir == 2)
 	       {
-		  b = CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
-				   NULL, NULL, 1, FLAG_FIXED_HORIZ, 1, 99999, 1,
-				   99999, 0, 0, desks.desk[i].x, 0,
-				   desks.desk[i].y, 0, 0, 0, 0, 0, 1, 0, 1);
+		  b =
+		     CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
+				  NULL, NULL, 1, FLAG_FIXED_HORIZ, 1, 99999, 1,
+				  99999, 0, 0, desks.desk[i].x, 0,
+				  desks.desk[i].y, 0, 0, 0, 0, 0, 1, 0, 1);
 	       }
 	     else
 	       {
-		  b = CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
-				   NULL, NULL, 1, FLAG_FIXED_HORIZ, 1, 99999, 1,
-				   99999, 0, 0, desks.desk[i].x, 0,
-				   desks.desk[i].y + root.h -
-				   desks.dragbar_width, 0, 0, 0, 0, 0, 1, 0, 1);
+		  b =
+		     CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
+				  NULL, NULL, 1, FLAG_FIXED_HORIZ, 1, 99999, 1,
+				  99999, 0, 0, desks.desk[i].x, 0,
+				  desks.desk[i].y + root.h -
+				  desks.dragbar_width, 0, 0, 0, 0, 0, 1, 0, 1);
 	       }
 	     AddItem(b, b->name, 2, LIST_TYPE_BUTTON);
 	     desks.desk[i].tag = b;
@@ -1375,8 +1356,8 @@ ConformEwinToDesktop(EWin * ewin)
      {
 	ewin->parent = desks.desk[ewin->desktop].win;
 	DesktopAddEwinToTop(ewin);
-	EReparentWindow(disp, ewin->win, desks.desk[ewin->desktop].win,
-			ewin->x, ewin->y);
+	EReparentWindow(disp, ewin->win, desks.desk[ewin->desktop].win, ewin->x,
+			ewin->y);
 	ICCCM_Configure(ewin);
 	StackDesktops();
 	GNOME_SetEwinDesk(ewin);
@@ -1403,8 +1384,8 @@ ConformEwinToDesktop(EWin * ewin)
      {
 	ewin->parent = desks.desk[ewin->desktop].win;
 	DesktopAddEwinToTop(ewin);
-	EReparentWindow(disp, ewin->win, desks.desk[ewin->desktop].win,
-			ewin->x, ewin->y);
+	EReparentWindow(disp, ewin->win, desks.desk[ewin->desktop].win, ewin->x,
+			ewin->y);
 	RaiseEwin(ewin);
 /*      ShowEwin(ewin); */
 	ICCCM_Configure(ewin);
@@ -1425,10 +1406,10 @@ DesktopAt(int x, int y)
 
    for (i = 0; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; i++)
      {
-	if ((x >= desks.desk[deskorder[i]].x) &&
-	    (x < (desks.desk[deskorder[i]].x + root.w)) &&
-	    (y >= desks.desk[deskorder[i]].y) &&
-	    (y < (desks.desk[deskorder[i]].y + root.h)))
+	if ((x >= desks.desk[deskorder[i]].x)
+	    && (x < (desks.desk[deskorder[i]].x + root.w))
+	    && (y >= desks.desk[deskorder[i]].y)
+	    && (y < (desks.desk[deskorder[i]].y + root.h)))
 	   EDBUG_RETURN(deskorder[i]);
      }
 
@@ -1504,8 +1485,8 @@ GotoDesktop(int num)
 	}
    }
 
-   if ((mode.mode == MODE_RESIZE) ||
-       (mode.mode == MODE_RESIZE_H) || (mode.mode == MODE_RESIZE_V))
+   if ((mode.mode == MODE_RESIZE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V))
      {
 	doResizeEnd(NULL);
      }
@@ -1521,15 +1502,14 @@ GotoDesktop(int num)
 		  mode.ewin->y = -99999;
 		  mode.ewin->reqx = -99999;
 		  mode.ewin->reqy = -99999;
-		  DrawEwinShape(mode.ewin, mode.movemode,
-				x, y,
+		  DrawEwinShape(mode.ewin, mode.movemode, x, y,
 				mode.ewin->client.w, mode.ewin->client.h, 3);
 	       }
 	  }
 	else
 	  {
-	     FloatEwinAt(mode.ewin, mode.ewin->x +
-			 desks.desk[mode.ewin->desktop].x,
+	     FloatEwinAt(mode.ewin,
+			 mode.ewin->x + desks.desk[mode.ewin->desktop].x,
 			 mode.ewin->y + desks.desk[mode.ewin->desktop].y);
 	  }
      }
@@ -1556,26 +1536,26 @@ GotoDesktop(int num)
 		    case 0:
 		       MoveDesktop(num, root.w, 0);
 		       RaiseDesktop(num);
-		       SlideWindowTo(desks.desk[num].win, root.w,
-				     0, 0, 0, desks.slidespeed);
+		       SlideWindowTo(desks.desk[num].win, root.w, 0, 0, 0,
+				     desks.slidespeed);
 		       break;
 		    case 1:
 		       MoveDesktop(num, -root.w, 0);
 		       RaiseDesktop(num);
-		       SlideWindowTo(desks.desk[num].win, -root.w,
-				     0, 0, 0, desks.slidespeed);
+		       SlideWindowTo(desks.desk[num].win, -root.w, 0, 0, 0,
+				     desks.slidespeed);
 		       break;
 		    case 2:
 		       MoveDesktop(num, 0, root.h);
 		       RaiseDesktop(num);
-		       SlideWindowTo(desks.desk[num].win, 0,
-				     root.h, 0, 0, desks.slidespeed);
+		       SlideWindowTo(desks.desk[num].win, 0, root.h, 0, 0,
+				     desks.slidespeed);
 		       break;
 		    case 3:
 		       MoveDesktop(num, 0, -root.h);
 		       RaiseDesktop(num);
-		       SlideWindowTo(desks.desk[num].win, 0,
-				     -root.h, 0, 0, desks.slidespeed);
+		       SlideWindowTo(desks.desk[num].win, 0, -root.h, 0, 0,
+				     desks.slidespeed);
 		       break;
 		    default:
 		       break;
@@ -1716,8 +1696,8 @@ MoveDesktop(int num, int x, int y)
 		       desks.desk[deskorder[i]].viewable = v;
 		    }
 
-		  if ((desks.desk[deskorder[i]].x == 0) &&
-		      (desks.desk[deskorder[i]].y == 0))
+		  if ((desks.desk[deskorder[i]].x == 0)
+		      && (desks.desk[deskorder[i]].y == 0))
 		    {
 		       v = 0;
 		    }
@@ -1729,8 +1709,7 @@ MoveDesktop(int num, int x, int y)
 
    if (desks.desk[num].tag)
      {
-	MovebuttonToCoord(desks.desk[num].tag,
-			  desks.desk[num].tag->x + dx,
+	MovebuttonToCoord(desks.desk[num].tag, desks.desk[num].tag->x + dx,
 			  desks.desk[num].tag->y + dy);
      }
    desks.desk[num].x = x;
@@ -1944,8 +1923,8 @@ StackDesktops()
      {
 	for (i = 0; i < bnum; i++)
 	  {
-	     if ((blst[i]->desktop == 0) && (blst[i]->ontop == 1) &&
-		 (!blst[i]->sticky))
+	     if ((blst[i]->desktop == 0) && (blst[i]->ontop == 1)
+		 && (!blst[i]->sticky))
 	       {
 		  tot++;
 		  wl = Erealloc(wl, tot * sizeof(Window));
@@ -1963,8 +1942,8 @@ StackDesktops()
      {
 	for (i = 0; i < bnum; i++)
 	  {
-	     if ((blst[i]->desktop == 0) && (blst[i]->ontop == -1) &&
-		 (!blst[i]->sticky))
+	     if ((blst[i]->desktop == 0) && (blst[i]->ontop == -1)
+		 && (!blst[i]->sticky))
 	       {
 		  tot++;
 		  wl = Erealloc(wl, tot * sizeof(Window));
@@ -2080,8 +2059,8 @@ DesktopAddEwinToTop(EWin * ewin)
    int                 i, j;
 
    EDBUG(5, "DesktopAddEwinToTop");
-   if ((ewin->desktop < 0) ||
-       (ewin->desktop > ENLIGHTENMENT_CONF_NUM_DESKTOPS - 1))
+   if ((ewin->desktop < 0)
+       || (ewin->desktop > ENLIGHTENMENT_CONF_NUM_DESKTOPS - 1))
       EDBUG_RETURN_;
 
    DesktopRemoveEwin(ewin);
@@ -2121,8 +2100,8 @@ DesktopAddEwinToBottom(EWin * ewin)
    int                 i, j;
 
    EDBUG(5, "DesktopAddEwinToBottom");
-   if ((ewin->desktop < 0) ||
-       (ewin->desktop > ENLIGHTENMENT_CONF_NUM_DESKTOPS - 1))
+   if ((ewin->desktop < 0)
+       || (ewin->desktop > ENLIGHTENMENT_CONF_NUM_DESKTOPS - 1))
       EDBUG_RETURN_;
 
    DesktopRemoveEwin(ewin);
