@@ -343,8 +343,8 @@ DialogSetTitle(Dialog * d, char *title)
 }
 
 void
-DialogSetExitFunction(Dialog * d, void (*func) (int val, void *data),
-		      int val, void *data)
+DialogSetExitFunction(Dialog * d, void (*func) (int val, void *data), int val,
+		      void *data)
 {
    d->exit_func = func;
    d->exit_val = val;
@@ -374,8 +374,8 @@ DialogAddButton(Dialog * d, char *text, void (*func) (int val, void *data),
    db->clicked = 0;
    db->close = close;
 
-   db->tclass = FindItem("DIALOG_BUTTON", 0,
-			 LIST_FINDBY_NAME, LIST_TYPE_TCLASS);
+   db->tclass =
+      FindItem("DIALOG_BUTTON", 0, LIST_FINDBY_NAME, LIST_TYPE_TCLASS);
    if (!db->tclass)
      {
 	DialogRealizeTClassDefault();
@@ -384,8 +384,8 @@ DialogAddButton(Dialog * d, char *text, void (*func) (int val, void *data),
    if (db->tclass)
       db->tclass->ref_count++;
 
-   db->iclass = FindItem("DIALOG_BUTTON", 0,
-			 LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+   db->iclass =
+      FindItem("DIALOG_BUTTON", 0, LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
    if (!db->iclass)
      {
 	DialogRealizeTClassDefault();
@@ -397,8 +397,9 @@ DialogAddButton(Dialog * d, char *text, void (*func) (int val, void *data),
    TextSize(db->tclass, 0, 0, STATE_NORMAL, text, &w, &h, 17);
    db->w = w + db->iclass->padding.left + db->iclass->padding.right;
    db->h = h + db->iclass->padding.top + db->iclass->padding.bottom;
-   XSelectInput(disp, db->win, EnterWindowMask | LeaveWindowMask |
-		ButtonPressMask | ButtonReleaseMask | ExposureMask);
+   XSelectInput(disp, db->win,
+		EnterWindowMask | LeaveWindowMask | ButtonPressMask |
+		ButtonReleaseMask | ExposureMask);
 }
 
 void
@@ -422,8 +423,8 @@ DialogDrawButton(Dialog * d, int bnum)
    IclassApply(d->button[bnum]->iclass, d->button[bnum]->win,
 	       d->button[bnum]->w, d->button[bnum]->h, 0, 0, state, 0);
    TclassApply(d->button[bnum]->iclass, d->button[bnum]->win,
-	       d->button[bnum]->w, d->button[bnum]->h,
-	       0, 0, state, 1, d->button[bnum]->tclass, d->button[bnum]->text);
+	       d->button[bnum]->w, d->button[bnum]->h, 0, 0, state, 1,
+	       d->button[bnum]->tclass, d->button[bnum]->text);
 }
 
 void
@@ -436,8 +437,8 @@ DialogActivateButton(Window win, int inclick)
    d = FindDialogButton(win, &bnum);
    if (!d)
       return;
-   if ((d->button[bnum]->hilited) && (d->button[bnum]->clicked) &&
-       (inclick == 3))
+   if ((d->button[bnum]->hilited) && (d->button[bnum]->clicked)
+       && (inclick == 3))
       doact = 1;
    if (inclick == 0)
       d->button[bnum]->hilited = 1;
@@ -462,8 +463,8 @@ DialogDraw(Dialog * d)
 
    if (d->text)
      {
-	TclassApply(d->iclass, d->win, d->w, d->h,
-		    0, 0, STATE_NORMAL, 1, d->tclass, d->text);
+	TclassApply(d->iclass, d->win, d->w, d->h, 0, 0, STATE_NORMAL, 1,
+		    d->tclass, d->text);
      }
    else if (d->item)
      {
@@ -479,8 +480,8 @@ DialogDrawArea(Dialog * d, int x, int y, int w, int h)
 
    if (d->text)
      {
-	TclassApply(d->iclass, d->win, d->w, d->h,
-		    0, 0, STATE_NORMAL, 1, d->tclass, d->text);
+	TclassApply(d->iclass, d->win, d->w, d->h, 0, 0, STATE_NORMAL, 1,
+		    d->tclass, d->text);
      }
    else if (d->item)
      {
@@ -549,30 +550,32 @@ ShowDialog(Dialog * d)
      }
    h += d->iclass->padding.top + d->iclass->padding.bottom + mh;
 
-   if ((d->iclass->padding.left + d->iclass->padding.right +
-	(d->num_buttons * (mw + d->iclass->padding.left +
-			   d->iclass->padding.right))) > w)
-      w = d->iclass->padding.left + d->iclass->padding.right +
-	 (d->num_buttons * (mw + d->iclass->padding.left +
-			    d->iclass->padding.right));
+   if (
+       (d->iclass->padding.left + d->iclass->padding.right +
+	(d->num_buttons *
+	 (mw + d->iclass->padding.left + d->iclass->padding.right))) > w)
+      w =
+	 d->iclass->padding.left + d->iclass->padding.right +
+	 (d->num_buttons *
+	  (mw + d->iclass->padding.left + d->iclass->padding.right));
 
    for (i = 0; i < d->num_buttons; i++)
      {
 	d->button[i]->x =
-	   (((w - (d->iclass->padding.left + d->iclass->padding.right)) -
-	     (d->num_buttons * (mw + d->iclass->padding.left +
-				d->iclass->padding.right))) / 2) +
-	   d->iclass->padding.left +
+	   (((w
+	      - (d->iclass->padding.left + d->iclass->padding.right)) -
+	     (d->num_buttons *
+	      (mw + d->iclass->padding.left +
+	       d->iclass->padding.right))) / 2) + d->iclass->padding.left +
 	   (i * (mw + d->iclass->padding.left + d->iclass->padding.right)) +
 	   d->iclass->padding.left;
-	d->button[i]->y = d->h - d->iclass->padding.bottom +
-	   d->iclass->padding.top;
+	d->button[i]->y =
+	   d->h - d->iclass->padding.bottom + d->iclass->padding.top;
 
 	d->button[i]->w = mw;
 	d->button[i]->h = mh;
-	EMoveResizeWindow(disp, d->button[i]->win,
-			  d->button[i]->x, d->button[i]->y,
-			  d->button[i]->w, d->button[i]->h);
+	EMoveResizeWindow(disp, d->button[i]->win, d->button[i]->x,
+			  d->button[i]->y, d->button[i]->w, d->button[i]->h);
      }
    d->w = w;
    d->h = d->h - d->iclass->padding.bottom;
@@ -582,14 +585,14 @@ ShowDialog(Dialog * d)
    IclassApply(d->iclass, d->win, w, h, 0, 0, STATE_NORMAL, 0);
 
    for (i = 0; i < d->num_buttons; i++)
-      IclassApply(d->button[i]->iclass, d->button[i]->win,
-		  d->button[i]->w, d->button[i]->h, 0, 0, STATE_NORMAL, 0);
+      IclassApply(d->button[i]->iclass, d->button[i]->win, d->button[i]->w,
+		  d->button[i]->h, 0, 0, STATE_NORMAL, 0);
    queue_up = pq;
 
    ewin = AddInternalToFamily(d->win, 1, NULL, 0, d);
-   XSelectInput(disp, d->win, ExposureMask | PointerMotionMask |
-		EnterWindowMask | LeaveWindowMask |
-		FocusChangeMask | KeyPressMask);
+   XSelectInput(disp, d->win,
+		ExposureMask | PointerMotionMask | EnterWindowMask |
+		LeaveWindowMask | FocusChangeMask | KeyPressMask);
    if (ewin)
      {
 	DesktopRemoveEwin(ewin);
@@ -896,6 +899,7 @@ DialogAddItem(DItem * dii, int type)
 	di->item.radio_button.first = NULL;
 	di->item.radio_button.radio_orig_w = 10;
 	di->item.radio_button.radio_orig_h = 10;
+	di->item.radio_button.event_func = NULL;
 	break;
      case DITEM_SLIDER:
 	di->item.slider.horizontal = 1;
@@ -946,17 +950,17 @@ DialogAddItem(DItem * dii, int type)
    if (dii)
      {
 	dii->item.table.num_items++;
-	dii->item.table.items = Erealloc(dii->item.table.items,
-					 sizeof(DItem *) *
-					 dii->item.table.num_items);
+	dii->item.table.items =
+	   Erealloc(dii->item.table.items,
+		    sizeof(DItem *) * dii->item.table.num_items);
 	dii->item.table.items[dii->item.table.num_items - 1] = di;
      }
    return di;
 }
 
 void
-DialogItemSetCallback(DItem * di, void (*func) (int val, void *data),
-		      int val, char *data)
+DialogItemSetCallback(DItem * di, void (*func) (int val, void *data), int val,
+		      char *data)
 {
    di->func = func;
    di->val = val;
@@ -1090,8 +1094,9 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	  {
 	     di->win = ECreateWindow(d->win, -20, -20, 2, 2, 0);
 	     EMapWindow(disp, di->win);
-	     XSelectInput(disp, di->win, EnterWindowMask | LeaveWindowMask |
-			  ButtonPressMask | ButtonReleaseMask);
+	     XSelectInput(disp, di->win,
+			  EnterWindowMask | LeaveWindowMask | ButtonPressMask |
+			  ButtonReleaseMask);
 	  }
 	di->item.slider.base_win = ECreateWindow(d->win, -20, -20, 2, 2, 0);
 	EMapWindow(disp, di->item.slider.base_win);
@@ -1194,15 +1199,15 @@ DialogRealizeItem(Dialog * d, DItem * di)
 		  ImlibImage         *im;
 
 		  im =
-		     ELoadImage(di->item.slider.ic_border->norm.normal->
-				im_file);
+		     ELoadImage(di->item.slider.ic_border->norm.
+				normal->im_file);
 		  if (im)
 		    {
 		       di->item.slider.border_orig_w = im->rgb_width;
 		       di->item.slider.border_orig_h = im->rgb_height;
 		       Imlib_destroy_image(id, im);
-		       di->item.slider.border_win = ECreateWindow(d->win, -20,
-								  -20, 2, 2, 0);
+		       di->item.slider.border_win =
+			  ECreateWindow(d->win, -20, -20, 2, 2, 0);
 		       EMapWindow(disp, di->item.slider.border_win);
 		    }
 	       }
@@ -1210,7 +1215,8 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	  }
 	if (di->item.slider.horizontal)
 	  {
-	     iw = di->item.slider.min_length +
+	     iw =
+		di->item.slider.min_length +
 		di->item.slider.ic_base->padding.left +
 		di->item.slider.ic_base->padding.right;
 	     ih = di->item.slider.base_orig_h;
@@ -1218,7 +1224,8 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	else
 	  {
 	     iw = di->item.slider.base_orig_w;
-	     ih = di->item.slider.min_length +
+	     ih =
+		di->item.slider.min_length +
 		di->item.slider.ic_base->padding.top +
 		di->item.slider.ic_base->padding.bottom;
 	  }
@@ -1226,14 +1233,15 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	di->h = ih;
 	break;
      case DITEM_BUTTON:
-	TextSize(di->tclass, 0, 0, STATE_NORMAL, di->item.button.text,
-		 &iw, &ih, 17);
+	TextSize(di->tclass, 0, 0, STATE_NORMAL, di->item.button.text, &iw, &ih,
+		 17);
 	iw += di->iclass->padding.left + di->iclass->padding.right;
 	ih += di->iclass->padding.top + di->iclass->padding.bottom;
 	di->win = ECreateWindow(d->win, -20, -20, 2, 2, 0);
 	EMapWindow(disp, di->win);
-	XSelectInput(disp, di->win, EnterWindowMask | LeaveWindowMask |
-		     ButtonPressMask | ButtonReleaseMask | ExposureMask);
+	XSelectInput(disp, di->win,
+		     EnterWindowMask | LeaveWindowMask | ButtonPressMask |
+		     ButtonReleaseMask | ExposureMask);
 	di->w = iw;
 	di->h = ih;
 	break;
@@ -1247,9 +1255,9 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	XSelectInput(disp, di->win, ExposureMask);
 	di->item.area.area_win = ECreateWindow(di->win, -20, -20, 2, 2, 0);
 	EMapWindow(disp, di->item.area.area_win);
-	XSelectInput(disp, di->item.area.area_win, EnterWindowMask |
-		     LeaveWindowMask | ButtonPressMask | ButtonReleaseMask |
-		     ExposureMask | PointerMotionMask);
+	XSelectInput(disp, di->item.area.area_win,
+		     EnterWindowMask | LeaveWindowMask | ButtonPressMask |
+		     ButtonReleaseMask | ExposureMask | PointerMotionMask);
 	di->w = iw;
 	di->h = ih;
 	break;
@@ -1271,19 +1279,20 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	if (ih < di->item.check_button.check_orig_h)
 	   ih = di->item.check_button.check_orig_h;
 	iw += di->item.check_button.check_orig_w + di->iclass->padding.left;
-	di->item.check_button.check_win = ECreateWindow(d->win, -20, -20,
-							2, 2, 0);
+	di->item.check_button.check_win =
+	   ECreateWindow(d->win, -20, -20, 2, 2, 0);
 	di->win = ECreateEventWindow(d->win, -20, -20, 2, 2);
 	EMapWindow(disp, di->item.check_button.check_win);
 	EMapWindow(disp, di->win);
-	XSelectInput(disp, di->win, EnterWindowMask | LeaveWindowMask |
-		     ButtonPressMask | ButtonReleaseMask | ExposureMask);
+	XSelectInput(disp, di->win,
+		     EnterWindowMask | LeaveWindowMask | ButtonPressMask |
+		     ButtonReleaseMask | ExposureMask);
 	di->w = iw;
 	di->h = ih;
 	break;
      case DITEM_TEXT:
-	TextSize(di->tclass, 0, 0, STATE_NORMAL, di->item.text.text,
-		 &iw, &ih, 17);
+	TextSize(di->tclass, 0, 0, STATE_NORMAL, di->item.text.text, &iw, &ih,
+		 17);
 	di->w = iw;
 	di->h = ih;
 	break;
@@ -1331,13 +1340,14 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	if (ih < di->item.radio_button.radio_orig_h)
 	   ih = di->item.radio_button.radio_orig_h;
 	iw += di->item.radio_button.radio_orig_w + di->iclass->padding.left;
-	di->item.radio_button.radio_win = ECreateWindow(d->win, -20, -20,
-							2, 2, 0);
+	di->item.radio_button.radio_win =
+	   ECreateWindow(d->win, -20, -20, 2, 2, 0);
 	di->win = ECreateEventWindow(d->win, -20, -20, 2, 2);
 	EMapWindow(disp, di->item.radio_button.radio_win);
 	EMapWindow(disp, di->win);
-	XSelectInput(disp, di->win, EnterWindowMask | LeaveWindowMask |
-		     ButtonPressMask | ButtonReleaseMask | ExposureMask);
+	XSelectInput(disp, di->win,
+		     EnterWindowMask | LeaveWindowMask | ButtonPressMask |
+		     ButtonReleaseMask | ExposureMask);
 	di->w = iw;
 	di->h = ih;
 	break;
@@ -1349,8 +1359,8 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	   rows = 1;
 	   if ((cols > 0) && (rows > 0))
 	     {
-		int                 i, *col_size, *row_size = NULL, r = 0,
-		   c = 0, x = 0, y = 0;
+		int                 i, *col_size, *row_size = NULL, r = 0, c =
+		   0, x = 0, y = 0;
 
 		col_size = Emalloc(sizeof(int) * cols);
 		row_size = Erealloc(row_size, sizeof(int));
@@ -1436,15 +1446,17 @@ DialogRealizeItem(Dialog * d, DItem * di)
 		       {
 			  int                 dx, dy, newx, newy;
 
-			  newx = di->x + x + d->iclass->padding.left +
+			  newx =
+			     di->x + x + d->iclass->padding.left +
 			     dii->padding.left +
-			     (((sw - (dii->padding.left
-				      + dii->padding.right) -
+			     (((sw
+				- (dii->padding.left + dii->padding.right) -
 				dii->w) * dii->align_h) >> 10);
-			  newy = di->y + y + d->iclass->padding.top +
+			  newy =
+			     di->y + y + d->iclass->padding.top +
 			     dii->padding.top +
-			     (((sh - (dii->padding.top
-				      + dii->padding.bottom) -
+			     (((sh
+				- (dii->padding.top + dii->padding.bottom) -
 				dii->h) * dii->align_v) >> 10);
 			  dx = newx - dii->x - d->iclass->padding.left;
 			  dy = newy - dii->y - d->iclass->padding.top;
@@ -1452,18 +1464,21 @@ DialogRealizeItem(Dialog * d, DItem * di)
 		       }
 		     else
 		       {
-			  dii->x = di->x + x + d->iclass->padding.left +
+			  dii->x =
+			     di->x + x + d->iclass->padding.left +
 			     dii->padding.left +
-			     (((sw - (dii->padding.left
-				      + dii->padding.right) -
+			     (((sw
+				- (dii->padding.left + dii->padding.right) -
 				dii->w) * dii->align_h) >> 10);
-			  dii->y = di->y + y + d->iclass->padding.top +
+			  dii->y =
+			     di->y + y + d->iclass->padding.top +
 			     dii->padding.top +
-			     (((sh - (dii->padding.top + dii->padding.bottom)
-				- dii->h) * dii->align_v) >> 10);
+			     (((sh
+				- (dii->padding.top + dii->padding.bottom) -
+				dii->h) * dii->align_v) >> 10);
 			  if (dii->win)
-			     EMoveResizeWindow(disp, dii->win, dii->x,
-					       dii->y, dii->w, dii->h);
+			     EMoveResizeWindow(disp, dii->win, dii->x, dii->y,
+					       dii->w, dii->h);
 			  if (dii->type == DITEM_CHECKBUTTON)
 			     EMoveResizeWindow(disp,
 					       dii->item.check_button.check_win,
@@ -1471,12 +1486,13 @@ DialogRealizeItem(Dialog * d, DItem * di)
 					       dii->y +
 					       ((dii->h
 						 -
-						 dii->item.check_button.
-						 check_orig_h) / 2),
-					       dii->item.check_button.
-					       check_orig_w,
-					       dii->item.check_button.
-					       check_orig_h);
+						 dii->item.
+						 check_button.check_orig_h) /
+						2),
+					       dii->item.
+					       check_button.check_orig_w,
+					       dii->item.
+					       check_button.check_orig_h);
 			  if (dii->type == DITEM_RADIOBUTTON)
 			     EMoveResizeWindow(disp,
 					       dii->item.radio_button.radio_win,
@@ -1484,20 +1500,21 @@ DialogRealizeItem(Dialog * d, DItem * di)
 					       dii->y +
 					       ((dii->h
 						 -
-						 dii->item.radio_button.
-						 radio_orig_h) / 2),
-					       dii->item.radio_button.
-					       radio_orig_w,
-					       dii->item.radio_button.
-					       radio_orig_h);
+						 dii->item.
+						 radio_button.radio_orig_h) /
+						2),
+					       dii->item.
+					       radio_button.radio_orig_w,
+					       dii->item.
+					       radio_button.radio_orig_h);
 			  if (dii->type == DITEM_AREA)
 			    {
-			       dii->item.area.w = dii->w -
-				  (dii->iclass->padding.left +
-				   dii->iclass->padding.right);
-			       dii->item.area.h = dii->h -
-				  (dii->iclass->padding.top +
-				   dii->iclass->padding.bottom);
+			       dii->item.area.w =
+				  dii->w - (dii->iclass->padding.left +
+					    dii->iclass->padding.right);
+			       dii->item.area.h =
+				  dii->h - (dii->iclass->padding.top +
+					    dii->iclass->padding.bottom);
 			       EMoveResizeWindow(disp, dii->item.area.area_win,
 						 dii->iclass->padding.left,
 						 dii->iclass->padding.top,
@@ -1590,12 +1607,12 @@ MoveTableBy(Dialog * d, DItem * di, int dx, int dy)
 	if (dii->win)
 	   EMoveWindow(disp, dii->win, dii->x, dii->y);
 	if (dii->type == DITEM_CHECKBUTTON)
-	   EMoveWindow(disp, dii->item.check_button.check_win,
-		       dii->x, dii->y +
+	   EMoveWindow(disp, dii->item.check_button.check_win, dii->x,
+		       dii->y +
 		       ((dii->h - dii->item.check_button.check_orig_h) / 2));
 	if (dii->type == DITEM_RADIOBUTTON)
-	   EMoveWindow(disp, dii->item.radio_button.radio_win,
-		       dii->x, dii->y +
+	   EMoveWindow(disp, dii->item.radio_button.radio_win, dii->x,
+		       dii->y +
 		       ((dii->h - dii->item.radio_button.radio_orig_h) / 2));
 	if (dii->type == DITEM_SLIDER)
 	  {
@@ -1681,22 +1698,27 @@ DialogDrawItems(Dialog * d, DItem * di, int x, int y, int w, int h)
 	  case DITEM_SLIDER:
 	     if (di->item.slider.horizontal)
 	       {
-		  di->item.slider.knob_x = di->item.slider.base_x +
-		     (((di->item.slider.base_w - di->item.slider.knob_w) *
-		       (di->item.slider.val - di->item.slider.lower)) /
+		  di->item.slider.knob_x =
+		     di->item.slider.base_x +
+		     (((di->item.slider.base_w -
+			di->item.slider.knob_w) * (di->item.slider.val -
+						   di->item.slider.lower)) /
 		      (di->item.slider.upper - di->item.slider.lower));
-		  di->item.slider.knob_y = di->item.slider.base_y +
+		  di->item.slider.knob_y =
+		     di->item.slider.base_y +
 		     ((di->item.slider.base_h - di->item.slider.knob_h) / 2);
 	       }
 	     else
 	       {
-		  di->item.slider.knob_y = (di->item.slider.base_y +
-					    di->item.slider.base_h -
-					    di->item.slider.knob_h) -
-		     (((di->item.slider.base_h - di->item.slider.knob_h) *
-		       (di->item.slider.val - di->item.slider.lower)) /
+		  di->item.slider.knob_y =
+		     (di->item.slider.base_y + di->item.slider.base_h -
+		      di->item.slider.knob_h) -
+		     (((di->item.slider.base_h -
+			di->item.slider.knob_h) * (di->item.slider.val -
+						   di->item.slider.lower)) /
 		      (di->item.slider.upper - di->item.slider.lower));
-		  di->item.slider.knob_x = di->item.slider.base_x +
+		  di->item.slider.knob_x =
+		     di->item.slider.base_x +
 		     ((di->item.slider.base_w - di->item.slider.knob_w) / 2);
 	       }
 	     if (di->item.slider.knob_win)
@@ -1706,15 +1728,14 @@ DialogDrawItems(Dialog * d, DItem * di, int x, int y, int w, int h)
 				  di->item.slider.knob_w,
 				  di->item.slider.knob_h);
 	     if (di->item.slider.base_win)
-		IclassApply(di->item.slider.ic_base,
-			    di->item.slider.base_win,
-			    di->item.slider.base_w, di->item.slider.base_h,
-			    0, 0, STATE_NORMAL, 0);
+		IclassApply(di->item.slider.ic_base, di->item.slider.base_win,
+			    di->item.slider.base_w, di->item.slider.base_h, 0,
+			    0, STATE_NORMAL, 0);
 	     if (di->item.slider.border_win)
 		IclassApply(di->item.slider.ic_border,
 			    di->item.slider.border_win,
-			    di->item.slider.border_w,
-			    di->item.slider.border_h, 0, 0, STATE_NORMAL, 0);
+			    di->item.slider.border_w, di->item.slider.border_h,
+			    0, 0, STATE_NORMAL, 0);
 	     state = STATE_NORMAL;
 	     if ((di->hilited) && (di->clicked))
 		state = STATE_CLICKED;
@@ -1723,10 +1744,9 @@ DialogDrawItems(Dialog * d, DItem * di, int x, int y, int w, int h)
 	     else if (!(di->hilited) && (di->clicked))
 		state = STATE_CLICKED;
 	     if (di->item.slider.knob_win)
-		IclassApply(di->item.slider.ic_knob,
-			    di->item.slider.knob_win,
-			    di->item.slider.knob_w, di->item.slider.knob_h,
-			    0, 0, state, 0);
+		IclassApply(di->item.slider.ic_knob, di->item.slider.knob_win,
+			    di->item.slider.knob_w, di->item.slider.knob_h, 0,
+			    0, state, 0);
 	     break;
 	  case DITEM_BUTTON:
 	     state = STATE_NORMAL;
@@ -1741,8 +1761,8 @@ DialogDrawItems(Dialog * d, DItem * di, int x, int y, int w, int h)
 			 di->tclass, di->item.button.text);
 	     break;
 	  case DITEM_AREA:
-	     IclassApply(di->iclass, di->win, di->w, di->h,
-			 0, 0, STATE_NORMAL, 0);
+	     IclassApply(di->iclass, di->win, di->w, di->h, 0, 0, STATE_NORMAL,
+			 0);
 	     break;
 	  case DITEM_CHECKBUTTON:
 	     state = STATE_NORMAL;
@@ -1766,24 +1786,24 @@ DialogDrawItems(Dialog * d, DItem * di, int x, int y, int w, int h)
 		      di->x + di->item.check_button.check_orig_w +
 		      di->iclass->padding.left, di->y,
 		      di->w - di->item.check_button.check_orig_w -
-		      di->iclass->padding.left, 99999,
-		      17, di->tclass->justification);
+		      di->iclass->padding.left, 99999, 17,
+		      di->tclass->justification);
 	     break;
 	  case DITEM_TEXT:
 	     XClearArea(disp, d->win, di->x, di->y, di->w, di->h, False);
 	     TextDraw(di->tclass, d->win, 0, 0, STATE_NORMAL,
-		      di->item.text.text, di->x, di->y, di->w,
-		      99999, 17, di->tclass->justification);
+		      di->item.text.text, di->x, di->y, di->w, 99999, 17,
+		      di->tclass->justification);
 	     break;
 	  case DITEM_IMAGE:
 	     break;
 	  case DITEM_SEPARATOR:
 	     if (di->item.separator.horizontal)
-		IclassApply(di->iclass, di->win, di->w,
-			    di->h, 0, 0, STATE_NORMAL, 0);
+		IclassApply(di->iclass, di->win, di->w, di->h, 0, 0,
+			    STATE_NORMAL, 0);
 	     else
-		IclassApply(di->iclass, di->win, di->w,
-			    di->h, 0, 0, STATE_CLICKED, 0);
+		IclassApply(di->iclass, di->win, di->w, di->h, 0, 0,
+			    STATE_CLICKED, 0);
 	     break;
 	  case DITEM_RADIOBUTTON:
 	     state = STATE_NORMAL;
@@ -1807,8 +1827,8 @@ DialogDrawItems(Dialog * d, DItem * di, int x, int y, int w, int h)
 		      di->x + di->item.radio_button.radio_orig_w +
 		      di->iclass->padding.left, di->y,
 		      di->w - di->item.radio_button.radio_orig_w -
-		      di->iclass->padding.left, 99999,
-		      17, di->tclass->justification);
+		      di->iclass->padding.left, 99999, 17,
+		      di->tclass->justification);
 	     break;
 	  default:
 	     break;
@@ -1856,6 +1876,13 @@ DialogItemTextSetText(DItem * di, char *text)
    di->item.text.text = duplicate(text);
 }
 
+void
+DialogItemRadioButtonSetEventFunc(DItem * di,
+				  void (*func) (int val, void *data))
+{
+   di->item.radio_button.event_func = func;
+}
+
 void
 DialogItemRadioButtonSetText(DItem * di, char *text)
 {
@@ -1999,8 +2026,7 @@ DialogItemAreaSetSize(DItem * di, int w, int h)
    di->item.area.h = h;
 }
 
-Window
-DialogItemAreaGetWindow(DItem * di)
+Window DialogItemAreaGetWindow(DItem * di)
 {
    return di->item.area.area_win;
 }
@@ -2087,10 +2113,11 @@ DialogItemFindWindow(DItem * di, Window win)
 		return dii;
 	  }
      }
-   else if ((di->win == win) || ((di->type == DITEM_SLIDER) &&
-				 ((di->item.slider.base_win == win) ||
-				  (di->item.slider.knob_win == win))) ||
-	    ((di->type == DITEM_AREA) && (di->item.area.area_win == win)))
+   else if ((di->win == win)
+	    || ((di->type == DITEM_SLIDER)
+		&& ((di->item.slider.base_win == win)
+		    || (di->item.slider.knob_win == win)))
+	    || ((di->type == DITEM_AREA) && (di->item.area.area_win == win)))
      {
 	return di;
      }
