@@ -44,8 +44,9 @@ HandleDrawQueue()
    /* find all DRAW queue entries most recent first and add them to the */
    /* end of the draw list array if there are no previous entries for that */
    /* draw type and that window in the array */
-   while ((dq = (DrawQueue *) RemoveItem(NULL, 0, LIST_FINDBY_NONE,
-					 LIST_TYPE_DRAW)))
+   while (
+	  (dq =
+	   (DrawQueue *) RemoveItem(NULL, 0, LIST_FINDBY_NONE, LIST_TYPE_DRAW)))
      {
 	already = 0;
 	if (dq->shape_propagate)
@@ -205,23 +206,25 @@ HandleDrawQueue()
 	       }
 	     else if (lst[i]->pager)
 	       {
-		  if (FindItem((char *)(lst[i]->pager), 0,
-			       LIST_FINDBY_POINTER, LIST_TYPE_PAGER))
-		     PagerForceUpdate(lst[i]->pager);
+		  if (FindItem
+		      ((char *)(lst[i]->pager), 0, LIST_FINDBY_POINTER,
+		       LIST_TYPE_PAGER)) PagerForceUpdate(lst[i]->pager);
 /*            printf("P %x\n", lst[i]->win); */
 	       }
 	     else if (lst[i]->d)
 	       {
-		  if (FindItem((char *)(lst[i]->d), 0,
-			       LIST_FINDBY_POINTER, LIST_TYPE_DIALOG))
+		  if (FindItem
+		      ((char *)(lst[i]->d), 0, LIST_FINDBY_POINTER,
+		       LIST_TYPE_DIALOG))
 		     DialogDrawItems(lst[i]->d, lst[i]->di, lst[i]->x,
 				     lst[i]->y, lst[i]->w, lst[i]->h);
 /*            printf("D %x\n", lst[i]->d->ewin->client.win); */
 	       }
 	     else if (lst[i]->redraw_pager)
 	       {
-		  if (FindItem((char *)(lst[i]->redraw_pager), 0,
-			       LIST_FINDBY_POINTER, LIST_TYPE_PAGER))
+		  if (FindItem
+		      ((char *)(lst[i]->redraw_pager), 0, LIST_FINDBY_POINTER,
+		       LIST_TYPE_PAGER))
 		     PagerRedraw(lst[i]->redraw_pager, lst[i]->newbg);
 /*            printf("p %x\n", lst[i]->win); */
 	       }
@@ -300,16 +303,18 @@ ECreatePixImg(Window win, int w, int h)
 	Efree(pi);
 	return NULL;
      }
-   pi->xim = XShmCreateImage(disp, root.vis, root.depth, ZPixmap, NULL,
-			     pi->shminfo, w, h);
+   pi->xim =
+      XShmCreateImage(disp, root.vis, root.depth, ZPixmap, NULL, pi->shminfo,
+		      w, h);
    if (!pi->xim)
      {
 	Efree(pi->shminfo);
 	Efree(pi);
 	return NULL;
      }
-   pi->shminfo->shmid = shmget(IPC_PRIVATE, pi->xim->bytes_per_line *
-			       pi->xim->height, IPC_CREAT | 0666);
+   pi->shminfo->shmid =
+      shmget(IPC_PRIVATE, pi->xim->bytes_per_line * pi->xim->height,
+	     IPC_CREAT | 0666);
    if (pi->shminfo->shmid < 0)
      {
 	XDestroyImage(pi->xim);
@@ -328,8 +333,9 @@ ECreatePixImg(Window win, int w, int h)
      }
    pi->shminfo->readOnly = False;
    XShmAttach(disp, pi->shminfo);
-   pi->pmap = XShmCreatePixmap(disp, win, pi->shminfo->shmaddr, pi->shminfo,
-			       w, h, root.depth);
+   pi->pmap =
+      XShmCreatePixmap(disp, win, pi->shminfo->shmaddr, pi->shminfo, w, h,
+		       root.depth);
    if (!pi->pmap)
      {
 	XShmDetach(disp, pi->shminfo);
@@ -359,6 +365,8 @@ ECreatePixImg(Window win, int w, int h)
 void
 EDestroyPixImg(PixImg * pi)
 {
+   if (!pi)
+      return;
    XSync(disp, False);
    XShmDetach(disp, pi->shminfo);
    shmdt(pi->shminfo->shmaddr);
@@ -406,8 +414,8 @@ EBlendRemoveShape(EWin * ewin, Pixmap pmap, int x, int y)
 	   return;
 	else if (rn == 1)
 	  {
-	     if ((rl[0].x == 0) && (rl[0].y == 0) &&
-		 (rl[0].width == ewin->w) && (rl[0].height == ewin->h))
+	     if ((rl[0].x == 0) && (rl[0].y == 0) && (rl[0].width == ewin->w)
+		 && (rl[0].height == ewin->h))
 	       {
 		  if (rl)
 		     XFree(rl);
@@ -437,8 +445,8 @@ EBlendRemoveShape(EWin * ewin, Pixmap pmap, int x, int y)
 }
 
 void
-EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x,
-	     int y, int w, int h)
+EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x, int y,
+	     int w, int h)
 {
    int                 ox, oy;
    int                 i, j;
@@ -504,18 +512,22 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x,
 	       {
 		  unsigned int       *ptr1, *ptr2, *ptr3;
 
-		  ptr1 = (unsigned int *)
-		     (s1->xim->data +
-		      ((x) * ((s1->xim->bits_per_pixel) >> 3)) +
-		      ((j + y) * s1->xim->bytes_per_line));
-		  ptr2 = (unsigned int *)
-		     (s2->xim->data +
-		      ((ox) * ((s2->xim->bits_per_pixel) >> 3)) +
-		      ((j + oy) * s2->xim->bytes_per_line));
-		  ptr3 = (unsigned int *)
-		     (dst->xim->data +
-		      ((ox) * ((dst->xim->bits_per_pixel) >> 3)) +
-		      ((j + oy) * dst->xim->bytes_per_line));
+		  ptr1 =
+		     (unsigned int *)(s1->xim->data +
+				      ((x) * ((s1->xim->bits_per_pixel) >> 3)) +
+				      ((j + y) * s1->xim->bytes_per_line));
+		  ptr2 =
+		     (unsigned int *)(s2->xim->data +
+				      ((ox) *
+				       ((s2->xim->bits_per_pixel) >> 3)) + ((j +
+									     oy)
+									    *
+									    s2->xim->bytes_per_line));
+		  ptr3 =
+		     (unsigned int *)(dst->xim->data +
+				      ((ox) *
+				       ((dst->xim->bits_per_pixel) >> 3)) +
+				      ((j + oy) * dst->xim->bytes_per_line));
 		  for (i = 0; i < w; i++)
 		    {
 		       unsigned int        p1, p2;
@@ -551,18 +563,23 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x,
 		    {
 		       unsigned int       *ptr1, *ptr2, *ptr3;
 
-		       ptr1 = (unsigned int *)
-			  (s1->xim->data +
-			   ((x) * ((s1->xim->bits_per_pixel) >> 3)) +
-			   ((j + y) * s1->xim->bytes_per_line));
-		       ptr2 = (unsigned int *)
-			  (s2->xim->data +
-			   ((ox) * ((s2->xim->bits_per_pixel) >> 3)) +
-			   ((j + oy) * s2->xim->bytes_per_line));
-		       ptr3 = (unsigned int *)
-			  (dst->xim->data +
-			   ((ox) * ((dst->xim->bits_per_pixel) >> 3)) +
-			   ((j + oy) * dst->xim->bytes_per_line));
+		       ptr1 =
+			  (unsigned int *)(s1->xim->data +
+					   ((x) *
+					    ((s1->xim->bits_per_pixel) >> 3)) +
+					   ((j + y) * s1->xim->bytes_per_line));
+		       ptr2 =
+			  (unsigned int *)(s2->xim->data +
+					   ((ox) *
+					    ((s2->xim->bits_per_pixel) >> 3)) +
+					   ((j + oy) *
+					    s2->xim->bytes_per_line));
+		       ptr3 =
+			  (unsigned int *)(dst->xim->data +
+					   ((ox) *
+					    ((dst->xim->bits_per_pixel) >> 3)) +
+					   ((j + oy) *
+					    dst->xim->bytes_per_line));
 		       if (!(w & 0x1))
 			 {
 			    for (i = 0; i < w; i += 2)
@@ -632,18 +649,23 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x,
 		    {
 		       unsigned int       *ptr1, *ptr2, *ptr3;
 
-		       ptr1 = (unsigned int *)
-			  (s1->xim->data +
-			   ((x) * ((s1->xim->bits_per_pixel) >> 3)) +
-			   ((j + y) * s1->xim->bytes_per_line));
-		       ptr2 = (unsigned int *)
-			  (s2->xim->data +
-			   ((ox) * ((s2->xim->bits_per_pixel) >> 3)) +
-			   ((j + oy) * s2->xim->bytes_per_line));
-		       ptr3 = (unsigned int *)
-			  (dst->xim->data +
-			   ((ox) * ((dst->xim->bits_per_pixel) >> 3)) +
-			   ((j + oy) * dst->xim->bytes_per_line));
+		       ptr1 =
+			  (unsigned int *)(s1->xim->data +
+					   ((x) *
+					    ((s1->xim->bits_per_pixel) >> 3)) +
+					   ((j + y) * s1->xim->bytes_per_line));
+		       ptr2 =
+			  (unsigned int *)(s2->xim->data +
+					   ((ox) *
+					    ((s2->xim->bits_per_pixel) >> 3)) +
+					   ((j + oy) *
+					    s2->xim->bytes_per_line));
+		       ptr3 =
+			  (unsigned int *)(dst->xim->data +
+					   ((ox) *
+					    ((dst->xim->bits_per_pixel) >> 3)) +
+					   ((j + oy) *
+					    dst->xim->bytes_per_line));
 		       if (!(w & 0x1))
 			 {
 			    for (i = 0; i < w; i += 2)
@@ -713,18 +735,21 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x,
 	       {
 		  unsigned char      *ptr1, *ptr2, *ptr3;
 
-		  ptr1 = (unsigned char *)
-		     (s1->xim->data +
-		      ((x) * ((s1->xim->bits_per_pixel) >> 3)) +
-		      ((j + y) * s1->xim->bytes_per_line));
-		  ptr2 = (unsigned char *)
-		     (s2->xim->data +
-		      ((ox) * ((s2->xim->bits_per_pixel) >> 3)) +
-		      ((j + oy) * s2->xim->bytes_per_line));
-		  ptr3 = (unsigned char *)
-		     (dst->xim->data +
-		      ((ox) * ((dst->xim->bits_per_pixel) >> 3)) +
-		      ((j + oy) * dst->xim->bytes_per_line));
+		  ptr1 =
+		     (unsigned char *)(s1->xim->data +
+				       ((x) *
+					((s1->xim->bits_per_pixel) >> 3)) +
+				       ((j + y) * s1->xim->bytes_per_line));
+		  ptr2 =
+		     (unsigned char *)(s2->xim->data +
+				       ((ox) *
+					((s2->xim->bits_per_pixel) >> 3)) +
+				       ((j + oy) * s2->xim->bytes_per_line));
+		  ptr3 =
+		     (unsigned char *)(dst->xim->data +
+				       ((ox) *
+					((dst->xim->bits_per_pixel) >> 3)) +
+				       ((j + oy) * dst->xim->bytes_per_line));
 		  if (!(w & 0x1))
 		    {
 		       if (j & 0x1)
@@ -829,8 +854,8 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
 	   break;
      }
 
-   if ((mode.mode == MODE_RESIZE) ||
-       (mode.mode == MODE_RESIZE_H) || (mode.mode == MODE_RESIZE_V))
+   if ((mode.mode == MODE_RESIZE) || (mode.mode == MODE_RESIZE_H)
+       || (mode.mode == MODE_RESIZE_V))
      {
 	w1 = ewin->client.w;
 	h1 = ewin->client.h;
@@ -845,9 +870,8 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
 	ewin->client.h = h1;
      }
    if ((md == 5)
-       && ((mode.mode == MODE_RESIZE) ||
-	   (mode.mode == MODE_RESIZE_H) ||
-	   (mode.mode == MODE_RESIZE_V) || (ewin->groups && check_move)))
+       && ((mode.mode == MODE_RESIZE) || (mode.mode == MODE_RESIZE_H)
+	   || (mode.mode == MODE_RESIZE_V) || (ewin->groups && check_move)))
       md = 0;
    if (md == 5)
      {
@@ -859,9 +883,8 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
 	   bpp = 3;
 	else
 	   bpp = 4;
-	if ((ird) ||
-	    ((id->max_shm) && ((bpp * w * h) > id->max_shm)) ||
-	    ((!id->x.shm) || (!id->x.shmp)))
+	if ((ird) || ((id->max_shm) && ((bpp * w * h) > id->max_shm))
+	    || ((!id->x.shm) || (!id->x.shmp)))
 	   md = 0;
      }
    pw = w;
@@ -885,14 +908,17 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
      case 4:
      case 5:
 	if (!b1)
-	   b1 = XCreateBitmapFromData(disp, root.win, flipped_gray_bits,
-				      flipped_gray_width, flipped_gray_height);
+	   b1 =
+	      XCreateBitmapFromData(disp, root.win, flipped_gray_bits,
+				    flipped_gray_width, flipped_gray_height);
 	if (!b2)
-	   b2 = XCreateBitmapFromData(disp, root.win, gray_bits,
-				      gray_width, gray_height);
+	   b2 =
+	      XCreateBitmapFromData(disp, root.win, gray_bits, gray_width,
+				    gray_height);
 	if (!b3)
-	   b3 = XCreateBitmapFromData(disp, root.win, gray3_bits,
-				      gray3_width, gray3_height);
+	   b3 =
+	      XCreateBitmapFromData(disp, root.win, gray3_bits, gray3_width,
+				    gray3_height);
 	x1 = ewin->x + desks.desk[ewin->desktop].x;
 	y1 = ewin->y + desks.desk[ewin->desktop].y;
 	w1 = ewin->w - (ewin->border->border.left + ewin->border->border.right);
@@ -1050,8 +1076,8 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
 	       {
 		  DO_DRAW_MODE_1(x1, y1, w1, h1);
 	       }
-	     if ((mode.mode != MODE_NONE) &&
-		 (!ewin->groups || (ewin->groups && !check_move)))
+	     if ((mode.mode != MODE_NONE)
+		 && (!ewin->groups || (ewin->groups && !check_move)))
 		SetCoords(ewin->x, ewin->y,
 			  (ewin->client.w -
 			   ewin->client.base_w) / ewin->client.w_inc,
@@ -1068,8 +1094,8 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
 	       {
 		  DO_DRAW_MODE_2(x1, y1, w1, h1);
 	       }
-	     if ((mode.mode != MODE_NONE) &&
-		 (!ewin->groups || (ewin->groups && !check_move)))
+	     if ((mode.mode != MODE_NONE)
+		 && (!ewin->groups || (ewin->groups && !check_move)))
 		SetCoords(ewin->x, ewin->y,
 			  (ewin->client.w -
 			   ewin->client.base_w) / ewin->client.w_inc,
@@ -1086,8 +1112,8 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
 	       {
 		  DO_DRAW_MODE_3(x1, y1, w1, h1);
 	       }
-	     if ((mode.mode != MODE_NONE) &&
-		 (!ewin->groups || (ewin->groups && !check_move)))
+	     if ((mode.mode != MODE_NONE)
+		 && (!ewin->groups || (ewin->groups && !check_move)))
 		SetCoords(ewin->x, ewin->y,
 			  (ewin->client.w -
 			   ewin->client.base_w) / ewin->client.w_inc,
@@ -1105,8 +1131,8 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
 		  DO_DRAW_MODE_4(x1, y1, w1, h1);
 	       }
 	     if (firstlast < 2)
-		if ((mode.mode != MODE_NONE) &&
-		    (!ewin->groups || (ewin->groups && !check_move)))
+		if ((mode.mode != MODE_NONE)
+		    && (!ewin->groups || (ewin->groups && !check_move)))
 		   SetCoords(ewin->x, ewin->y,
 			     (ewin->client.w -
 			      ewin->client.base_w) / ewin->client.w_inc,
@@ -1156,8 +1182,8 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
 		  XCopyArea(disp, root_pi->pmap, ewin_pi->pmap, gc, x1, y1,
 			    ewin->w, ewin->h, 0, 0);
 		  XFreeGC(disp, gc);
-		  EBlendPixImg(ewin, root_pi, ewin_pi, draw_pi, x, y,
-			       ewin->w, ewin->h);
+		  EBlendPixImg(ewin, root_pi, ewin_pi, draw_pi, x, y, ewin->w,
+			       ewin->h);
 	       }
 	     else if (firstlast == 1)
 	       {
@@ -1245,8 +1271,8 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
 		  ht = ewin->h;
 		  root_pi = ECreatePixImg(root.win, root.w, root.h);
 		  EFillPixmap(root.win, root_pi->pmap, x, y, wt, ht);
-		  EBlendPixImg(ewin, root_pi, ewin_pi, draw_pi, x, y,
-			       ewin->w, ewin->h);
+		  EBlendPixImg(ewin, root_pi, ewin_pi, draw_pi, x, y, ewin->w,
+			       ewin->h);
 	       }
 	     else if (firstlast == 5)
 	       {
@@ -1422,8 +1448,8 @@ PropagateShapes(Window win)
 				       ShapeSet);
 		  else if (rn == 1)
 		    {
-		       if ((rl[0].x == 0) && (rl[0].y == 0) &&
-			   (rl[0].width == ww) && (rl[0].height == hh))
+		       if ((rl[0].x == 0) && (rl[0].y == 0)
+			   && (rl[0].width == ww) && (rl[0].height == hh))
 			  EShapeCombineMask(disp, win, ShapeBounding, 0, 0,
 					    None, ShapeSet);
 		    }
