@@ -126,8 +126,8 @@ NukeBoringevents(XEvent * ev, int num)
 	     win = ev[i].xany.window;
 	     for (j = i; j < num; j++)
 	       {
-		  if ((ev[j].type == event_base_shape + ShapeNotify) &&
-		      (ev[j].xany.window == win))
+		  if ((ev[j].type == event_base_shape + ShapeNotify)
+		      && (ev[j].xany.window == win))
 		    {
 		       ok[j] = 0;
 		       last = j;
@@ -269,12 +269,12 @@ HandleEvent(XEvent * ev)
    WarpFocusHandleEvent(ev);
    if (ev->type == event_base_shape + ShapeNotify)
       HandleChildShapeChange(ev);
-   if ((ev->type == KeyPress) || (ev->type == KeyRelease) ||
-       (ev->type == ButtonPress) || (ev->type == ButtonRelease) ||
-       (ev->type == EnterNotify) || (ev->type == LeaveNotify))
+   if ((ev->type == KeyPress) || (ev->type == KeyRelease)
+       || (ev->type == ButtonPress) || (ev->type == ButtonRelease)
+       || (ev->type == EnterNotify) || (ev->type == LeaveNotify))
      {
-	if (((ev->type == KeyPress) || (ev->type == KeyRelease)) &&
-	    (ev->xkey.root != root.win))
+	if (((ev->type == KeyPress) || (ev->type == KeyRelease))
+	    && (ev->xkey.root != root.win))
 	  {
 	     XSetInputFocus(disp, ev->xkey.root, RevertToPointerRoot,
 			    CurrentTime);
@@ -487,8 +487,8 @@ WaitEvent()
 
    DBUG_STACKCHECK;
 
-   if ((!(FD_ISSET(xfd, &fdset))) && (qe) && (count == 0) &&
-       (((smfd >= 0) && (!(FD_ISSET(smfd, &fdset)))) || (smfd < 0)))
+   if ((!(FD_ISSET(xfd, &fdset))) && (qe) && (count == 0)
+       && (((smfd >= 0) && (!(FD_ISSET(smfd, &fdset)))) || (smfd < 0)))
       HandleTimerEvent();
 
    DBUG_STACKCHECK;
@@ -541,8 +541,8 @@ void
 HButtonPress(XEvent * ev)
 {
    EDBUG(7, "HButtonPress");
-   ApplySclass(FindItem("SOUND_BUTTON_CLICK", 0,
-			LIST_FINDBY_NAME, LIST_TYPE_SCLASS));
+   ApplySclass(FindItem
+	       ("SOUND_BUTTON_CLICK", 0, LIST_FINDBY_NAME, LIST_TYPE_SCLASS));
    HandleMouseDown(ev);
 #if 0
    {
@@ -579,20 +579,19 @@ HButtonPress(XEvent * ev)
 	   count++;
 	   if (pb->depth == 1)
 	      mcount++;
-	   fprintf(stderr, "%08x (%5ix%5i %i) : "
-		   "%x %x %x %x %x %x %x %x "
-		   "%x %x %x %x %x %x %x %x "
-		   "%x %x %x %x %x %x %x %x "
-		   "%x %x %x %x %x %x %x %x\n",
-		   pb->id, pb->w, pb->h, pb->depth,
-		   pb->stack[0], pb->stack[1], pb->stack[2], pb->stack[3],
-		   pb->stack[4], pb->stack[5], pb->stack[6], pb->stack[7],
-		   pb->stack[8], pb->stack[9], pb->stack[10], pb->stack[11],
-		   pb->stack[12], pb->stack[13], pb->stack[14], pb->stack[15],
-		   pb->stack[16], pb->stack[17], pb->stack[18], pb->stack[19],
-		   pb->stack[20], pb->stack[21], pb->stack[22], pb->stack[23],
-		   pb->stack[24], pb->stack[25], pb->stack[26], pb->stack[27],
-		   pb->stack[28], pb->stack[29], pb->stack[30], pb->stack[31]);
+	   fprintf(stderr,
+		   "%08x (%5ix%5i %i) : " "%x %x %x %x %x %x %x %x "
+		   "%x %x %x %x %x %x %x %x " "%x %x %x %x %x %x %x %x "
+		   "%x %x %x %x %x %x %x %x\n", pb->id, pb->w, pb->h,
+		   pb->depth, pb->stack[0], pb->stack[1], pb->stack[2],
+		   pb->stack[3], pb->stack[4], pb->stack[5], pb->stack[6],
+		   pb->stack[7], pb->stack[8], pb->stack[9], pb->stack[10],
+		   pb->stack[11], pb->stack[12], pb->stack[13], pb->stack[14],
+		   pb->stack[15], pb->stack[16], pb->stack[17], pb->stack[18],
+		   pb->stack[19], pb->stack[20], pb->stack[21], pb->stack[22],
+		   pb->stack[23], pb->stack[24], pb->stack[25], pb->stack[26],
+		   pb->stack[27], pb->stack[28], pb->stack[29], pb->stack[30],
+		   pb->stack[31]);
 	}
       fprintf(stderr, "Total %i, %i of them bitmaps\n", count, mcount);
       XFreeGC(disp, gc);
@@ -605,8 +604,8 @@ void
 HButtonRelease(XEvent * ev)
 {
    EDBUG(7, "HButtonRelease");
-   ApplySclass(FindItem("SOUND_BUTTON_RAISE", 0,
-			LIST_FINDBY_NAME, LIST_TYPE_SCLASS));
+   ApplySclass(FindItem
+	       ("SOUND_BUTTON_RAISE", 0, LIST_FINDBY_NAME, LIST_TYPE_SCLASS));
    HandleMouseUp(ev);
    EDBUG_RETURN_;
 }
@@ -659,8 +658,8 @@ HLeaveNotify(XEvent * ev)
 	 */
 	if (ev->xcrossing.window == root.win)
 	  {
-	     if (ev->xcrossing.mode == NotifyNormal &&
-		 ev->xcrossing.detail != NotifyInferior && mode.focuswin)
+	     if (ev->xcrossing.mode == NotifyNormal
+		 && ev->xcrossing.detail != NotifyInferior && mode.focuswin)
 		HandleFocusWindow(root.focuswin);
 	     else
 		HandleFocusWindow(ev->xcrossing.window);
