@@ -1,3 +1,4 @@
+
 /*
  * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
  * *
@@ -71,11 +72,13 @@ ToolTipTimeout(int val, void *data)
 
    /* In the case of multiple screens, check to make sure
     * the root window is still where the mouse is... */
-   if (False == XQueryPointer(disp, root.win, &rt, &ch, &x, &y, &dum,
-			      &dum, &mask)) EDBUG_RETURN_;
+   if (False ==
+       XQueryPointer(disp, root.win, &rt, &ch, &x, &y, &dum, &dum, &mask))
+      EDBUG_RETURN_;
    /* dont pop up tooltip is mouse button down */
-   if (mask & (Button1Mask | Button2Mask | Button3Mask |
-	       Button4Mask | Button5Mask)) EDBUG_RETURN_;
+   if (mask &
+       (Button1Mask | Button2Mask | Button3Mask | Button4Mask | Button5Mask))
+      EDBUG_RETURN_;
    win = WindowAtXY(x, y);
    ac = FindActionClass(win);
    if (!ac)
@@ -189,9 +192,9 @@ HandleClientMessage(XEvent * ev)
 		       ewin->sticky = 1;
 		       RaiseEwin(ewin);
 		       DrawEwin(ewin);
-		       ApplySclass(FindItem("SOUND_WINDOW_STICK", 0,
-					    LIST_FINDBY_NAME,
-					    LIST_TYPE_SCLASS));
+		       ApplySclass(FindItem
+				   ("SOUND_WINDOW_STICK", 0, LIST_FINDBY_NAME,
+				    LIST_TYPE_SCLASS));
 		    }
 	       }
 	     else
@@ -201,9 +204,9 @@ HandleClientMessage(XEvent * ev)
 		       ewin->sticky = 0;
 		       RaiseEwin(ewin);
 		       DrawEwin(ewin);
-		       ApplySclass(FindItem("SOUND_WINDOW_UNSTICK", 0,
-					    LIST_FINDBY_NAME,
-					    LIST_TYPE_SCLASS));
+		       ApplySclass(FindItem
+				   ("SOUND_WINDOW_UNSTICK", 0, LIST_FINDBY_NAME,
+				    LIST_TYPE_SCLASS));
 		    }
 	       }
 	  }
@@ -253,8 +256,8 @@ HandleFocusWindowIn(Window win)
 	     if (mode.focusmode == FOCUS_CLICK)
 		XGrabButton(disp, AnyButton, AnyModifier,
 			    mode.focuswin->win_container, False,
-			    ButtonPressMask,
-			    GrabModeSync, GrabModeAsync, None, None);
+			    ButtonPressMask, GrabModeSync, GrabModeAsync, None,
+			    None);
 	  }
 	mode.focuswin = ewin;
 	if ((ewin) && (!ewin->menu))
@@ -356,9 +359,10 @@ HandleMotion(XEvent * ev)
    ewin = NULL;
    desks.current = DesktopAt(mode.x, mode.y);
 
-   if ((!(ev->xmotion.state & (Button1Mask | Button2Mask |
-			       Button3Mask | Button4Mask |
-			       Button5Mask)) && (!mode.place)))
+   if (
+       (!(ev->xmotion.state
+	  & (Button1Mask | Button2Mask | Button3Mask | Button4Mask |
+	     Button5Mask)) && (!mode.place)))
      {
 	switch (mode.mode)
 	  {
@@ -386,18 +390,25 @@ HandleMotion(XEvent * ev)
 	if (mode.ewin)
 	  {
 	     EWin              **gwins;
-	     int                 i, num;
+	     int                 i, j, num;
 	     int                 ndx, ndy;
 	     int                 prx, pry;
 	     int                 screen_snap_dist;
 
 	     ewin = mode.ewin;
-	     gwins =
-		ListWinGroupMembersForEwin(ewin, ACTION_MOVE, mode.nogroup,
-					   &num);
-
-	     if ((mode.moveresize_pending_ewin) &&
-		 (mode.ewin == mode.moveresize_pending_ewin))
+	     if (mode.swapmovemode /* && mode.group_swapmove */ )
+	       {
+		  gwins =
+		     ListWinGroupMembersForEwin(ewin, ACTION_MOVE, 1, &num);
+	       }
+	     else
+	       {
+		  gwins =
+		     ListWinGroupMembersForEwin(ewin, ACTION_MOVE, mode.nogroup,
+						&num);
+	       }
+	     if ((mode.moveresize_pending_ewin)
+		 && (mode.ewin == mode.moveresize_pending_ewin))
 	       {
 		  for (i = 0; i < num; i++)
 		     DrawEwinShape(gwins[i], mode.movemode, gwins[i]->x,
@@ -470,54 +481,58 @@ HandleMotion(XEvent * ev)
 		   ndy = max_dy;
 		else
 		   ndy = min_dy;
-		screen_snap_dist = mode.constrained ? (root.w + root.h)
-		   : mode.screen_snap_dist;
+		screen_snap_dist =
+		   mode.constrained ? (root.w + root.h) : mode.screen_snap_dist;
 		for (i = 0; i < num; i++)
 		  {
 		     /* jump out of snap horizontally */
-		     if ((ndx != dx) &&
-			 (((gwins[i]->x == 0) &&
-			   (!(IN_RANGE
-			      (gwins[i]->reqx, gwins[i]->x, screen_snap_dist))))
-			  || ((gwins[i]->x == (root.w - gwins[i]->w))
+		     if ((ndx != dx)
+			 && (((gwins[i]->x == 0)
 			      &&
 			      (!(IN_RANGE
 				 (gwins[i]->reqx, gwins[i]->x,
-				  screen_snap_dist)))) || ((gwins[i]->x != 0)
-							   && (gwins[i]->x !=
-							       (root.w -
-								gwins[i]->w)
-							       &&
-							       (!(IN_RANGE
-								  (gwins
-								   [i]->reqx,
-								   gwins[i]->x,
-								   mode.
-								   edge_snap_dist)))))))
+				  screen_snap_dist))))
+			     || ((gwins[i]->x == (root.w - gwins[i]->w))
+				 &&
+				 (!(IN_RANGE
+				    (gwins[i]->reqx, gwins[i]->x,
+				     screen_snap_dist)))) || ((gwins[i]->x != 0)
+							      && (gwins[i]->x !=
+								  (root.w -
+								   gwins[i]->w)
+								  &&
+								  (!(IN_RANGE
+								     (gwins
+								      [i]->reqx,
+								      gwins
+								      [i]->x,
+								      mode.edge_snap_dist)))))))
 		       {
 			  jumpx = 1;
 			  ndx = gwins[i]->reqx - gwins[i]->x + dx;
 		       }
 		     /* jump out of snap vertically */
-		     if ((ndy != dy) &&
-			 (((gwins[i]->y == 0) &&
-			   (!(IN_RANGE
-			      (gwins[i]->reqy, gwins[i]->y, screen_snap_dist))))
-			  || ((gwins[i]->y == (root.h - gwins[i]->h))
+		     if ((ndy != dy)
+			 && (((gwins[i]->y == 0)
 			      &&
 			      (!(IN_RANGE
 				 (gwins[i]->reqy, gwins[i]->y,
-				  screen_snap_dist)))) || ((gwins[i]->y != 0)
-							   && (gwins[i]->y !=
-							       (root.h -
-								gwins[i]->h)
-							       &&
-							       (!(IN_RANGE
-								  (gwins
-								   [i]->reqy,
-								   gwins[i]->y,
-								   mode.
-								   edge_snap_dist)))))))
+				  screen_snap_dist))))
+			     || ((gwins[i]->y == (root.h - gwins[i]->h))
+				 &&
+				 (!(IN_RANGE
+				    (gwins[i]->reqy, gwins[i]->y,
+				     screen_snap_dist)))) || ((gwins[i]->y != 0)
+							      && (gwins[i]->y !=
+								  (root.h -
+								   gwins[i]->h)
+								  &&
+								  (!(IN_RANGE
+								     (gwins
+								      [i]->reqy,
+								      gwins
+								      [i]->y,
+								      mode.edge_snap_dist)))))))
 		       {
 			  jumpy = 1;
 			  ndy = gwins[i]->reqy - gwins[i]->y + dy;
@@ -532,16 +547,66 @@ HandleMotion(XEvent * ev)
 		     /* draw the new position of the window */
 		     prx = gwins[i]->reqx;
 		     pry = gwins[i]->reqy;
-		     DrawEwinShape(gwins[i], mode.movemode,
-				   gwins[i]->x + ndx, gwins[i]->y + ndy,
-				   gwins[i]->client.w, gwins[i]->client.h,
-				   mode.firstlast);
-		     /* if we didnt jump the winow after a reist at the edge */
-		     /* reset the requested x to be the prev requested + delta */
+		     DrawEwinShape(gwins[i], mode.movemode, gwins[i]->x + ndx,
+				   gwins[i]->y + ndy, gwins[i]->client.w,
+				   gwins[i]->client.h, mode.firstlast);
+		     /* if we didnt jump the winow after a resist at the edge */
+		     /* reset the requested x to be the prev. requested + delta */
 		     if (!(jumpx))
 			gwins[i]->reqx = prx + dx;
 		     if (!(jumpy))
 			gwins[i]->reqy = pry + dy;
+
+		     /* swapping of group member locations: */
+		     if (mode.swapmovemode && mode.group_swapmove)
+		       {
+			  EWin              **all_gwins;
+			  int                 all_gwins_num;
+
+			  all_gwins =
+			     ListWinGroupMembersForEwin(ewin, ACTION_NONE, 0,
+							&all_gwins_num);
+
+			  for (j = 0; j < all_gwins_num; j++)
+			    {
+			       if (gwins[i] == all_gwins[j])
+				  continue;
+
+			       /* check for sufficient overlap and avoid flickering */
+			       if (
+				   ((gwins
+				     [i]->x >= all_gwins[j]->x
+				     && gwins[i]->x <=
+				     all_gwins[j]->x + all_gwins[j]->w / 2
+				     && mode.x <= mode.px)
+				    || (gwins[i]->x <= all_gwins[j]->x
+					&& gwins[i]->x + gwins[i]->w / 2 >=
+					all_gwins[j]->x && mode.x >= mode.px))
+				   &&
+				   ((gwins
+				     [i]->y >= all_gwins[j]->y
+				     && gwins[i]->y <=
+				     all_gwins[j]->y + all_gwins[j]->h / 2
+				     && mode.y <= mode.py)
+				    || (gwins[i]->y <= all_gwins[j]->y
+					&& gwins[i]->y + gwins[i]->h / 2 >=
+					all_gwins[j]->y && mode.y >= mode.py)))
+				 {
+				    int                 tmp_swapcoord_x;
+				    int                 tmp_swapcoord_y;
+
+				    tmp_swapcoord_x = mode.swapcoord_x;
+				    tmp_swapcoord_y = mode.swapcoord_y;
+				    mode.swapcoord_x = all_gwins[j]->x;
+				    mode.swapcoord_y = all_gwins[j]->y;
+				    MoveEwin(all_gwins[j], tmp_swapcoord_x,
+					     tmp_swapcoord_y);
+				    break;
+				 }
+			    }
+
+			  Efree(all_gwins);
+		       }
 		  }
 	     }
 	     Efree(gwins);
@@ -743,16 +808,16 @@ HandleMotion(XEvent * ev)
 		x = -x;
 	     if (y < 0)
 		y = -y;
-	     if ((x > mode.button_move_resistance) ||
-		 (y > mode.button_move_resistance)) mode.button_move_pending =
-		   0;
+	     if ((x > mode.button_move_resistance)
+		 || (y > mode.button_move_resistance))
+		mode.button_move_pending = 0;
 	  }
 	if (!mode.button_move_pending)
 	  {
 	     if (mode.button)
 	       {
-		  MovebuttonToCoord(mode.button,
-				    mode.button->x + dx, mode.button->y + dy);
+		  MovebuttonToCoord(mode.button, mode.button->x + dx,
+				    mode.button->y + dy);
 		  if (mode.deskmode == MODE_DESKRAY)
 		    {
 		       MoveDesktop(mode.deskdrag, desks.desk[mode.deskdrag].x,
@@ -773,6 +838,7 @@ HandleMotion(XEvent * ev)
 #ifdef HAS_XINERAMA
 	static XineramaScreenInfo *screens;
 	static int          num_screens;
+
 #endif
 	EWin               *menus[256];
 	int                 fx[256];
@@ -988,8 +1054,8 @@ HandleMotion(XEvent * ev)
 	     GetAreaSize(&ax, &ay);
 	     dx = mode.x - mode.px;
 	     dy = mode.y - mode.py;
-	     if (!FindItem((char *)p->hi_ewin, 0,
-			   LIST_FINDBY_POINTER, LIST_TYPE_EWIN))
+	     if (!FindItem
+		 ((char *)p->hi_ewin, 0, LIST_FINDBY_POINTER, LIST_TYPE_EWIN))
 		p->hi_ewin = NULL;
 	     if ((p->hi_ewin) && (!p->hi_ewin->pager)
 		 && (!p->hi_ewin->fixedpos))
@@ -1014,8 +1080,8 @@ HandleMotion(XEvent * ev)
 					   mode.nogroup, &num);
 	     for (i = 0; i < num; i++)
 	       {
-		  if ((gwins[i] != p->hi_ewin) && (!gwins[i]->pager) &&
-		      (!gwins[i]->fixedpos))
+		  if ((gwins[i] != p->hi_ewin) && (!gwins[i]->pager)
+		      && (!gwins[i]->fixedpos))
 		    {
 		       GetWinXY(gwins[i]->win, &x, &y);
 		       x += (dx * root.w * ax) / p->w;
@@ -1048,7 +1114,8 @@ HandleMotion(XEvent * ev)
 		     if (di->item.slider.horizontal)
 		       {
 			  di->item.slider.wanted_val += dx;
-			  di->item.slider.val = di->item.slider.lower +
+			  di->item.slider.val =
+			     di->item.slider.lower +
 			     (((di->item.slider.wanted_val *
 				(di->item.slider.upper -
 				 di->item.slider.lower)) /
@@ -1059,9 +1126,10 @@ HandleMotion(XEvent * ev)
 		     else
 		       {
 			  di->item.slider.wanted_val += dy;
-			  di->item.slider.val = di->item.slider.lower +
-			     ((((di->
-				 item.slider.base_h - di->item.slider.knob_h -
+			  di->item.slider.val =
+			     di->item.slider.lower +
+			     ((((di->item.
+				 slider.base_h - di->item.slider.knob_h -
 				 di->item.slider.wanted_val) *
 				(di->item.slider.upper -
 				 di->item.slider.lower)) /
@@ -1149,7 +1217,7 @@ HandleDestroy(XEvent * ev)
 	   mode.mouse_over_win = NULL;
 	if (ewin == mode.ewin)
 	   mode.ewin = NULL;
-	if (ewin->docked)
+	if (mode.dockapp_support && ewin->docked)
 	   DockDestroy(ewin);
 	DesktopRemoveEwin(ewin);
 	FreeEwin(ewin);
@@ -1401,8 +1469,7 @@ HandleConfigureRequest(XEvent * ev)
 	   ewin->client.height.min = h;
 	if (h > ewin->client.height.max)
 	   ewin->client.height.max = h;
-	MoveResizeEwin(ewin,
-		       x - ewin->border->border.left,
+	MoveResizeEwin(ewin, x - ewin->border->border.left,
 		       y - ewin->border->border.top, w, h);
 	if (mode.mode == MODE_MOVE)
 	   ICCCM_Configure(ewin);
@@ -1494,7 +1561,7 @@ HandleUnmap(XEvent * ev)
 	     mode.mode = MODE_NONE;
 	     mode.context_pager = NULL;
 	  }
-	if (ewin->docked)
+	if (mode.dockapp_support && ewin->docked)
 	   DockDestroy(ewin);
 	if (ewin == mode.ewin)
 	  {
@@ -1530,10 +1597,10 @@ HandleUnmap(XEvent * ev)
 	  {
 	     XTranslateCoordinates(disp, ewin->client.win, root.win,
 				   -ewin->border->border.left,
-				   -ewin->border->border.top,
-				   &ewin->client.x, &ewin->client.y, &win);
-	     EReparentWindow(disp, ewin->client.win, root.win,
-			     ewin->client.x, ewin->client.y);
+				   -ewin->border->border.top, &ewin->client.x,
+				   &ewin->client.y, &win);
+	     EReparentWindow(disp, ewin->client.win, root.win, ewin->client.x,
+			     ewin->client.y);
 	     XRemoveFromSaveSet(disp, ewin->client.win);
 	     ICCCM_Withdraw(ewin);
 	     RemoveItem(NULL, ewin->client.win, LIST_FINDBY_ID, LIST_TYPE_EWIN);
@@ -1598,8 +1665,8 @@ HandleExpose(XEvent * ev)
 	       {
 		  ewin[i]->bits[j].no_expose = 0;
 		  ewin[i]->bits[j].expose = 1;
-		  if ((DrawEwinWinpart(ewin[i], j)) &&
-		      (IsPropagateEwinOnQueue(ewin[i])))
+		  if ((DrawEwinWinpart(ewin[i], j))
+		      && (IsPropagateEwinOnQueue(ewin[i])))
 		     PropagateShapes(ewin[i]->win);
 		  Efree(ewin);
 		  EDBUG_RETURN_;
@@ -1694,9 +1761,9 @@ HandleMouseDown(XEvent * ev)
      {
 	unsigned int        bmask = 0, evmask;
 
-	evmask = ev->xbutton.state &
-	   (Button1Mask | Button2Mask | Button3Mask | Button4Mask |
-	    Button5Mask);
+	evmask =
+	   ev->xbutton.state & (Button1Mask | Button2Mask | Button3Mask |
+				Button4Mask | Button5Mask);
 	if (ev->xbutton.button == 1)
 	   bmask = Button1Mask;
 	else if (ev->xbutton.button == 2)
@@ -1723,8 +1790,7 @@ HandleMouseDown(XEvent * ev)
    if (
        (((float)(ev->xbutton.time - last_time) / 1000) <
 	mode_double_click_time)
-       && ((int)(ev->xbutton.button) == (int)(last_button)))
-      double_click = 1;
+       && ((int)(ev->xbutton.button) == (int)(last_button))) double_click = 1;
    last_time = ev->xbutton.time;
    last_button = ev->xbutton.button;
 
@@ -1860,8 +1926,9 @@ HandleMouseDown(XEvent * ev)
 		  mode.button = buttons[i];
 		  buttons[i]->state = STATE_CLICKED;
 		  DrawButton(buttons[i]);
-		  ac = FindItem("ACTION_BUTTON_DRAG", 0, LIST_FINDBY_NAME,
-				LIST_TYPE_ACLASS);
+		  ac =
+		     FindItem("ACTION_BUTTON_DRAG", 0, LIST_FINDBY_NAME,
+			      LIST_TYPE_ACLASS);
 		  if (ac)
 		     EventAclass(ev, ac);
 		  if (buttons[i]->aclass)
@@ -1944,8 +2011,9 @@ HandleMouseDown(XEvent * ev)
      {
 	ActionClass        *ac;
 
-	ac = (ActionClass *) FindItem("BUTTONBINDINGS", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ACLASS);
+	ac =
+	   (ActionClass *) FindItem("BUTTONBINDINGS", 0, LIST_FINDBY_NAME,
+				    LIST_TYPE_ACLASS);
 	if (ac)
 	  {
 	     mode.ewin = ewin;
@@ -1967,8 +2035,9 @@ HandleMouseDown(XEvent * ev)
 	{
 	   EWin              **gwins;
 
-	   gwins = ListWinGroupMembersForEwin(p->hi_ewin, ACTION_MOVE,
-					      mode.nogroup, &num);
+	   gwins =
+	      ListWinGroupMembersForEwin(p->hi_ewin, ACTION_MOVE,
+					 mode.nogroup, &num);
 	   gwin_px = calloc(num, sizeof(int));
 	   gwin_py = calloc(num, sizeof(int));
 
@@ -1990,8 +2059,8 @@ HandleMouseDown(XEvent * ev)
 	     }
 	   if ((int)ev->xbutton.button == mode.pager_menu_button)
 	     {
-		if ((ev->xbutton.x >= 0) && (ev->xbutton.y >= 0) &&
-		    (ev->xbutton.x < p->w) && (ev->xbutton.y < p->h))
+		if ((ev->xbutton.x >= 0) && (ev->xbutton.y >= 0)
+		    && (ev->xbutton.x < p->w) && (ev->xbutton.y < p->h))
 		   PagerShowMenu(p, ev->xbutton.x, ev->xbutton.y);
 	     }
 	   else if ((int)ev->xbutton.button == mode.pager_win_button)
@@ -2051,8 +2120,8 @@ HandleMouseUp(XEvent * ev)
    EDBUG(5, "HandleMouseUp");
 
    /* DON'T handle clicks whilst moving/resizing things */
-   if ((mode.mode != MODE_NONE) &&
-       (!((mode.place) && (mode.mode == MODE_MOVE))))
+   if ((mode.mode != MODE_NONE)
+       && (!((mode.place) && (mode.mode == MODE_MOVE))))
      {
 	if ((int)last_button != (int)ev->xbutton.button)
 	   EDBUG_RETURN_;
@@ -2105,8 +2174,8 @@ HandleMouseUp(XEvent * ev)
 	       {
 		  if (last_bpress == ewin->bits[j].win)
 		    {
-		       if ((ewin->bits[j].state == STATE_CLICKED) &&
-			   (!ewin->bits[j].left))
+		       if ((ewin->bits[j].state == STATE_CLICKED)
+			   && (!ewin->bits[j].left))
 			  ewin->bits[j].state = STATE_HILITED;
 		       else
 			  ewin->bits[j].state = STATE_NORMAL;
@@ -2177,8 +2246,8 @@ HandleMouseUp(XEvent * ev)
 	doDragButtonEnd(NULL);
      }
    m = FindMenuItem(win, &mi);
-   if ((((float)(ev->xbutton.time - last_time) / 1000) < 0.5) &&
-       (mode.cur_menu_depth > 0) && (!clickmenu))
+   if ((((float)(ev->xbutton.time - last_time) / 1000) < 0.5)
+       && (mode.cur_menu_depth > 0) && (!clickmenu))
      {
 	clickmenu = 1;
 	justclicked = 1;
@@ -2220,8 +2289,8 @@ HandleMouseUp(XEvent * ev)
 		    {
 		       if (ww == ewin->bits[i].win)
 			 {
-			    if ((ewin->border->part[i].flags & FLAG_TITLE) &&
-				(ewin->menu))
+			    if ((ewin->border->part[i].flags & FLAG_TITLE)
+				&& (ewin->menu))
 			      {
 				 ewin->menu->stuck = 1;
 				 mode.context_ewin = ewin;
@@ -2282,8 +2351,8 @@ HandleMouseUp(XEvent * ev)
 				 break;
 			      }
 			 }
-		       if ((ewins[i]->bits[j].state == STATE_CLICKED) &&
-			   (!ewins[i]->bits[j].left))
+		       if ((ewins[i]->bits[j].state == STATE_CLICKED)
+			   && (!ewins[i]->bits[j].left))
 			  ewins[i]->bits[j].state = STATE_HILITED;
 		       else
 			  ewins[i]->bits[j].state = STATE_NORMAL;
@@ -2419,8 +2488,9 @@ HandleMouseUp(XEvent * ev)
      {
 	ActionClass        *ac;
 
-	ac = (ActionClass *) FindItem("BUTTONBINDINGS", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ACLASS);
+	ac =
+	   (ActionClass *) FindItem("BUTTONBINDINGS", 0, LIST_FINDBY_NAME,
+				    LIST_TYPE_ACLASS);
 	if (ac)
 	  {
 	     mode.borderpartpress = 1;
@@ -2464,8 +2534,8 @@ HandleMouseUp(XEvent * ev)
 		  ev->xbutton.x += hx;
 		  ev->xbutton.y += hy;
 	       }
-	     if (!FindItem((char *)p->hi_ewin, 0,
-			   LIST_FINDBY_POINTER, LIST_TYPE_EWIN))
+	     if (!FindItem
+		 ((char *)p->hi_ewin, 0, LIST_FINDBY_POINTER, LIST_TYPE_EWIN))
 		p->hi_ewin = NULL;
 	     if ((mode.mode == MODE_PAGER_DRAG) && (p->hi_ewin))
 	       {
@@ -2475,8 +2545,8 @@ HandleMouseUp(XEvent * ev)
 		       EWin               *ew;
 
 		       ew = desks.desk[desks.current].list[i];
-		       if (((ew->pager) || (ew->ibox)) &&
-			   ((ew->desktop == desks.current) || (ew->sticky)))
+		       if (((ew->pager) || (ew->ibox))
+			   && ((ew->desktop == desks.current) || (ew->sticky)))
 			 {
 			    if (
 				(ev->xbutton.x_root >=
@@ -2511,23 +2581,26 @@ HandleMouseUp(XEvent * ev)
 		       GetAreaSize(&ax, &ay);
 		       GetWinXY(p->hi_win, &x, &y);
 		       GetWinWH(p->hi_win, &w, &h);
-		       XTranslateCoordinates(disp, pp->win, root.win, 0, 0,
-					     &px, &py, &dw);
-		       wx = ((x - px) - (cx * (pp->w / ax))) *
-			  (root.w / (pp->w / ax));
-		       wy = ((y - py) - (cy * (pp->h / ay))) *
-			  (root.h / (pp->h / ay));
-		       if (((x + w) <= px) ||
-			   ((y + h) <= py) ||
-			   (x >= (px + pp->w)) || (y >= (py + pp->h)))
+		       XTranslateCoordinates(disp, pp->win, root.win, 0, 0, &px,
+					     &py, &dw);
+		       wx =
+			  ((x - px) -
+			   (cx * (pp->w / ax))) * (root.w / (pp->w / ax));
+		       wy =
+			  ((y - py) -
+			   (cy * (pp->h / ay))) * (root.h / (pp->h / ay));
+		       if (((x + w) <= px) || ((y + h) <= py)
+			   || (x >= (px + pp->w)) || (y >= (py + pp->h)))
 			 {
 			    int                 ndesk, nx, ny;
 
 			    ndesk = desks.current;
-			    nx = (int)ev->xbutton.x_root -
+			    nx =
+			       (int)ev->xbutton.x_root -
 			       desks.desk[desks.current].x -
 			       ((int)p->hi_ewin->w / 2);
-			    ny = (int)ev->xbutton.y_root -
+			    ny =
+			       (int)ev->xbutton.y_root -
 			       desks.desk[desks.current].y -
 			       ((int)p->hi_ewin->h / 2);
 			    MoveEwin(p->hi_ewin, nx, ny);
@@ -2565,10 +2638,12 @@ HandleMouseUp(XEvent * ev)
 			      }
 			 }
 		    }
-		  else if ((ewin) && (ewin->ibox) &&
-			   (!((p->hi_ewin->ibox) ||
-			      ((ewin->client.need_input) &&
-			       ((ewin->skiptask) || (ewin->skipwinlist))))))
+		  else if ((ewin) && (ewin->ibox)
+			   &&
+			   (!((p->hi_ewin->ibox) || ((ewin->client.need_input)
+						     && ((ewin->skiptask)
+							 ||
+							 (ewin->skipwinlist))))))
 		    {
 		       char                was_shaded;
 
@@ -2591,7 +2666,8 @@ HandleMouseUp(XEvent * ev)
 						    ewin->ibox->icon_mode);
 				   }
 				 HideEwin(gwins[i]);
-				 MoveEwin(gwins[i], gwin_px[i] +
+				 MoveEwin(gwins[i],
+					  gwin_px[i] +
 					  ((desks.desk
 					    [gwins[i]->
 					     desktop].current_area_x) -
@@ -2614,7 +2690,8 @@ HandleMouseUp(XEvent * ev)
 			  0, ax, ay;
 
 		       ndesk = desks.current;
-		       nx = (int)ev->xbutton.x_root -
+		       nx =
+			  (int)ev->xbutton.x_root -
 			  desks.desk[desks.current].x -
 			  ((int)p->hi_ewin->w / 2);
 		       ny =
@@ -2652,8 +2729,8 @@ HandleMouseUp(XEvent * ev)
 		  p->hi_visible = 1;
 		  PagerHideHi(p);
 	       }
-	     else if ((ev->xbutton.x >= 0) && (ev->xbutton.y >= 0) &&
-		      (ev->xbutton.x < p->w) && (ev->xbutton.y < p->h))
+	     else if ((ev->xbutton.x >= 0) && (ev->xbutton.y >= 0)
+		      && (ev->xbutton.x < p->w) && (ev->xbutton.y < p->h))
 	       {
 		  PagerAreaAt(p, ev->xbutton.x, ev->xbutton.y, &pax, &pay);
 		  GotoDesktop(p->desktop);
@@ -2748,8 +2825,8 @@ SubmenuShowTimeout(int val, void *dat)
 			      }
 			 }
 		    }
-		  SlideEwinsTo(menus, fx, fy, tx, ty,
-			       mode.cur_menu_depth, mode.shadespeed);
+		  SlideEwinsTo(menus, fx, fy, tx, ty, mode.cur_menu_depth,
+			       mode.shadespeed);
 		  if (mode.warpmenus)
 		     XWarpPointer(disp, None, None, 0, 0, 0, 0, xdist, ydist);
 	       }
@@ -2801,8 +2878,8 @@ HandleMouseIn(XEvent * ev)
 	  {
 	     if (mode.cur_menu[i] == m)
 	       {
-		  if ((!mi->child) ||
-		      ((mi->child) && (mode.cur_menu[i + 1] != mi->child)))
+		  if ((!mi->child)
+		      || ((mi->child) && (mode.cur_menu[i + 1] != mi->child)))
 		    {
 		       for (j = i + 1; j < mode.cur_menu_depth; j++)
 			  HideMenu(mode.cur_menu[j]);
@@ -2906,6 +2983,12 @@ HandleMouseIn(XEvent * ev)
 		     if (di->item.area.event_func)
 			(di->item.area.event_func) (0, ev);
 		  }
+		else if (di->type == DITEM_RADIOBUTTON)
+		  {
+		     if (di->item.radio_button.event_func)
+			(di->item.radio_button.event_func) (di->item.radio_button.val,
+							    ev);
+		  }
 		di->hilited = 1;
 		DialogDrawItems(d, di, 0, 0, 99999, 99999);
 	     }
@@ -3026,6 +3109,12 @@ HandleMouseOut(XEvent * ev)
 		     if (di->item.area.event_func)
 			(di->item.area.event_func) (0, ev);
 		  }
+		else if (di->type == DITEM_RADIOBUTTON)
+		  {
+		     if (di->item.radio_button.event_func)
+			(di->item.radio_button.event_func) (di->item.radio_button.val,
+							    NULL);
+		  }
 		di->hilited = 0;
 		DialogDrawItems(d, di, 0, 0, 99999, 99999);
 	     }
