@@ -238,11 +238,13 @@ FX_ripple_timeout(int val, void *data)
 
 	fx_ripple_win = desks.desk[desks.current].win;
 	if ((desks.current == 0) && (ird))
-	   fx_ripple_above = ECreatePixmap(disp, fx_ripple_win, root.w,
-					   fx_ripple_waterh * 2, ird->x.depth);
+	   fx_ripple_above =
+	      ECreatePixmap(disp, fx_ripple_win, root.w, fx_ripple_waterh * 2,
+			    ird->x.depth);
 	else
-	   fx_ripple_above = ECreatePixmap(disp, fx_ripple_win, root.w,
-					   fx_ripple_waterh * 2, id->x.depth);
+	   fx_ripple_above =
+	      ECreatePixmap(disp, fx_ripple_win, root.w, fx_ripple_waterh * 2,
+			    id->x.depth);
 	if (gc)
 	   XFreeGC(disp, gc);
 	if (gc1)
@@ -252,9 +254,7 @@ FX_ripple_timeout(int val, void *data)
 	gc1 = XCreateGC(disp, fx_ripple_win, 0L, &gcv);
 	if (!before)
 	   DIALOG_OK(_("Starting up Ripples FX..."),
-		     _("\n"
-		       "You have just started the Ripples Effect.\n"
-		       "\n"
+		     _("\n" "You have just started the Ripples Effect.\n" "\n"
 		       "If you look closely on your desktop background, and if it\n"
 		       "doesn't have a solid colour (i.e. has a background texture or\n"
 		       "image), you will see a pool of water at the bottom of your\n"
@@ -265,9 +265,9 @@ FX_ripple_timeout(int val, void *data)
 	before = 1;
      }
    if (fx_ripple_count == 0)
-      XCopyArea(disp, fx_ripple_win, fx_ripple_above, gc,
-		0, root.h - (fx_ripple_waterh * 3),
-		root.w, fx_ripple_waterh * 2, 0, 0);
+      XCopyArea(disp, fx_ripple_win, fx_ripple_above, gc, 0,
+		root.h - (fx_ripple_waterh * 3), root.w, fx_ripple_waterh * 2,
+		0, 0);
    fx_ripple_count++;
    if (fx_ripple_count > 32)
       fx_ripple_count = 0;
@@ -292,8 +292,8 @@ FX_ripple_timeout(int val, void *data)
 	yy = (fx_ripple_waterh * 2) - yoff;
 	aa = p * p * 64 + inch;
 	off = (int)(sin(aa) * 10 * (1 - p));
-	XCopyArea(disp, fx_ripple_above, fx_ripple_win, gc1,
-		  0, yy, root.w, 1, off, root.h - fx_ripple_waterh + y);
+	XCopyArea(disp, fx_ripple_above, fx_ripple_win, gc1, 0, yy, root.w, 1,
+		  off, root.h - fx_ripple_waterh + y);
      }
    DoIn("FX_RIPPLE_TIMEOUT", 0.066, FX_ripple_timeout, 0, NULL);
    return;
@@ -321,8 +321,8 @@ void
 FX_Ripple_Quit(void)
 {
    RemoveTimerEvent("FX_RIPPLE_TIMEOUT");
-   XClearArea(disp, fx_ripple_win,
-	      0, root.h - fx_ripple_waterh, root.w, fx_ripple_waterh, False);
+   XClearArea(disp, fx_ripple_win, 0, root.h - fx_ripple_waterh, root.w,
+	      fx_ripple_waterh, False);
 }
 
 void
@@ -388,13 +388,11 @@ FX_raindrops_timeout(int val, void *data)
 		       _("\n"
 			 "Enlightenment is unable to display raindrops on this\n"
 			 "display because Shared memory is not available on this\n"
-			 "X-Server.\n"
-			 "\n"
+			 "X-Server.\n" "\n"
 			 "This may be due to Enlightenment being a remote client\n"
 			 "running over the network, a MIT-SHM incapable X-server,\n"
 			 "having run out of SHM ID's on the system or Shared\n"
-			 "Memory support being turned off in Imlib\n"
-			 "\n"
+			 "Memory support being turned off in Imlib\n" "\n"
 			 "You may correct this by either running `imlib_config'\n"
 			 "or copying the system imrc (/usr/etc/imrc) to ~/.imrc\n"
 			 "and editing it, enabling shared memory.\n" "\n"));
@@ -406,12 +404,10 @@ FX_raindrops_timeout(int val, void *data)
 		       _("\n"
 			 "Enlightenment is unable to display raindrops on this\n"
 			 "display because shared pixmaps are not available on this\n"
-			 "X-Server.\n"
-			 "\n"
+			 "X-Server.\n" "\n"
 			 "This may be due to either the X-Server not implementing\n"
 			 "shared pixmaps, or shared pixmaps being disabled in\n"
-			 "Imlib's configuration.\n"
-			 "\n"
+			 "Imlib's configuration.\n" "\n"
 			 "You may correct this by either running `imlib_config'\n"
 			 "or copying the system imrc (/usr/etc/imrc) to ~/.imrc\n"
 			 "and editing it, enabling shared pixmaps.\n" "\n"));
@@ -419,8 +415,7 @@ FX_raindrops_timeout(int val, void *data)
 	  }
 	if (!before)
 	   DIALOG_OK(_("Starting up Raindrops FX..."),
-		     _("\n"
-		       "You have just started the Raindrops Effect.\n"
+		     _("\n" "You have just started the Raindrops Effect.\n"
 		       "\n"
 		       "If you look closely on your desktop background, and if it\n"
 		       "doesn't have a solid colour (i.e. has a background texture or\n"
@@ -457,15 +452,15 @@ FX_raindrops_timeout(int val, void *data)
 	gcv.subwindow_mode = IncludeInferiors;
 	gc = XCreateGC(disp, fx_raindrops_win, GCSubwindowMode, &gcv);
 	gc1 = XCreateGC(disp, fx_raindrops_win, 0L, &gcv);
-	fx_raindrops_draw = ECreatePixImg(fx_raindrops_win,
-					  fx_raindrop_size, fx_raindrop_size);
+	fx_raindrops_draw =
+	   ECreatePixImg(fx_raindrops_win, fx_raindrop_size, fx_raindrop_size);
 	if (!fx_raindrops_draw)
 	   return;
 	for (i = 0; i < fx_raindrops_number; i++)
 	  {
-	     fx_raindrops[i].buf = ECreatePixImg(fx_raindrops_win,
-						 fx_raindrop_size,
-						 fx_raindrop_size);
+	     fx_raindrops[i].buf =
+		ECreatePixImg(fx_raindrops_win, fx_raindrop_size,
+			      fx_raindrop_size);
 	     if (fx_raindrops[i].buf)
 		XShmGetImage(disp, fx_raindrops_win, fx_raindrops[i].buf->xim,
 			     fx_raindrops[i].x, fx_raindrops[i].y, 0xffffffff);
@@ -481,9 +476,9 @@ FX_raindrops_timeout(int val, void *data)
 	     int                 j, count = 0;
 	     char                intersect = 1;
 
-	     XClearArea(disp, fx_raindrops_win,
-			fx_raindrops[i].x, fx_raindrops[i].y,
-			fx_raindrop_size, fx_raindrop_size, False);
+	     XClearArea(disp, fx_raindrops_win, fx_raindrops[i].x,
+			fx_raindrops[i].y, fx_raindrop_size, fx_raindrop_size,
+			False);
 	     fx_raindrops[i].count = 0;
 	     while (intersect)
 	       {
@@ -505,9 +500,9 @@ FX_raindrops_timeout(int val, void *data)
 			  fx_raindrops[i].y = root.h - fx_raindrop_size;
 		       if (i != j)
 			 {
-			    if (((fx_raindrops[i].x >= fx_raindrops[j].x) &&
-				 (fx_raindrops[i].x <
-				  fx_raindrops[j].x + fx_raindrop_size)
+			    if (((fx_raindrops[i].x >= fx_raindrops[j].x)
+				 && (fx_raindrops[i].x <
+				     fx_raindrops[j].x + fx_raindrop_size)
 				 && (fx_raindrops[i].y >= fx_raindrops[j].y)
 				 && (fx_raindrops[i].y <
 				     fx_raindrops[j].y + fx_raindrop_size))
@@ -593,9 +588,9 @@ FX_raindrops_timeout(int val, void *data)
 		    }
 	       }
 	  }
-	XShmPutImage(disp, fx_raindrops_win, gc1, fx_raindrops_draw->xim,
-		     0, 0, fx_raindrops[i].x, fx_raindrops[i].y,
-		     fx_raindrop_size, fx_raindrop_size, False);
+	XShmPutImage(disp, fx_raindrops_win, gc1, fx_raindrops_draw->xim, 0, 0,
+		     fx_raindrops[i].x, fx_raindrops[i].y, fx_raindrop_size,
+		     fx_raindrop_size, False);
 	XSync(disp, False);
      }
    DoIn("FX_RAINDROPS_TIMEOUT", (0.066 /*/ (float)fx_raindrops_number */ ),
@@ -635,8 +630,7 @@ FX_Raindrops_Quit(void)
    RemoveTimerEvent("FX_RAINDROPS_TIMEOUT");
    for (i = 0; i < fx_raindrops_number; i++)
      {
-	XClearArea(disp, fx_raindrops_win,
-		   fx_raindrops[i].x, fx_raindrops[i].y,
+	XClearArea(disp, fx_raindrops_win, fx_raindrops[i].x, fx_raindrops[i].y,
 		   fx_raindrop_size, fx_raindrop_size, False);
 	if (fx_raindrops[i].buf)
 	   EDestroyPixImg(fx_raindrops[i].buf);
@@ -700,11 +694,13 @@ FX_Wave_timeout(int val, void *data)
 
 	fx_wave_win = desks.desk[desks.current].win;
 	if ((desks.current == 0) && (ird))
-	   fx_wave_above = XCreatePixmap(disp, fx_wave_win, root.w,
-					 FX_WAVE_WATERH * 2, ird->x.depth);
+	   fx_wave_above =
+	      XCreatePixmap(disp, fx_wave_win, root.w, FX_WAVE_WATERH * 2,
+			    ird->x.depth);
 	else
-	   fx_wave_above = XCreatePixmap(disp, fx_wave_win, root.w,
-					 FX_WAVE_WATERH * 2, id->x.depth);
+	   fx_wave_above =
+	      XCreatePixmap(disp, fx_wave_win, root.w, FX_WAVE_WATERH * 2,
+			    id->x.depth);
 	if (gc)
 	   XFreeGC(disp, gc);
 	if (gc1)
@@ -714,9 +710,7 @@ FX_Wave_timeout(int val, void *data)
 	gc1 = XCreateGC(disp, fx_wave_win, 0L, &gcv);
 	if (!before)
 	   DIALOG_OK(_("Starting up Waves FX..."),
-		     _("\n"
-		       "You have just started the Waves Effect.\n"
-		       "\n"
+		     _("\n" "You have just started the Waves Effect.\n" "\n"
 		       "If you look closely on your desktop background, and if it\n"
 		       "doesn't have a solid colour (i.e. has a background texture or\n"
 		       "image), you will see a pool of water at the bottom of your\n"
@@ -730,9 +724,9 @@ FX_Wave_timeout(int val, void *data)
    /* On the zero, grab the desktop again. */
    if (fx_wave_count == 0)
      {
-	XCopyArea(disp, fx_wave_win, fx_wave_above, gc,
-		  0, root.h - (FX_WAVE_WATERH * 3),
-		  root.w, FX_WAVE_WATERH * 2, 0, 0);
+	XCopyArea(disp, fx_wave_win, fx_wave_above, gc, 0,
+		  root.h - (FX_WAVE_WATERH * 3), root.w, FX_WAVE_WATERH * 2, 0,
+		  0);
      }
 
    /* Increment and roll the counter */
@@ -756,9 +750,9 @@ FX_Wave_timeout(int val, void *data)
    /* Copy the area to correct bugs */
    if (fx_wave_count == 0)
      {
-	XCopyArea(disp, fx_wave_above, fx_wave_win, gc1,
-		  0, root.h - FX_WAVE_GRABH,
-		  root.w, FX_WAVE_DEPTH * 2, 0, root.h - FX_WAVE_GRABH);
+	XCopyArea(disp, fx_wave_above, fx_wave_win, gc1, 0,
+		  root.h - FX_WAVE_GRABH, root.w, FX_WAVE_DEPTH * 2, 0,
+		  root.h - FX_WAVE_GRABH);
      }
 
    /* Go through the bottom couple (FX_WAVE_WATERH) lines of the window */
@@ -834,8 +828,8 @@ void
 FX_Waves_Quit(void)
 {
    RemoveTimerEvent("FX_WAVE_TIMEOUT");
-   XClearArea(disp, fx_wave_win,
-	      0, root.h - FX_WAVE_WATERH, root.w, FX_WAVE_WATERH, False);
+   XClearArea(disp, fx_wave_win, 0, root.h - FX_WAVE_WATERH, root.w,
+	      FX_WAVE_WATERH, False);
 }
 
 void
@@ -880,8 +874,7 @@ FX_imagespinner_timeout(int val, void *data)
 	   fx_imagespinner_imd = id;
 	if (!before)
 	   DIALOG_OK(_("Starting up imagespinners FX..."),
-		     _("\n"
-		       "You have just started the imagespinners Effect.\n"
+		     _("\n" "You have just started the imagespinners Effect.\n"
 		       "\n"
 		       "To disable this effect just select this option again to toggle\n"
 		       "it off.\n"));
@@ -909,8 +902,8 @@ FX_imagespinner_timeout(int val, void *data)
 	     sscanf(fx_imagespinner_params, "%*s %i %i ", &x, &y);
 	     x = ((root.w * x) >> 10) - ((w * x) >> 10);
 	     y = ((root.h * y) >> 10) - ((h * y) >> 10);
-	     Imlib_paste_image(fx_imagespinner_imd, im,
-			       fx_imagespinner_win, x, y, w, h);
+	     Imlib_paste_image(fx_imagespinner_imd, im, fx_imagespinner_win, x,
+			       y, w, h);
 	     Imlib_destroy_image(fx_imagespinner_imd, im);
 	  }
 	Efree(string);
