@@ -242,16 +242,20 @@ RemoveEwinFromGroup(EWin * ewin, Group * g)
 				 if ((ewin->x + ewin->border->border.left + 1) >
 				     root.w)
 				    x = root.w - ewin->border->border.left - 1;
-				 else if ((ewin->x + ewin->w -
-					   ewin->border->border.right - 1) < 0)
+				 else
+				    if (
+					(ewin->x + ewin->w -
+					 ewin->border->border.right - 1) < 0)
 				    x =
 				       0 - ewin->w +
 				       ewin->border->border.right + 1;
 				 if ((ewin->y + ewin->border->border.top + 1) >
 				     root.h)
 				    y = root.h - ewin->border->border.top - 1;
-				 else if ((ewin->y + ewin->h -
-					   ewin->border->border.bottom - 1) < 0)
+				 else
+				    if (
+					(ewin->y + ewin->h -
+					 ewin->border->border.bottom - 1) < 0)
 				    y =
 				       0 - ewin->h +
 				       ewin->border->border.bottom + 1;
@@ -392,8 +396,8 @@ SaveGroups(void)
 	FILE               *f;
 	char                s[1024];
 
-	Esnprintf(s, sizeof(s), "%s/...e_session-XXXXXX.groups.%i",
-		  UserEDir(), root.scr);
+	Esnprintf(s, sizeof(s), "%s/...e_session-XXXXXX.groups.%i", UserEDir(),
+		  root.scr);
 	f = fopen(s, "w");
 	if (f)
 	  {
@@ -437,8 +441,8 @@ LoadGroups(void)
    FILE               *f;
    char                s[1024];
 
-   Esnprintf(s, sizeof(s), "%s/...e_session-XXXXXX.groups.%i",
-	     UserEDir(), root.scr);
+   Esnprintf(s, sizeof(s), "%s/...e_session-XXXXXX.groups.%i", UserEDir(),
+	     root.scr);
    f = fopen(s, "r");
    if (f)
      {
