@@ -1,3 +1,4 @@
+
 /*
  * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
  *
@@ -382,9 +383,10 @@ ICCCM_Adopt(EWin * ewin, Window win)
      }
    EReparentWindow(disp, win, ewin->win_container, 0, 0);
    XGetWindowAttributes(disp, win, &att);
-   XSelectInput(disp, win, att.your_event_mask | PropertyChangeMask |
-		EnterWindowMask | LeaveWindowMask | FocusChangeMask |
-		ResizeRedirectMask | StructureNotifyMask | ColormapChangeMask);
+   XSelectInput(disp, win,
+		att.your_event_mask | PropertyChangeMask | EnterWindowMask |
+		LeaveWindowMask | FocusChangeMask | ResizeRedirectMask |
+		StructureNotifyMask | ColormapChangeMask);
    XShapeSelectInput(disp, win, ShapeNotifyMask);
    if (!a)
       a = XInternAtom(disp, "WM_STATE", False);
@@ -662,8 +664,8 @@ ICCCM_GetGeoms(EWin * ewin, Atom atom_change)
 	  {
 	     if ((hint.min_aspect.y > 0.0) && (hint.min_aspect.x > 0.0))
 	       {
-		  ewin->client.aspect_min = ((double)hint.min_aspect.x) /
-		     ((double)hint.min_aspect.y);
+		  ewin->client.aspect_min =
+		     ((double)hint.min_aspect.x) / ((double)hint.min_aspect.y);
 	       }
 	     else
 	       {
@@ -671,8 +673,8 @@ ICCCM_GetGeoms(EWin * ewin, Atom atom_change)
 	       }
 	     if ((hint.max_aspect.y > 0.0) && (hint.max_aspect.x > 0.0))
 	       {
-		  ewin->client.aspect_max = ((double)hint.max_aspect.x) /
-		     ((double)hint.max_aspect.y);
+		  ewin->client.aspect_max =
+		     ((double)hint.max_aspect.x) / ((double)hint.max_aspect.y);
 	       }
 	     else
 	       {
@@ -694,10 +696,6 @@ ICCCM_GetGeoms(EWin * ewin, Atom atom_change)
 	     ewin->client.base_w = ewin->client.width.min;
 	     ewin->client.base_h = ewin->client.height.min;
 	  }
-	if (ewin->client.base_w < 1)
-	   ewin->client.base_w = 1;
-	if (ewin->client.base_h < 1)
-	   ewin->client.base_h = 1;
 	if (ewin->client.width.min < ewin->client.base_w)
 	   ewin->client.width.min = ewin->client.base_w;
 	if (ewin->client.height.min < ewin->client.base_h)
@@ -821,8 +819,8 @@ ICCCM_GetInfo(EWin * ewin, Atom atom_change)
 	       {
 		  for (i = 0; i < lnum; i++)
 		    {
-		       if ((lst[i] != ewin) &&
-			   (lst[i]->client.group == ewin->client.group))
+		       if ((lst[i] != ewin)
+			   && (lst[i]->client.group == ewin->client.group))
 			 {
 			    ok = 0;
 			    i = lnum;
@@ -978,9 +976,8 @@ ICCCM_GetInfo(EWin * ewin, Atom atom_change)
 	s = NULL;
 	if (!a2)
 	   a2 = XInternAtom(disp, "WM_WINDOW_ROLE", False);
-	XGetWindowProperty(disp, ewin->client.win, a2, 0, 10, False,
-			   XA_STRING, &a3, &dummy, &lnum, &ldummy,
-			   (unsigned char **)&s);
+	XGetWindowProperty(disp, ewin->client.win, a2, 0, 10, False, XA_STRING,
+			   &a3, &dummy, &lnum, &ldummy, (unsigned char **)&s);
 	num = (int)lnum;
 	if (s)
 	  {
@@ -1029,11 +1026,11 @@ ICCCM_GetHints(EWin * ewin, Atom atom_change)
 	if ((hint->flags & StateHint)
 	    && (hint->initial_state == WithdrawnState))
 	  {
-	     if (hint->flags & (StateHint | IconWindowHint |
-				IconPositionHint | WindowGroupHint))
+	     if (hint->flags & (StateHint | IconWindowHint | IconPositionHint |
+				WindowGroupHint))
 	       {
-		  if ((hint->icon_x == 0) && (hint->icon_y == 0) &&
-		      hint->window_group == ewin->client.win)
+		  if ((hint->icon_x == 0) && (hint->icon_y == 0)
+		      && hint->window_group == ewin->client.win)
 		     ewin->docked = 1;
 	       }
 	  }
@@ -1192,13 +1189,13 @@ ICCCM_GetShapeInfo(EWin * ewin)
    if (rn < 1)
      {
 	ewin->client.shaped = 0;
-	EShapeCombineMask(disp, ewin->win_container, ShapeBounding, 0, 0,
-			  None, ShapeSet);
+	EShapeCombineMask(disp, ewin->win_container, ShapeBounding, 0, 0, None,
+			  ShapeSet);
      }
    else if (rn == 1)
      {
-	if ((rl[0].x <= 0) && (rl[0].y <= 0) &&
-	    (rl[0].width >= w) && (rl[0].height >= h))
+	if ((rl[0].x <= 0) && (rl[0].y <= 0) && (rl[0].width >= w)
+	    && (rl[0].height >= h))
 	  {
 	     ewin->client.shaped = 0;
 	     EShapeCombineMask(disp, ewin->win_container, ShapeBounding, 0, 0,
@@ -1263,8 +1260,8 @@ ICCCM_SetEInfo(EWin * ewin)
    c[5] = ewin->shaded;
    c[6] = ewin->client.w;
    c[7] = ewin->client.h;
-   XChangeProperty(disp, ewin->client.win, a, XA_CARDINAL, 32,
-		   PropModeReplace, (unsigned char *)c, 9);
+   XChangeProperty(disp, ewin->client.win, a, XA_CARDINAL, 32, PropModeReplace,
+		   (unsigned char *)c, 9);
    XChangeProperty(disp, ewin->client.win, aa, XA_STRING, 8, PropModeReplace,
 		   (unsigned char *)ewin->border->name,
 		   strlen(ewin->border->name) + 1);
@@ -1300,8 +1297,8 @@ ICCCM_GetMainEInfo(void)
    int                 num, dummy, i;
 
    a = XInternAtom(disp, "ENL_INTERNAL_AREA_DATA", False);
-   XGetWindowProperty(disp, root.win, a, 0, 10, False, XA_CARDINAL,
-		      &a2, &dummy, &lnum, &ldummy, (unsigned char **)&c);
+   XGetWindowProperty(disp, root.win, a, 0, 10, False, XA_CARDINAL, &a2,
+		      &dummy, &lnum, &ldummy, (unsigned char **)&c);
    num = (int)lnum;
    if ((num > 0) && (c))
      {
@@ -1319,8 +1316,8 @@ ICCCM_GetMainEInfo(void)
    c = NULL;
 
    a = XInternAtom(disp, "ENL_INTERNAL_DESK_DATA", False);
-   XGetWindowProperty(disp, root.win, a, 0, 10, False, XA_CARDINAL,
-		      &a2, &dummy, &lnum, &ldummy, (unsigned char **)&c);
+   XGetWindowProperty(disp, root.win, a, 0, 10, False, XA_CARDINAL, &a2,
+		      &dummy, &lnum, &ldummy, (unsigned char **)&c);
    num = (int)lnum;
    if ((num > 0) && (c))
      {
@@ -1346,8 +1343,8 @@ ICCCM_GetEInfo(EWin * ewin)
       a = XInternAtom(disp, "ENL_INTERNAL_DATA", False);
    if (!aa)
       aa = XInternAtom(disp, "ENL_INTERNAL_DATA_BORDER", False);
-   XGetWindowProperty(disp, ewin->client.win, a, 0, 10, True, XA_CARDINAL,
-		      &a2, &dummy, &lnum, &ldummy, (unsigned char **)&c);
+   XGetWindowProperty(disp, ewin->client.win, a, 0, 10, True, XA_CARDINAL, &a2,
+		      &dummy, &lnum, &ldummy, (unsigned char **)&c);
    num = (int)lnum;
    if ((num >= 8) && (c))
      {
@@ -1381,8 +1378,9 @@ ICCCM_GetEInfo(EWin * ewin)
 	       {
 		  Border             *b = NULL;
 
-		  b = (Border *) FindItem(str, 0,
-					  LIST_FINDBY_NAME, LIST_TYPE_BORDER);
+		  b =
+		     (Border *) FindItem(str, 0, LIST_FINDBY_NAME,
+					 LIST_TYPE_BORDER);
 		  if ((ewin->border) && (strcmp(ewin->border->name, b->name)))
 		     b = NULL;
 		  if (b)
