@@ -348,15 +348,18 @@ IclassPopulate(ImageClass * iclass)
 
    if (!iclass->colmod)
      {
-	cm = (ColorModifierClass *) FindItem("ICLASS", 0, LIST_FINDBY_NAME,
-					     LIST_TYPE_COLORMODIFIER);
+	cm =
+	   (ColorModifierClass *) FindItem("ICLASS", 0, LIST_FINDBY_NAME,
+					   LIST_TYPE_COLORMODIFIER);
 	if (!cm)
-	   cm = (ColorModifierClass *) FindItem("DEFAULT", 0, LIST_FINDBY_NAME,
-						LIST_TYPE_COLORMODIFIER);
+	   cm =
+	      (ColorModifierClass *) FindItem("DEFAULT", 0, LIST_FINDBY_NAME,
+					      LIST_TYPE_COLORMODIFIER);
 	iclass->colmod = cm;
      }
-   cm = (ColorModifierClass *) FindItem("NORMAL", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_COLORMODIFIER);
+   cm =
+      (ColorModifierClass *) FindItem("NORMAL", 0, LIST_FINDBY_NAME,
+				      LIST_TYPE_COLORMODIFIER);
    if (!cm)
       cm = iclass->colmod;
    if (!iclass->norm.normal->colmod)
@@ -391,8 +394,9 @@ IclassPopulate(ImageClass * iclass)
 	     cm->ref_count++;
 	  }
      }
-   cm = (ColorModifierClass *) FindItem("ACTIVE", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_COLORMODIFIER);
+   cm =
+      (ColorModifierClass *) FindItem("ACTIVE", 0, LIST_FINDBY_NAME,
+				      LIST_TYPE_COLORMODIFIER);
    if (!cm)
       cm = iclass->colmod;
    if (!iclass->active.normal->colmod)
@@ -427,8 +431,9 @@ IclassPopulate(ImageClass * iclass)
 	     cm->ref_count++;
 	  }
      }
-   cm = (ColorModifierClass *) FindItem("STICKY", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_COLORMODIFIER);
+   cm =
+      (ColorModifierClass *) FindItem("STICKY", 0, LIST_FINDBY_NAME,
+				      LIST_TYPE_COLORMODIFIER);
    if (!cm)
       cm = iclass->colmod;
    if (!iclass->sticky.normal->colmod)
@@ -463,8 +468,9 @@ IclassPopulate(ImageClass * iclass)
 	     cm->ref_count++;
 	  }
      }
-   cm = (ColorModifierClass *) FindItem("STICKY_ACTIVE", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_COLORMODIFIER);
+   cm =
+      (ColorModifierClass *) FindItem("STICKY_ACTIVE", 0, LIST_FINDBY_NAME,
+				      LIST_TYPE_COLORMODIFIER);
    if (!cm)
       cm = iclass->colmod;
    if (!iclass->sticky_active.normal->colmod)
@@ -504,8 +510,8 @@ IclassPopulate(ImageClass * iclass)
 }
 
 void
-IclassApply(ImageClass * iclass, Window win, int w, int h,
-	    int active, int sticky, int state, char expose)
+IclassApply(ImageClass * iclass, Window win, int w, int h, int active,
+	    int sticky, int state, char expose)
 {
    ImageState         *is;
 
@@ -679,8 +685,8 @@ IclassApply(ImageClass * iclass, Window win, int w, int h,
 			    if (pmap)
 			      {
 				 ESetWindowBackgroundPixmap(disp, win, pmap);
-				 EShapeCombineMask(disp, win, ShapeBounding,
-						   0, 0, mask, ShapeSet);
+				 EShapeCombineMask(disp, win, ShapeBounding, 0,
+						   0, mask, ShapeSet);
 				 Imlib_free_pixmap(id, pmap);
 			      }
 			 }
@@ -725,13 +731,15 @@ IclassApply(ImageClass * iclass, Window win, int w, int h,
 				 gcv.ts_x_origin = 0;
 				 gcv.ts_y_origin = 0;
 				 tm = ECreatePixmap(disp, win, w, h, 1);
-				 gc = XCreateGC(disp, tm, GCFillStyle | GCTile |
-						GCTileStipXOrigin |
-						GCTileStipYOrigin, &gcv);
+				 gc =
+				    XCreateGC(disp, tm,
+					      GCFillStyle | GCTile |
+					      GCTileStipXOrigin |
+					      GCTileStipYOrigin, &gcv);
 				 XFillRectangle(disp, tm, gc, 0, 0, w, h);
 				 XFreeGC(disp, gc);
-				 EShapeCombineMask(disp, win, ShapeBounding,
-						   0, 0, tm, ShapeSet);
+				 EShapeCombineMask(disp, win, ShapeBounding, 0,
+						   0, tm, ShapeSet);
 				 EFreePixmap(disp, tm);
 			      }
 			    ESetWindowBackgroundPixmap(disp, win, pmap);
@@ -1025,9 +1033,10 @@ IclassApplyCopy(ImageClass * iclass, Window win, int w, int h, int active,
 		       gcv.tile = pmap;
 		       gcv.ts_x_origin = 0;
 		       gcv.ts_y_origin = 0;
-		       gc = XCreateGC(disp, tp, GCFillStyle | GCTile |
-				      GCTileStipXOrigin | GCTileStipYOrigin,
-				      &gcv);
+		       gc =
+			  XCreateGC(disp, tp,
+				    GCFillStyle | GCTile | GCTileStipXOrigin |
+				    GCTileStipYOrigin, &gcv);
 		       XFillRectangle(disp, tp, gc, 0, 0, w, h);
 		       XFreeGC(disp, gc);
 		       if ((mret) && (mask))
@@ -1036,9 +1045,11 @@ IclassApplyCopy(ImageClass * iclass, Window win, int w, int h, int active,
 			    gcv.tile = mask;
 			    gcv.ts_x_origin = 0;
 			    gcv.ts_y_origin = 0;
-			    gc = XCreateGC(disp, tm, GCFillStyle | GCTile |
-					   GCTileStipXOrigin |
-					   GCTileStipYOrigin, &gcv);
+			    gc =
+			       XCreateGC(disp, tm,
+					 GCFillStyle | GCTile |
+					 GCTileStipXOrigin | GCTileStipYOrigin,
+					 &gcv);
 			    XFillRectangle(disp, tm, gc, 0, 0, w, h);
 			    XFreeGC(disp, gc);
 			 }
