@@ -31,8 +31,8 @@ void
 IB_Animate(char iconify, EWin * from, EWin * to)
 {
    double              t1, t2, t, i, spd, ii;
-   int                 x, y, x1, y1, x2, y2, x3, y3, x4, y4, w, h, fx, fy,
-      fw, fh, dx, dy, dw, dh;
+   int                 x, y, x1, y1, x2, y2, x3, y3, x4, y4, w, h, fx, fy, fw,
+      fh, dx, dy, dw, dh;
    GC                  gc;
    XGCValues           gcv;
 
@@ -45,8 +45,9 @@ IB_Animate(char iconify, EWin * from, EWin * to)
    gcv.foreground = WhitePixel(disp, root.scr);
    if (gcv.foreground == 0)
       gcv.foreground = BlackPixel(disp, root.scr);
-   gc = XCreateGC(disp, root.win, GCFunction | GCForeground | GCSubwindowMode,
-		  &gcv);
+   gc =
+      XCreateGC(disp, root.win, GCFunction | GCForeground | GCSubwindowMode,
+		&gcv);
    t1 = GetTime();
    if (iconify)
      {
@@ -443,18 +444,24 @@ CreateIconbox(char *name)
    ib->scrollbar_win = ECreateWindow(ib->scroll_win, 122, 26, 6, 6, 0);
    ib->scrollbarknob_win = ECreateWindow(ib->scrollbar_win, -20, -20, 4, 4, 0);
    ib->pmap = ECreatePixmap(disp, ib->icon_win, 128, 32, id->x.depth);
-   XSelectInput(disp, ib->icon_win, EnterWindowMask | LeaveWindowMask |
-		ButtonPressMask | ButtonReleaseMask | PointerMotionMask);
-   XSelectInput(disp, ib->scroll_win, EnterWindowMask | LeaveWindowMask |
-		ButtonPressMask | ButtonReleaseMask);
-   XSelectInput(disp, ib->cover_win, EnterWindowMask | LeaveWindowMask |
-		ButtonPressMask | ButtonReleaseMask);
-   XSelectInput(disp, ib->arrow1_win, EnterWindowMask | LeaveWindowMask |
-		ButtonPressMask | ButtonReleaseMask);
-   XSelectInput(disp, ib->arrow2_win, EnterWindowMask | LeaveWindowMask |
-		ButtonPressMask | ButtonReleaseMask);
-   XSelectInput(disp, ib->scrollbar_win, EnterWindowMask | LeaveWindowMask |
-		ButtonPressMask | ButtonReleaseMask | PointerMotionMask);
+   XSelectInput(disp, ib->icon_win,
+		EnterWindowMask | LeaveWindowMask | ButtonPressMask |
+		ButtonReleaseMask | PointerMotionMask);
+   XSelectInput(disp, ib->scroll_win,
+		EnterWindowMask | LeaveWindowMask | ButtonPressMask |
+		ButtonReleaseMask);
+   XSelectInput(disp, ib->cover_win,
+		EnterWindowMask | LeaveWindowMask | ButtonPressMask |
+		ButtonReleaseMask);
+   XSelectInput(disp, ib->arrow1_win,
+		EnterWindowMask | LeaveWindowMask | ButtonPressMask |
+		ButtonReleaseMask);
+   XSelectInput(disp, ib->arrow2_win,
+		EnterWindowMask | LeaveWindowMask | ButtonPressMask |
+		ButtonReleaseMask);
+   XSelectInput(disp, ib->scrollbar_win,
+		EnterWindowMask | LeaveWindowMask | ButtonPressMask |
+		ButtonReleaseMask | PointerMotionMask);
    EMapWindow(disp, ib->icon_win);
    EMapWindow(disp, ib->scroll_win);
    EMapWindow(disp, ib->arrow1_win);
@@ -530,8 +537,7 @@ ShowIconbox(Iconbox * ib)
 			 LIST_TYPE_ICLASS);
 	     if (ic)
 		extra = ic->padding.left + ic->padding.right;
-	     ib->ewin->client.width.max =
-		ib->ewin->client.width.min =
+	     ib->ewin->client.width.max = ib->ewin->client.width.min =
 		ib->iconsize + ib->scroll_thickness + extra;
 	     ewin->client.no_resize_h = 1;
 	  }
@@ -545,8 +551,7 @@ ShowIconbox(Iconbox * ib)
 			 LIST_TYPE_ICLASS);
 	     if (ic)
 		extra = ic->padding.left + ic->padding.right;
-	     ib->ewin->client.height.max =
-		ib->ewin->client.height.min =
+	     ib->ewin->client.height.max = ib->ewin->client.height.min =
 		ib->iconsize + ib->scroll_thickness + extra;
 	     ewin->client.no_resize_v = 1;
 	  }
@@ -665,8 +670,8 @@ IB_SnapEWin(EWin * ewin)
    ewin->icon_pmap_w = w;
    ewin->icon_pmap_h = h;
    ewin->icon_pmap = ECreatePixmap(disp, ewin->win, w, h, id->x.depth);
-   PagerScaleRect(ewin->icon_pmap, ewin->win,
-		  0, 0, 0, 0, ewin->w, ewin->h, w, h);
+   PagerScaleRect(ewin->icon_pmap, ewin->win, 0, 0, 0, 0, ewin->w, ewin->h, w,
+		  h);
    r = EShapeGetRectangles(disp, ewin->win, ShapeBounding, &rn, &ord);
    ewin->icon_mask = ECreatePixmap(disp, ewin->win, w, h, 1);
    gc = XCreateGC(disp, ewin->icon_mask, 0, &gcv);
@@ -837,8 +842,9 @@ IB_GetEIcon(EWin * ewin)
 		mh = ib->iconsize;
 		if (ib->draw_icon_base)
 		  {
-		     ic = FindItem("DEFAULT_ICON_BUTTON", 0, LIST_FINDBY_NAME,
-				   LIST_TYPE_ICLASS);
+		     ic =
+			FindItem("DEFAULT_ICON_BUTTON", 0, LIST_FINDBY_NAME,
+				 LIST_TYPE_ICLASS);
 		     if (ic)
 		       {
 			  mw -= ic->padding.left + ic->padding.right;
@@ -1138,13 +1144,15 @@ SelectIconboxForEwin(EWin * ewin)
 	       {
 		  int                 dx, dy, dist;
 
-		  dx = (ib[i]->ewin->x + (ib[i]->ewin->w / 2)) -
-		     (ewin->x + (ewin->w / 2));
-		  dy = (ib[i]->ewin->y + (ib[i]->ewin->h / 2)) -
-		     (ewin->y + (ewin->h / 2));
+		  dx =
+		     (ib[i]->ewin->x + (ib[i]->ewin->w / 2)) - (ewin->x +
+								(ewin->w / 2));
+		  dy =
+		     (ib[i]->ewin->y + (ib[i]->ewin->h / 2)) - (ewin->y +
+								(ewin->h / 2));
 		  dist = (dx * dx) + (dy * dy);
-		  if ((!ib[i]->ewin->sticky) &&
-		      (ib[i]->ewin->desktop != ewin->desktop))
+		  if ((!ib[i]->ewin->sticky)
+		      && (ib[i]->ewin->desktop != ewin->desktop))
 		     dist += (root.w * root.w) + (root.h * root.h);
 		  if (dist < min_dist)
 		    {
@@ -1330,8 +1338,8 @@ IB_FindIcon(Iconbox * ib, int px, int py)
 		     xx += (ib->iconsize - w) / 2;
 		  yy += (ib->iconsize - h) / 2;
 	       }
-	     if ((px >= (xx - 1)) && (py >= (yy - 1)) &&
-		 (px < (xx + w + 1)) && (py < (yy + h + 1)))
+	     if ((px >= (xx - 1)) && (py >= (yy - 1)) && (px < (xx + w + 1))
+		 && (py < (yy + h + 1)))
 		return ewin;
 	  }
 	if (ib->orientation)
@@ -1373,8 +1381,9 @@ IB_DrawScroll(Iconbox * ib)
 	if (ic)
 	  {
 	     bs -= (ic->padding.top + ic->padding.bottom);
-	     bw = ((ib->h - (ic->padding.top + ic->padding.bottom)) *
-		   bs) / ib->max;
+	     bw =
+		((ib->h - (ic->padding.top + ic->padding.bottom)) * bs) /
+		ib->max;
 	  }
 	if (bs < 1)
 	   bs = 1;
@@ -1391,12 +1400,12 @@ IB_DrawScroll(Iconbox * ib)
 	   FindItem("ICONBOX_SCROLLKNOB_VERTICAL", 0, LIST_FINDBY_NAME,
 		    LIST_TYPE_ICLASS);
 	if ((ic) && (bw > ib->knob_length))
-	   EMoveResizeWindow(disp, ib->scrollbarknob_win,
-			     0, (bw - ib->knob_length) / 2,
-			     ib->bar_thickness, ib->knob_length);
+	   EMoveResizeWindow(disp, ib->scrollbarknob_win, 0,
+			     (bw - ib->knob_length) / 2, ib->bar_thickness,
+			     ib->knob_length);
 	else
-	   EMoveResizeWindow(disp, ib->scrollbarknob_win,
-			     -9999, -9999, ib->bar_thickness, ib->knob_length);
+	   EMoveResizeWindow(disp, ib->scrollbarknob_win, -9999, -9999,
+			     ib->bar_thickness, ib->knob_length);
 	if (show_sb)
 	  {
 	     /* fix this area */
@@ -1481,8 +1490,7 @@ IB_DrawScroll(Iconbox * ib)
 		    {
 		       EMapWindow(disp, ib->arrow1_win);
 		       EMapWindow(disp, ib->arrow2_win);
-		       EMoveResizeWindow(disp, ib->arrow1_win,
-					 0, 0,
+		       EMoveResizeWindow(disp, ib->arrow1_win, 0, 0,
 					 ib->scroll_thickness,
 					 ib->arrow_thickness);
 		       EMoveResizeWindow(disp, ib->arrow2_win, 0,
@@ -1499,8 +1507,7 @@ IB_DrawScroll(Iconbox * ib)
 		    {
 		       EMapWindow(disp, ib->arrow1_win);
 		       EMapWindow(disp, ib->arrow2_win);
-		       EMoveResizeWindow(disp, ib->arrow1_win,
-					 0, 0,
+		       EMoveResizeWindow(disp, ib->arrow1_win, 0, 0,
 					 ib->scroll_thickness,
 					 ib->arrow_thickness);
 		       EMoveResizeWindow(disp, ib->arrow2_win, 0,
@@ -1517,8 +1524,8 @@ IB_DrawScroll(Iconbox * ib)
 		    {
 		       EMapWindow(disp, ib->arrow1_win);
 		       EMapWindow(disp, ib->arrow2_win);
-		       EMoveResizeWindow(disp, ib->arrow1_win,
-					 0, ib->h - (ib->arrow_thickness * 2),
+		       EMoveResizeWindow(disp, ib->arrow1_win, 0,
+					 ib->h - (ib->arrow_thickness * 2),
 					 ib->scroll_thickness,
 					 ib->arrow_thickness);
 		       EMoveResizeWindow(disp, ib->arrow2_win, 0,
@@ -1534,8 +1541,8 @@ IB_DrawScroll(Iconbox * ib)
 		    {
 		       EUnmapWindow(disp, ib->arrow1_win);
 		       EUnmapWindow(disp, ib->arrow2_win);
-		       EMoveResizeWindow(disp, ib->scroll_win,
-					 0, 0, ib->scroll_thickness, ib->h);
+		       EMoveResizeWindow(disp, ib->scroll_win, 0, 0,
+					 ib->scroll_thickness, ib->h);
 		    }
 	       }
 	  }
@@ -1622,8 +1629,9 @@ IB_DrawScroll(Iconbox * ib)
 	if (ic)
 	  {
 	     bs -= (ic->padding.left + ic->padding.right);
-	     bw = ((ib->w - (ic->padding.left + ic->padding.right)) *
-		   bs) / ib->max;
+	     bw =
+		((ib->w - (ic->padding.left + ic->padding.right)) * bs) /
+		ib->max;
 	  }
 	if (bs < 1)
 	   bs = 1;
@@ -1641,11 +1649,11 @@ IB_DrawScroll(Iconbox * ib)
 		    LIST_TYPE_ICLASS);
 	if ((ic) && (bw > ib->knob_length))
 	   EMoveResizeWindow(disp, ib->scrollbarknob_win,
-			     (bw - ib->knob_length) / 2, 0,
-			     ib->knob_length, ib->bar_thickness);
+			     (bw - ib->knob_length) / 2, 0, ib->knob_length,
+			     ib->bar_thickness);
 	else
-	   EMoveResizeWindow(disp, ib->scrollbarknob_win,
-			     -9999, -9999, ib->knob_length, ib->bar_thickness);
+	   EMoveResizeWindow(disp, ib->scrollbarknob_win, -9999, -9999,
+			     ib->knob_length, ib->bar_thickness);
 
 	if (show_sb)
 	  {
@@ -1657,8 +1665,8 @@ IB_DrawScroll(Iconbox * ib)
 		    {
 		       EMapWindow(disp, ib->arrow1_win);
 		       EMapWindow(disp, ib->arrow2_win);
-		       EMoveResizeWindow(disp, ib->arrow1_win,
-					 0, ib->h - ib->scroll_thickness,
+		       EMoveResizeWindow(disp, ib->arrow1_win, 0,
+					 ib->h - ib->scroll_thickness,
 					 ib->arrow_thickness,
 					 ib->scroll_thickness);
 		       EMoveResizeWindow(disp, ib->arrow2_win,
@@ -1677,8 +1685,8 @@ IB_DrawScroll(Iconbox * ib)
 		    {
 		       EMapWindow(disp, ib->arrow1_win);
 		       EMapWindow(disp, ib->arrow2_win);
-		       EMoveResizeWindow(disp, ib->arrow1_win,
-					 0, ib->h - ib->scroll_thickness,
+		       EMoveResizeWindow(disp, ib->arrow1_win, 0,
+					 ib->h - ib->scroll_thickness,
 					 ib->arrow_thickness,
 					 ib->scroll_thickness);
 		       EMoveResizeWindow(disp, ib->arrow2_win,
@@ -1717,9 +1725,9 @@ IB_DrawScroll(Iconbox * ib)
 		    {
 		       EUnmapWindow(disp, ib->arrow1_win);
 		       EUnmapWindow(disp, ib->arrow2_win);
-		       EMoveResizeWindow(disp, ib->scroll_win,
-					 0, ib->h - ib->scroll_thickness,
-					 ib->w, ib->scroll_thickness);
+		       EMoveResizeWindow(disp, ib->scroll_win, 0,
+					 ib->h - ib->scroll_thickness, ib->w,
+					 ib->scroll_thickness);
 		    }
 	       }
 	     else
@@ -1730,8 +1738,7 @@ IB_DrawScroll(Iconbox * ib)
 		    {
 		       EMapWindow(disp, ib->arrow1_win);
 		       EMapWindow(disp, ib->arrow2_win);
-		       EMoveResizeWindow(disp, ib->arrow1_win,
-					 0, 0,
+		       EMoveResizeWindow(disp, ib->arrow1_win, 0, 0,
 					 ib->arrow_thickness,
 					 ib->scroll_thickness);
 		       EMoveResizeWindow(disp, ib->arrow2_win,
@@ -1748,8 +1755,7 @@ IB_DrawScroll(Iconbox * ib)
 		    {
 		       EMapWindow(disp, ib->arrow1_win);
 		       EMapWindow(disp, ib->arrow2_win);
-		       EMoveResizeWindow(disp, ib->arrow1_win,
-					 0, 0,
+		       EMoveResizeWindow(disp, ib->arrow1_win, 0, 0,
 					 ib->arrow_thickness,
 					 ib->scroll_thickness);
 		       EMoveResizeWindow(disp, ib->arrow2_win,
@@ -1783,8 +1789,8 @@ IB_DrawScroll(Iconbox * ib)
 		    {
 		       EUnmapWindow(disp, ib->arrow1_win);
 		       EUnmapWindow(disp, ib->arrow2_win);
-		       EMoveResizeWindow(disp, ib->scroll_win,
-					 0, 0, ib->w, ib->scroll_thickness);
+		       EMoveResizeWindow(disp, ib->scroll_win, 0, 0, ib->w,
+					 ib->scroll_thickness);
 		    }
 	       }
 	  }
@@ -1795,9 +1801,9 @@ IB_DrawScroll(Iconbox * ib)
 	     EMoveResizeWindow(disp, ib->arrow2_win, -9999, -9999, 2, 2);
 	  }
 
-	EMoveResizeWindow(disp, ib->scrollbar_win,
-			  bx, (ib->scroll_thickness - ib->bar_thickness) / 2,
-			  bw, ib->bar_thickness);
+	EMoveResizeWindow(disp, ib->scrollbar_win, bx,
+			  (ib->scroll_thickness - ib->bar_thickness) / 2, bw,
+			  ib->bar_thickness);
 
 	ic =
 	   FindItem("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 0, LIST_FINDBY_NAME,
@@ -1939,24 +1945,29 @@ RedrawIconbox(Iconbox * ib)
 		add = ic->padding.top + ic->padding.bottom;
 	     if (ib->ewin->border)
 	       {
-		  if ((ib->ewin->border->border.top +
+		  if (
+		      (ib->ewin->border->border.top +
 		       ib->ewin->border->border.bottom + add) > root.h)
-		     add = root.h - (ib->ewin->border->border.top +
-				     ib->ewin->border->border.bottom);
+		     add =
+			root.h - (ib->ewin->border->border.top +
+				  ib->ewin->border->border.bottom);
 	       }
 	     x = ib->ewin->x;
-	     y = ib->ewin->y +
+	     y =
+		ib->ewin->y +
 		(((ib->ewin->client.h - add) * ib->auto_resize_anchor) >> 10);
 	     w = ib->ewin->client.w;
 	     h = add;
 	     if (ib->ewin->border)
 	       {
-		  if ((ib->ewin->y + ib->ewin->border->border.top +
+		  if (
+		      (ib->ewin->y + ib->ewin->border->border.top +
 		       ib->ewin->border->border.bottom + add) > root.h)
 		    {
 		       x = ib->ewin->x;
-		       y = root.h - (ib->ewin->border->border.top +
-				     ib->ewin->border->border.bottom + add);
+		       y =
+			  root.h - (ib->ewin->border->border.top +
+				    ib->ewin->border->border.bottom + add);
 		       w = ib->ewin->client.w;
 		       h = add;
 		    }
@@ -1971,23 +1982,28 @@ RedrawIconbox(Iconbox * ib)
 		add = ic->padding.left + ic->padding.right;
 	     if (ib->ewin->border)
 	       {
-		  if ((ib->ewin->border->border.left +
+		  if (
+		      (ib->ewin->border->border.left +
 		       ib->ewin->border->border.right + add) > root.w)
-		     add = root.w - (ib->ewin->border->border.left +
-				     ib->ewin->border->border.right);
+		     add =
+			root.w - (ib->ewin->border->border.left +
+				  ib->ewin->border->border.right);
 	       }
-	     x = ib->ewin->x +
+	     x =
+		ib->ewin->x +
 		(((ib->ewin->client.w - add) * ib->auto_resize_anchor) >> 10);
 	     y = ib->ewin->y;
 	     w = add;
 	     h = ib->ewin->client.h;
 	     if (ib->ewin->border)
 	       {
-		  if ((ib->ewin->x + ib->ewin->border->border.left +
+		  if (
+		      (ib->ewin->x + ib->ewin->border->border.left +
 		       ib->ewin->border->border.right + add) > root.w)
 		    {
-		       x = root.w - (ib->ewin->border->border.left +
-				     ib->ewin->border->border.right + add);
+		       x =
+			  root.w - (ib->ewin->border->border.left +
+				    ib->ewin->border->border.right + add);
 		       y = ib->ewin->y;
 		       w = add;
 		       h = ib->ewin->client.h;
@@ -2023,24 +2039,29 @@ RedrawIconbox(Iconbox * ib)
 	     add += ib->max;
 	     if (ib->ewin->border)
 	       {
-		  if ((ib->ewin->border->border.top +
+		  if (
+		      (ib->ewin->border->border.top +
 		       ib->ewin->border->border.bottom + add) > root.h)
-		     add = root.h - (ib->ewin->border->border.top +
-				     ib->ewin->border->border.bottom);
+		     add =
+			root.h - (ib->ewin->border->border.top +
+				  ib->ewin->border->border.bottom);
 	       }
 	     x = ib->ewin->x;
-	     y = ib->ewin->y +
+	     y =
+		ib->ewin->y +
 		(((ib->ewin->client.h - add) * ib->auto_resize_anchor) >> 10);
 	     w = ib->ewin->client.w;
 	     h = add;
 	     if (ib->ewin->border)
 	       {
-		  if ((ib->ewin->y + ib->ewin->border->border.top +
+		  if (
+		      (ib->ewin->y + ib->ewin->border->border.top +
 		       ib->ewin->border->border.bottom + add) > root.h)
 		    {
 		       x = ib->ewin->x;
-		       y = root.h - (ib->ewin->border->border.top +
-				     ib->ewin->border->border.bottom + add);
+		       y =
+			  root.h - (ib->ewin->border->border.top +
+				    ib->ewin->border->border.bottom + add);
 		       w = ib->ewin->client.w;
 		       h = add;
 		    }
@@ -2056,23 +2077,28 @@ RedrawIconbox(Iconbox * ib)
 	     add += ib->max;
 	     if (ib->ewin->border)
 	       {
-		  if ((ib->ewin->border->border.left +
+		  if (
+		      (ib->ewin->border->border.left +
 		       ib->ewin->border->border.right + add) > root.w)
-		     add = root.w - (ib->ewin->border->border.left +
-				     ib->ewin->border->border.right);
+		     add =
+			root.w - (ib->ewin->border->border.left +
+				  ib->ewin->border->border.right);
 	       }
-	     x = ib->ewin->x +
+	     x =
+		ib->ewin->x +
 		(((ib->ewin->client.w - add) * ib->auto_resize_anchor) >> 10);
 	     y = ib->ewin->y;
 	     w = add;
 	     h = ib->ewin->client.h;
 	     if (ib->ewin->border)
 	       {
-		  if ((ib->ewin->x + ib->ewin->border->border.left +
+		  if (
+		      (ib->ewin->x + ib->ewin->border->border.left +
 		       ib->ewin->border->border.right + add) > root.w)
 		    {
-		       x = root.w - (ib->ewin->border->border.left +
-				     ib->ewin->border->border.right + add);
+		       x =
+			  root.w - (ib->ewin->border->border.left +
+				    ib->ewin->border->border.right + add);
 		       y = ib->ewin->y;
 		       w = add;
 		       h = ib->ewin->client.h;
@@ -2080,8 +2106,8 @@ RedrawIconbox(Iconbox * ib)
 	       }
 	  }
 
-	if ((x != ib->ewin->x) || (y != ib->ewin->y) ||
-	    (w != ib->ewin->client.w) || (h != ib->ewin->client.h))
+	if ((x != ib->ewin->x) || (y != ib->ewin->y)
+	    || (w != ib->ewin->client.w) || (h != ib->ewin->client.h))
 	  {
 	     MoveResizeEwin(ib->ewin, x, y, w, h);
 	     EResizeWindow(disp, ib->win, w, h);
@@ -2110,15 +2136,15 @@ RedrawIconbox(Iconbox * ib)
 	if (ib->scrollbar_side == 1)
 	  {
 	     /* right */
-	     EMoveResizeWindow(disp, ib->icon_win,
-			       0, 0, ib->w - ib->scroll_thickness, ib->h);
+	     EMoveResizeWindow(disp, ib->icon_win, 0, 0,
+			       ib->w - ib->scroll_thickness, ib->h);
 	     if (
 		 (ic =
 		  FindItem("ICONBOX_COVER_VERTICAL", 0, LIST_FINDBY_NAME,
 			   LIST_TYPE_ICLASS)) && (!(ib->cover_hide)))
 	       {
-		  EMoveResizeWindow(disp, ib->cover_win,
-				    0, 0, ib->w - ib->scroll_thickness, ib->h);
+		  EMoveResizeWindow(disp, ib->cover_win, 0, 0,
+				    ib->w - ib->scroll_thickness, ib->h);
 		  EMapWindow(disp, ib->cover_win);
 		  IclassApply(ic, ib->cover_win, -1, -1, 0, 0, STATE_NORMAL, 0);
 	       }
@@ -2131,17 +2157,15 @@ RedrawIconbox(Iconbox * ib)
 	else
 	  {
 	     /* left */
-	     EMoveResizeWindow(disp, ib->icon_win,
-			       ib->scroll_thickness, 0,
+	     EMoveResizeWindow(disp, ib->icon_win, ib->scroll_thickness, 0,
 			       ib->w - ib->scroll_thickness, ib->h);
 	     if (
 		 (ic =
 		  FindItem("ICONBOX_COVER_VERTICAL", 0, LIST_FINDBY_NAME,
 			   LIST_TYPE_ICLASS)) && (!(ib->cover_hide)))
 	       {
-		  EMoveResizeWindow(disp, ib->cover_win,
-				    ib->scroll_thickness, 0,
-				    ib->w - ib->scroll_thickness, ib->h);
+		  EMoveResizeWindow(disp, ib->cover_win, ib->scroll_thickness,
+				    0, ib->w - ib->scroll_thickness, ib->h);
 		  EMapWindow(disp, ib->cover_win);
 		  IclassApply(ic, ib->cover_win, -1, -1, 0, 0, STATE_NORMAL, 0);
 	       }
@@ -2216,8 +2240,7 @@ RedrawIconbox(Iconbox * ib)
 						  ib->iconsize);
 		    }
 		  if (ib->draw_icon_base)
-		     PastePixmap(disp, ib->pmap,
-				 ewin->icon_pmap,
+		     PastePixmap(disp, ib->pmap, ewin->icon_pmap,
 				 ewin->icon_mask, x + ((ib->iconsize - w) / 2),
 				 y + ((ib->iconsize - h) / 2));
 		  else
@@ -2242,15 +2265,15 @@ RedrawIconbox(Iconbox * ib)
 	if (ib->scrollbar_side == 1)
 	  {
 	     /* bottom */
-	     EMoveResizeWindow(disp, ib->icon_win,
-			       0, 0, ib->w, ib->h - ib->scroll_thickness);
+	     EMoveResizeWindow(disp, ib->icon_win, 0, 0, ib->w,
+			       ib->h - ib->scroll_thickness);
 	     if (
 		 (ic =
 		  FindItem("ICONBOX_COVER_HORIZONTAL", 0, LIST_FINDBY_NAME,
 			   LIST_TYPE_ICLASS)) && (!(ib->cover_hide)))
 	       {
-		  EMoveResizeWindow(disp, ib->cover_win,
-				    0, 0, ib->w, ib->h - ib->scroll_thickness);
+		  EMoveResizeWindow(disp, ib->cover_win, 0, 0, ib->w,
+				    ib->h - ib->scroll_thickness);
 		  EMapWindow(disp, ib->cover_win);
 		  IclassApply(ic, ib->cover_win, -1, -1, 0, 0, STATE_NORMAL, 0);
 	       }
@@ -2263,17 +2286,16 @@ RedrawIconbox(Iconbox * ib)
 	else
 	  {
 	     /* top */
-	     EMoveResizeWindow(disp, ib->icon_win,
-			       0, ib->scroll_thickness,
+	     EMoveResizeWindow(disp, ib->icon_win, 0, ib->scroll_thickness,
 			       ib->w, ib->h - ib->scroll_thickness);
 	     if (
 		 (ic =
 		  FindItem("ICONBOX_COVER_HORIZONTAL", 0, LIST_FINDBY_NAME,
 			   LIST_TYPE_ICLASS)) && (!(ib->cover_hide)))
 	       {
-		  EMoveResizeWindow(disp, ib->cover_win,
-				    0, ib->scroll_thickness,
-				    ib->w, ib->h - ib->scroll_thickness);
+		  EMoveResizeWindow(disp, ib->cover_win, 0,
+				    ib->scroll_thickness, ib->w,
+				    ib->h - ib->scroll_thickness);
 		  EMapWindow(disp, ib->cover_win);
 		  IclassApply(ic, ib->cover_win, -1, -1, 0, 0, STATE_NORMAL, 0);
 	       }
@@ -2349,8 +2371,7 @@ RedrawIconbox(Iconbox * ib)
 						  ib->iconsize);
 		    }
 		  if (ib->draw_icon_base)
-		     PastePixmap(disp, ib->pmap,
-				 ewin->icon_pmap,
+		     PastePixmap(disp, ib->pmap, ewin->icon_pmap,
 				 ewin->icon_mask, x + ((ib->iconsize - w) / 2),
 				 y + ((ib->iconsize - h) / 2));
 		  else
@@ -2423,8 +2444,8 @@ IB_ShowMenu(Iconbox * ib, int x, int y)
       FindItem("DEFAULT", 0, LIST_FINDBY_NAME, LIST_TYPE_MENU_STYLE);
    Esnprintf(s, sizeof(s), "iconbox %s", ib->name);
    mi =
-      CreateMenuItem(_("This Iconbox Settings..."), NULL, ACTION_CONFIG,
-		     s, NULL);
+      CreateMenuItem(_("This Iconbox Settings..."), NULL, ACTION_CONFIG, s,
+		     NULL);
    AddItemToMenu(p_menu, mi);
    mi = CreateMenuItem(_("Close Iconbox"), NULL, ACTION_KILL, NULL, NULL);
    AddItemToMenu(p_menu, mi);
@@ -2457,8 +2478,7 @@ IB_CompleteRedraw(Iconbox * ib)
 	   FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 	if (ic)
 	   extra = ic->padding.left + ic->padding.right;
-	ib->ewin->client.width.max =
-	   ib->ewin->client.width.min =
+	ib->ewin->client.width.max = ib->ewin->client.width.min =
 	   ib->iconsize + ib->scroll_thickness + extra;
 	ib->ewin->client.no_resize_h = 1;
      }
@@ -2472,8 +2492,7 @@ IB_CompleteRedraw(Iconbox * ib)
 		    LIST_TYPE_ICLASS);
 	if (ic)
 	   extra = ic->padding.left + ic->padding.right;
-	ib->ewin->client.height.max =
-	   ib->ewin->client.height.min =
+	ib->ewin->client.height.max = ib->ewin->client.height.min =
 	   ib->iconsize + ib->scroll_thickness + extra;
 	ib->ewin->client.no_resize_v = 1;
      }
@@ -2694,16 +2713,18 @@ IconboxHandleEvent(XEvent * ev)
 		    {
 		       if (ib[i]->shownames)
 			 {
-			    tt = FindItem("ICONBOX", 0, LIST_FINDBY_NAME,
-					  LIST_TYPE_TOOLTIP);
+			    tt =
+			       FindItem("ICONBOX", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_TOOLTIP);
 			    if (tt)
 			      {
 				 name_ewin = ewin;
 				 HideToolTip(tt);
 				 if (ewin)
 				   {
-				      if ((ewin->client.icon_name) &&
-					  (strlen(ewin->client.icon_name) > 0))
+				      if ((ewin->client.icon_name)
+					  && (strlen(ewin->client.icon_name) >
+					      0))
 					 ShowToolTip(tt, ewin->client.icon_name,
 						     NULL, mode.x, mode.y);
 				      else
@@ -2718,8 +2739,9 @@ IconboxHandleEvent(XEvent * ev)
 	       {
 		  ToolTip            *tt = NULL;
 
-		  tt = FindItem("ICONBOX", 0, LIST_FINDBY_NAME,
-				LIST_TYPE_TOOLTIP);
+		  tt =
+		     FindItem("ICONBOX", 0, LIST_FINDBY_NAME,
+			      LIST_TYPE_TOOLTIP);
 		  if (tt)
 		    {
 		       HideToolTip(tt);
@@ -2746,8 +2768,9 @@ IconboxHandleEvent(XEvent * ev)
 		    {
 		       ToolTip            *tt = NULL;
 
-		       tt = FindItem("ICONBOX", 0, LIST_FINDBY_NAME,
-				     LIST_TYPE_TOOLTIP);
+		       tt =
+			  FindItem("ICONBOX", 0, LIST_FINDBY_NAME,
+				   LIST_TYPE_TOOLTIP);
 		       if (tt)
 			  HideToolTip(tt);
 		       gwins =
