@@ -224,8 +224,8 @@ KDE_NewWindow(EWin * ewin)
      {
 	if (!ewin->kde_hint)
 	  {
-	     XChangeProperty(disp, ewin->client.win, KDE_WIN_TITLE,
-			     XA_STRING, 8, PropModeReplace,
+	     XChangeProperty(disp, ewin->client.win, KDE_WIN_TITLE, XA_STRING,
+			     8, PropModeReplace,
 			     (unsigned char *)ewin->client.title,
 			     strlen(ewin->client.title) + 1);
 
@@ -334,8 +334,8 @@ KDE_AddModule(Window win)
 		ptr = KModules;
 		while (ptr)
 		  {
-		     KDE_ClientMessage(win, KDE_MODULE_DOCKWIN_ADD,
-				       ptr->win, CurrentTime);
+		     KDE_ClientMessage(win, KDE_MODULE_DOCKWIN_ADD, ptr->win,
+				       CurrentTime);
 		     ptr = ptr->next;
 		  }
 	     }
@@ -356,8 +356,7 @@ KDE_AddModule(Window win)
 		{
 		   if (!(lst[i]->internal))
 		     {
-			XChangeProperty(disp, lst[i]->client.win,
-					KDE_WIN_TITLE,
+			XChangeProperty(disp, lst[i]->client.win, KDE_WIN_TITLE,
 					XA_STRING, 8, PropModeReplace,
 					(unsigned char *)lst[i]->client.title,
 					strlen(lst[i]->client.title) + 1);
@@ -377,29 +376,29 @@ KDE_AddModule(Window win)
 			  }
 			if (lst[i]->iconified)
 			  {
-			     if (!getSimpleHint(lst[i]->client.win,
-						KDE_WIN_ICONIFIED))
+			     if (!getSimpleHint
+				 (lst[i]->client.win, KDE_WIN_ICONIFIED))
 				setSimpleHint(lst[i]->client.win,
 					      KDE_WIN_ICONIFIED, 1);
 			  }
 			else
 			  {
-			     if (getSimpleHint(lst[i]->client.win,
-					       KDE_WIN_ICONIFIED))
+			     if (getSimpleHint
+				 (lst[i]->client.win, KDE_WIN_ICONIFIED))
 				setSimpleHint(lst[i]->client.win,
 					      KDE_WIN_ICONIFIED, 0);
 			  }
 			if (lst[i]->toggle)
 			  {
-			     if (!getSimpleHint(lst[i]->client.win,
-						KDE_WIN_MAXIMIZED))
+			     if (!getSimpleHint
+				 (lst[i]->client.win, KDE_WIN_MAXIMIZED))
 				setSimpleHint(lst[i]->client.win,
 					      KDE_WIN_MAXIMIZED, 1);
 			  }
 			else
 			  {
-			     if (getSimpleHint(lst[i]->client.win,
-					       KDE_WIN_MAXIMIZED))
+			     if (getSimpleHint
+				 (lst[i]->client.win, KDE_WIN_MAXIMIZED))
 				setSimpleHint(lst[i]->client.win,
 					      KDE_WIN_MAXIMIZED, 0);
 			  }
@@ -507,9 +506,8 @@ KDE_Init(void)
 
 	KDE_WIN_DESKTOP = XInternAtom(disp, "KWM_WIN_DESKTOP", False);
 
-	KDE_WIN_GEOMETRY_RESTORE = XInternAtom(disp,
-					       "KWM_WIN_GEOMETRY_RESTORE",
-					       False);
+	KDE_WIN_GEOMETRY_RESTORE =
+	   XInternAtom(disp, "KWM_WIN_GEOMETRY_RESTORE", False);
 
 	KDE_WIN_STICKY = XInternAtom(disp, "KWM_WIN_STICKY", False);
 
@@ -519,8 +517,8 @@ KDE_Init(void)
 
 	KDE_WIN_TITLE = XInternAtom(disp, "KWM_WIN_TITLE", False);
 
-	KDE_WIN_ICON_GEOMETRY = XInternAtom(disp, "KWM_WIN_ICON_GEOMETRY",
-					    False);
+	KDE_WIN_ICON_GEOMETRY =
+	   XInternAtom(disp, "KWM_WIN_ICON_GEOMETRY", False);
 
 	KDE_COMMAND = XInternAtom(disp, "KWM_COMMAND", False);
 
@@ -536,8 +534,8 @@ KDE_Init(void)
 
 	KDE_CURRENT_DESKTOP = XInternAtom(disp, "KWM_CURRENT_DESKTOP", False);
 
-	KDE_NUMBER_OF_DESKTOPS = XInternAtom(disp, "KWM_NUMBER_OF_DESKTOPS",
-					     False);
+	KDE_NUMBER_OF_DESKTOPS =
+	   XInternAtom(disp, "KWM_NUMBER_OF_DESKTOPS", False);
 
 	KDE_DOCKWINDOW = XInternAtom(disp, "KWM_DOCKWINDOW", False);
 
@@ -546,22 +544,21 @@ KDE_Init(void)
 	KDE_MODULE = XInternAtom(disp, "KWM_MODULE", False);
 
 	KDE_MODULE_INIT = XInternAtom(disp, "KWM_MODULE_INIT", False);
-	KDE_MODULE_INITIALIZED = XInternAtom(disp, "KWM_MODULE_INITIALIZED",
-					     False);
+	KDE_MODULE_INITIALIZED =
+	   XInternAtom(disp, "KWM_MODULE_INITIALIZED", False);
 
-	KDE_MODULE_DESKTOP_CHANGE = XInternAtom(disp,
-						"KWM_MODULE_DESKTOP_CHANGE",
-						False);
+	KDE_MODULE_DESKTOP_CHANGE =
+	   XInternAtom(disp, "KWM_MODULE_DESKTOP_CHANGE", False);
 	KDE_MODULE_DESKTOP_NAME_CHANGE =
 	   XInternAtom(disp, "KWM_MODULE_DESKTOP_NAME_CHANGE", False);
 	KDE_MODULE_DESKTOP_NUMBER_CHANGE =
 	   XInternAtom(disp, "KWM_MODULE_DESKTOP_NUMBER_CHANGE", False);
 
 	KDE_MODULE_WIN_ADD = XInternAtom(disp, "KWM_MODULE_WIN_ADD", False);
-	KDE_MODULE_WIN_REMOVE = XInternAtom(disp, "KWM_MODULE_WIN_REMOVE",
-					    False);
-	KDE_MODULE_WIN_CHANGE = XInternAtom(disp, "KWM_MODULE_WIN_CHANGE",
-					    False);
+	KDE_MODULE_WIN_REMOVE =
+	   XInternAtom(disp, "KWM_MODULE_WIN_REMOVE", False);
+	KDE_MODULE_WIN_CHANGE =
+	   XInternAtom(disp, "KWM_MODULE_WIN_CHANGE", False);
 	KDE_MODULE_WIN_RAISE = XInternAtom(disp, "KWM_MODULE_WIN_RAISE", False);
 	KDE_MODULE_WIN_LOWER = XInternAtom(disp, "KWM_MODULE_WIN_LOWER", False);
 	KDE_MODULE_WIN_ACTIVATE =
@@ -828,21 +825,25 @@ KDE_GetDecorationHint(Window win, long *dechints)
    switch (*dechints & ~KDE_NO_FOCUS)
      {
      case KDE_NO_DECORATION:
-	b = (Border *) FindItem("BORDERLESS", 0, LIST_FINDBY_NAME,
-				LIST_TYPE_BORDER);
+	b =
+	   (Border *) FindItem("BORDERLESS", 0, LIST_FINDBY_NAME,
+			       LIST_TYPE_BORDER);
 	break;
      case KDE_TINY_DECORATION:
-	b = (Border *) FindItem("TRANSIENT", 0, LIST_FINDBY_NAME,
-				LIST_TYPE_BORDER);
+	b =
+	   (Border *) FindItem("TRANSIENT", 0, LIST_FINDBY_NAME,
+			       LIST_TYPE_BORDER);
 	break;
      case KDE_STANDALONE_MENUBAR:
-	b = (Border *) FindItem("BORDERLESS", 0, LIST_FINDBY_NAME,
-				LIST_TYPE_BORDER);
+	b =
+	   (Border *) FindItem("BORDERLESS", 0, LIST_FINDBY_NAME,
+			       LIST_TYPE_BORDER);
 	ewin->skipfocus = 1;
 	break;
      case KDE_DESKTOP_ICON:
-	b = (Border *) FindItem("BORDERLESS", 0, LIST_FINDBY_NAME,
-				LIST_TYPE_BORDER);
+	b =
+	   (Border *) FindItem("BORDERLESS", 0, LIST_FINDBY_NAME,
+			       LIST_TYPE_BORDER);
 	ewin->skipfocus = 1;
 	ewin->sticky = 1;
 	ewin->layer = 1;
@@ -852,19 +853,22 @@ KDE_GetDecorationHint(Window win, long *dechints)
 	break;
      case KDE_NORMAL_DECORATION:
      default:
-	b = (Border *) FindItem("DEFAULT", 0, LIST_FINDBY_NAME,
-				LIST_TYPE_BORDER);
+	b =
+	   (Border *) FindItem("DEFAULT", 0, LIST_FINDBY_NAME,
+			       LIST_TYPE_BORDER);
 	break;
 
      }
    if (!b)
      {
-	b = (Border *) FindItem("DEFAULT", 0, LIST_FINDBY_NAME,
-				LIST_TYPE_BORDER);
+	b =
+	   (Border *) FindItem("DEFAULT", 0, LIST_FINDBY_NAME,
+			       LIST_TYPE_BORDER);
 	if (!b)
 	  {
-	     b = (Border *) FindItem("__FALLBACK_BORDER", 0, LIST_FINDBY_NAME,
-				     LIST_TYPE_BORDER);
+	     b =
+		(Border *) FindItem("__FALLBACK_BORDER", 0, LIST_FINDBY_NAME,
+				    LIST_TYPE_BORDER);
 
 	  }
      }
@@ -1069,8 +1073,9 @@ KDE_ProcessClientMessage(XClientMessageEvent * event)
 
 	if (ewin)
 	  {
-	     b = (Border *) FindItem("BORDERLESS", 0, LIST_FINDBY_NAME,
-				     LIST_TYPE_BORDER);
+	     b =
+		(Border *) FindItem("BORDERLESS", 0, LIST_FINDBY_NAME,
+				    LIST_TYPE_BORDER);
 
 	     MakeWindowSticky(ewin);
 	     ewin->border_new = 1;
@@ -1190,9 +1195,9 @@ KDE_SetNumDesktops(void)
 
    EDBUG(6, "KDE_SetRootArea");
 
-   if (!(getSimpleHint(root.win, KDE_NUMBER_OF_DESKTOPS)) ||
-       !(*(getSimpleHint(root.win, KDE_NUMBER_OF_DESKTOPS)) ==
-	 mode.numdesktops))
+   if (!(getSimpleHint(root.win, KDE_NUMBER_OF_DESKTOPS))
+       || !(*(getSimpleHint(root.win, KDE_NUMBER_OF_DESKTOPS)) ==
+	    mode.numdesktops))
      {
 	setSimpleHint(root.win, KDE_NUMBER_OF_DESKTOPS, mode.numdesktops);
 	KDE_SendMessagesToModules(KDE_MODULE_DESKTOP_NUMBER_CHANGE,
@@ -1230,8 +1235,9 @@ KDE_HintChange(Atom a)
      }
    else if (a == KDE_NUMBER_OF_DESKTOPS)
      {
-	ChangeNumberOfDesktops(*(getSimpleHint(root.win,
-					       KDE_NUMBER_OF_DESKTOPS)));
+	ChangeNumberOfDesktops(*
+			       (getSimpleHint
+				(root.win, KDE_NUMBER_OF_DESKTOPS)));
      }
    else
      {
@@ -1302,9 +1308,8 @@ KDE_UpdateClient(EWin * ewin)
 
    if (!ewin->internal)
      {
-	XChangeProperty(disp, ewin->client.win, KDE_WIN_TITLE,
-			XA_STRING, 8, PropModeReplace,
-			(unsigned char *)ewin->client.title,
+	XChangeProperty(disp, ewin->client.win, KDE_WIN_TITLE, XA_STRING, 8,
+			PropModeReplace, (unsigned char *)ewin->client.title,
 			strlen(ewin->client.title) + 1);
      }
    if (getSimpleHint(ewin->client.win, KDE_WIN_STICKY))
