@@ -330,8 +330,8 @@ ShowMenu(Menu * m, char noshow)
 	int                 dum;
 	Window              rt, ch;
 
-	XQueryPointer(disp, m->win, &rt, &ch, &(mode.x), &(mode.y),
-		      &dum, &dum, (unsigned int *)&dum);
+	XQueryPointer(disp, m->win, &rt, &ch, &(mode.x), &(mode.y), &dum, &dum,
+		      (unsigned int *)&dum);
      }
 
    wx = 0;
@@ -340,8 +340,9 @@ ShowMenu(Menu * m, char noshow)
      {
 	Border             *b;
 
-	b = (Border *) FindItem(m->style->border_name, 0, LIST_FINDBY_NAME,
-				LIST_TYPE_BORDER);
+	b =
+	   (Border *) FindItem(m->style->border_name, 0, LIST_FINDBY_NAME,
+			       LIST_TYPE_BORDER);
 	if (b)
 	  {
 	     int                 width;
@@ -377,8 +378,9 @@ ShowMenu(Menu * m, char noshow)
 			      {
 				 if (pointer_y >= screens[i].y_org)
 				   {
-				      if (pointer_y <= (screens[i].height +
-							screens[i].y_org))
+				      if (pointer_y <=
+					  (screens[i].height +
+					   screens[i].y_org))
 					{
 					   x_origin = screens[i].x_org;
 					   y_origin = screens[i].y_org;
@@ -616,9 +618,9 @@ DestroyMenu(Menu * m)
 	  {
 	     if (m->items[i]->child)
 	       {
-		  if (FindItem((char *)m->items[i]->child, 0,
-			       LIST_FINDBY_POINTER, LIST_TYPE_MENU))
-		     DestroyMenu(m->items[i]->child);
+		  if (FindItem
+		      ((char *)m->items[i]->child, 0, LIST_FINDBY_POINTER,
+		       LIST_TYPE_MENU)) DestroyMenu(m->items[i]->child);
 	       }
 	     if (m->items[i]->text)
 		Efree(m->items[i]->text);
@@ -765,8 +767,9 @@ RealizeMenu(Menu * m)
    has_s = 0;
    att.event_mask = PointerMotionMask;
    XChangeWindowAttributes(disp, m->win, CWEventMask, &att);
-   att.event_mask = ButtonPressMask | ButtonReleaseMask | EnterWindowMask |
-      LeaveWindowMask | PointerMotionMask;
+   att.event_mask =
+      ButtonPressMask | ButtonReleaseMask | EnterWindowMask | LeaveWindowMask
+      | PointerMotionMask;
    for (i = 0; i < m->num; i++)
      {
 	if (m->items[i]->child)
@@ -791,9 +794,9 @@ RealizeMenu(Menu * m)
 	     im = ELoadImage(m->items[i]->icon_iclass->norm.normal->im_file);
 	     if (im)
 	       {
-		  m->items[i]->icon_win = ECreateWindow(m->items[i]->win, 0, 0,
-							im->rgb_width,
-							im->rgb_height, 0);
+		  m->items[i]->icon_win =
+		     ECreateWindow(m->items[i]->win, 0, 0, im->rgb_width,
+				   im->rgb_height, 0);
 		  EMapWindow(disp, m->items[i]->icon_win);
 		  XChangeWindowAttributes(disp, m->items[i]->icon_win,
 					  CWEventMask, &att);
@@ -881,9 +884,9 @@ RealizeMenu(Menu * m)
 	     m->items[i]->text_w = maxx1;
 	     m->items[i]->text_y = (maxh - m->items[i]->text_h) / 2;
 	     if (m->items[i]->icon_win)
-		EMoveWindow(disp, m->items[i]->icon_win, maxw -
-			    m->style->item_iclass->padding.right - maxx2 +
-			    ((maxx2 - w) / 2), ((maxh - h) / 2));
+		EMoveWindow(disp, m->items[i]->icon_win,
+			    maxw - m->style->item_iclass->padding.right -
+			    maxx2 + ((maxx2 - w) / 2), ((maxh - h) / 2));
 	  }
 	if (m->items[i]->icon_iclass)
 	  {
@@ -1015,15 +1018,15 @@ DrawMenuItem(Menu * m, MenuItem * mi, char shape)
      }
    if ((m->style->tclass) && (mi->text))
      {
-	TextDraw(m->style->tclass, mi->pmap[(int)(mi->state)], 0, 0,
-		 mi->state, mi->text, mi->text_x, mi->text_y, mi->text_w,
-		 mi->text_h, 17, m->style->tclass->justification);
+	TextDraw(m->style->tclass, mi->pmap[(int)(mi->state)], 0, 0, mi->state,
+		 mi->text, mi->text_x, mi->text_y, mi->text_w, mi->text_h, 17,
+		 m->style->tclass->justification);
      }
    if (mi->text)
      {
 	ESetWindowBackgroundPixmap(disp, mi->win, mi->pmap[(int)(mi->state)]);
-	EShapeCombineMask(disp, mi->win, ShapeBounding,
-			  0, 0, mi->mask[(int)(mi->state)], ShapeSet);
+	EShapeCombineMask(disp, mi->win, ShapeBounding, 0, 0,
+			  mi->mask[(int)(mi->state)], ShapeSet);
 	XClearWindow(disp, mi->win);
      }
    else
@@ -1038,8 +1041,8 @@ DrawMenuItem(Menu * m, MenuItem * mi, char shape)
 	     else
 	       {
 		  ESetWindowBackgroundPixmap(disp, mi->win, ParentRelative);
-		  EShapeCombineMask(disp, mi->win, ShapeBounding,
-				    0, 0, None, ShapeSet);
+		  EShapeCombineMask(disp, mi->win, ShapeBounding, 0, 0, None,
+				    ShapeSet);
 		  XClearWindow(disp, mi->win);
 	       }
 	  }
@@ -1101,24 +1104,16 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 	   cc = st.st_ctime;
 	Esnprintf(cs, sizeof(cs),
 		  "%s/cached/img/.%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c",
-		  UserCacheDir(),
-		  chmap[(aa >> 0) & 0x3f],
-		  chmap[(aa >> 6) & 0x3f],
-		  chmap[(aa >> 12) & 0x3f],
-		  chmap[(aa >> 18) & 0x3f],
-		  chmap[(aa >> 24) & 0x3f],
-		  chmap[(aa >> 28) & 0x3f],
-		  chmap[(bb >> 0) & 0x3f],
-		  chmap[(bb >> 6) & 0x3f],
-		  chmap[(bb >> 12) & 0x3f],
-		  chmap[(bb >> 18) & 0x3f],
-		  chmap[(bb >> 24) & 0x3f],
-		  chmap[(bb >> 28) & 0x3f],
-		  chmap[(cc >> 0) & 0x3f],
-		  chmap[(cc >> 6) & 0x3f],
-		  chmap[(cc >> 12) & 0x3f],
-		  chmap[(cc >> 18) & 0x3f],
-		  chmap[(cc >> 24) & 0x3f], chmap[(cc >> 28) & 0x3f]);
+		  UserCacheDir(), chmap[(aa >> 0) & 0x3f],
+		  chmap[(aa >> 6) & 0x3f], chmap[(aa >> 12) & 0x3f],
+		  chmap[(aa >> 18) & 0x3f], chmap[(aa >> 24) & 0x3f],
+		  chmap[(aa >> 28) & 0x3f], chmap[(bb >> 0) & 0x3f],
+		  chmap[(bb >> 6) & 0x3f], chmap[(bb >> 12) & 0x3f],
+		  chmap[(bb >> 18) & 0x3f], chmap[(bb >> 24) & 0x3f],
+		  chmap[(bb >> 28) & 0x3f], chmap[(cc >> 0) & 0x3f],
+		  chmap[(cc >> 6) & 0x3f], chmap[(cc >> 12) & 0x3f],
+		  chmap[(cc >> 18) & 0x3f], chmap[(cc >> 24) & 0x3f],
+		  chmap[(cc >> 28) & 0x3f]);
 	/* cached dir listing - use it */
 	if (exists(cs))
 	  {
@@ -1323,21 +1318,21 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
  * fprintf(f, "EXE %s\n", list[i]);
  * }
  */
-	     else if ((!strcmp(ext, "jpg")) || (!strcmp(ext, "JPG")) ||
-		      (!strcmp(ext, "jpeg")) || (!strcmp(ext, "Jpeg")) ||
-		      (!strcmp(ext, "JPEG")) || (!strcmp(ext, "Jpg")) ||
-		      (!strcmp(ext, "gif")) || (!strcmp(ext, "Gif")) ||
-		      (!strcmp(ext, "GIF")) || (!strcmp(ext, "png")) ||
-		      (!strcmp(ext, "Png")) || (!strcmp(ext, "PNG")) ||
-		      (!strcmp(ext, "tif")) || (!strcmp(ext, "Tif")) ||
-		      (!strcmp(ext, "TIFF")) || (!strcmp(ext, "tiff")) ||
-		      (!strcmp(ext, "Tiff")) || (!strcmp(ext, "TIFF")) ||
-		      (!strcmp(ext, "xpm")) || (!strcmp(ext, "Xpm")) ||
-		      (!strcmp(ext, "XPM")) || (!strcmp(ext, "ppm")) ||
-		      (!strcmp(ext, "PPM")) || (!strcmp(ext, "pgm")) ||
-		      (!strcmp(ext, "PGM")) || (!strcmp(ext, "pnm")) ||
-		      (!strcmp(ext, "PNM")) || (!strcmp(ext, "bmp")) ||
-		      (!strcmp(ext, "Bmp")) || (!strcmp(ext, "BMP")))
+	     else if ((!strcmp(ext, "jpg")) || (!strcmp(ext, "JPG"))
+		      || (!strcmp(ext, "jpeg")) || (!strcmp(ext, "Jpeg"))
+		      || (!strcmp(ext, "JPEG")) || (!strcmp(ext, "Jpg"))
+		      || (!strcmp(ext, "gif")) || (!strcmp(ext, "Gif"))
+		      || (!strcmp(ext, "GIF")) || (!strcmp(ext, "png"))
+		      || (!strcmp(ext, "Png")) || (!strcmp(ext, "PNG"))
+		      || (!strcmp(ext, "tif")) || (!strcmp(ext, "Tif"))
+		      || (!strcmp(ext, "TIFF")) || (!strcmp(ext, "tiff"))
+		      || (!strcmp(ext, "Tiff")) || (!strcmp(ext, "TIFF"))
+		      || (!strcmp(ext, "xpm")) || (!strcmp(ext, "Xpm"))
+		      || (!strcmp(ext, "XPM")) || (!strcmp(ext, "ppm"))
+		      || (!strcmp(ext, "PPM")) || (!strcmp(ext, "pgm"))
+		      || (!strcmp(ext, "PGM")) || (!strcmp(ext, "pnm"))
+		      || (!strcmp(ext, "PNM")) || (!strcmp(ext, "bmp"))
+		      || (!strcmp(ext, "Bmp")) || (!strcmp(ext, "BMP")))
 	       {
 		  Background         *bg;
 		  char                ok = 1;
@@ -1358,22 +1353,14 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 		     cc = st.st_ctime;
 		  Esnprintf(s3, sizeof(s3),
 			    ".%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c",
-			    chmap[(aa >> 0) & 0x3f],
-			    chmap[(aa >> 6) & 0x3f],
-			    chmap[(aa >> 12) & 0x3f],
-			    chmap[(aa >> 18) & 0x3f],
-			    chmap[(aa >> 24) & 0x3f],
-			    chmap[(aa >> 28) & 0x3f],
-			    chmap[(bb >> 0) & 0x3f],
-			    chmap[(bb >> 6) & 0x3f],
-			    chmap[(bb >> 12) & 0x3f],
-			    chmap[(bb >> 18) & 0x3f],
-			    chmap[(bb >> 24) & 0x3f],
-			    chmap[(bb >> 28) & 0x3f],
-			    chmap[(cc >> 0) & 0x3f],
-			    chmap[(cc >> 6) & 0x3f],
-			    chmap[(cc >> 12) & 0x3f],
-			    chmap[(cc >> 18) & 0x3f],
+			    chmap[(aa >> 0) & 0x3f], chmap[(aa >> 6) & 0x3f],
+			    chmap[(aa >> 12) & 0x3f], chmap[(aa >> 18) & 0x3f],
+			    chmap[(aa >> 24) & 0x3f], chmap[(aa >> 28) & 0x3f],
+			    chmap[(bb >> 0) & 0x3f], chmap[(bb >> 6) & 0x3f],
+			    chmap[(bb >> 12) & 0x3f], chmap[(bb >> 18) & 0x3f],
+			    chmap[(bb >> 24) & 0x3f], chmap[(bb >> 28) & 0x3f],
+			    chmap[(cc >> 0) & 0x3f], chmap[(cc >> 6) & 0x3f],
+			    chmap[(cc >> 12) & 0x3f], chmap[(cc >> 18) & 0x3f],
 			    chmap[(cc >> 24) & 0x3f], chmap[(cc >> 28) & 0x3f]);
 		  bg =
 		     (Background *) FindItem(s3, 0, LIST_FINDBY_NAME,
@@ -1419,8 +1406,8 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 				 tile = 1;
 				 keep_asp = 0;
 			      }
-			    else if ((!(IN_RANGE(scr_asp, im_asp, 16000))) &&
-				     ((width < 480) && (height < 360)))
+			    else if ((!(IN_RANGE(scr_asp, im_asp, 16000)))
+				     && ((width < 480) && (height < 360)))
 			      {
 				 scalex = 0;
 				 scaley = 0;
@@ -1451,9 +1438,10 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 			    icl.r = 0;
 			    icl.g = 0;
 			    icl.b = 0;
-			    bg = CreateDesktopBG(s3, &icl, ss, tile, keep_asp,
-						 512, 512, scalex, scaley,
-						 NULL, 0, 0, 0, 0, 0);
+			    bg =
+			       CreateDesktopBG(s3, &icl, ss, tile, keep_asp,
+					       512, 512, scalex, scaley, NULL,
+					       0, 0, 0, 0, 0);
 			    AddItem(bg, bg->name, 0, LIST_TYPE_BACKGROUND);
 			 }
 		       else
@@ -1767,8 +1755,8 @@ CreateMenuFromGnome(char *name, MenuStyle * ms, char *dir)
 			       s[strlen(s) - 1] = 0;
 			    if (!strncmp(s, "Name=", strlen("Name=")))
 			       en_name = duplicate(&(s[strlen("Name=")]));
-			    else if (name_buf[0] &&
-				     !strncmp(s, name_buf, strlen(name_buf)))
+			    else if (name_buf[0]
+				     && !strncmp(s, name_buf, strlen(name_buf)))
 			       iname = duplicate(&(s[strlen(name_buf)]));
 			    else
 			       if (!strncmp(s, "TryExec=", strlen("TryExec=")))
@@ -1949,9 +1937,10 @@ CreateMenuFromDesktopEWins(char *name, MenuStyle * ms, int desk)
      {
 	for (i = 0; i < num; i++)
 	  {
-	     if (((lst[i]->desktop == desk) || (lst[i]->sticky)) &&
-		 (!lst[i]->menu) && (!lst[i]->pager) && (!lst[i]->skipwinlist)
-		 && (lst[i]->client.title) && (!lst[i]->ibox))
+	     if (((lst[i]->desktop == desk) || (lst[i]->sticky))
+		 && (!lst[i]->menu) && (!lst[i]->pager)
+		 && (!lst[i]->skipwinlist) && (lst[i]->client.title)
+		 && (!lst[i]->ibox))
 	       {
 		  Esnprintf(s, sizeof(s), "%i", (int)(lst[i]->client.win));
 		  mi =
@@ -1988,13 +1977,13 @@ CreateMenuFromDesktops(char *name, MenuStyle * ms)
 	mm->style = ms;
 	Esnprintf(s, sizeof(s), "%i", j);
 	mi =
-	   CreateMenuItem(_("Go to this Desktop"), NULL, ACTION_GOTO_DESK,
-			  s, NULL);
+	   CreateMenuItem(_("Go to this Desktop"), NULL, ACTION_GOTO_DESK, s,
+			  NULL);
 	AddItemToMenu(mm, mi);
 	for (i = 0; i < num; i++)
 	  {
-	     if (((lst[i]->desktop == j) || (lst[i]->sticky)) &&
-		 (!lst[i]->menu) && (!lst[i]->pager) && (!lst[i]->skipwinlist)
+	     if (((lst[i]->desktop == j) || (lst[i]->sticky)) && (!lst[i]->menu)
+		 && (!lst[i]->pager) && (!lst[i]->skipwinlist)
 		 && (lst[i]->client.title) && (!lst[i]->ibox))
 	       {
 		  Esnprintf(s, sizeof(s), "%i", (int)(lst[i]->client.win));
@@ -2029,8 +2018,9 @@ ShowMenuMasker(Menu * m)
 	mode.menu_cover_win = ECreateEventWindow(parent, 0, 0, root.w, root.h);
 	wl[0] = ewin->win;
 	wl[1] = mode.menu_cover_win;
-	XSelectInput(disp, mode.menu_cover_win, ButtonPressMask |
-		     ButtonReleaseMask | EnterWindowMask | LeaveWindowMask);
+	XSelectInput(disp, mode.menu_cover_win,
+		     ButtonPressMask | ButtonReleaseMask | EnterWindowMask |
+		     LeaveWindowMask);
 	XRestackWindows(disp, wl, 2);
 	EMapWindow(disp, mode.menu_cover_win);
      }
@@ -2072,8 +2062,8 @@ CreateMenuFromGroups(char *name, MenuStyle * ms)
 			       ACTION_SHOW_HIDE_GROUP, s, NULL);
 	     AddItemToMenu(mm, mi);
 	     mi =
-		CreateMenuItem(_("Iconify this group"), NULL,
-			       ACTION_ICONIFY, s, NULL);
+		CreateMenuItem(_("Iconify this group"), NULL, ACTION_ICONIFY, s,
+			       NULL);
 	     AddItemToMenu(mm, mi);
 
 	     for (j = 0; j < lst[i]->num_members; j++)
