@@ -58,30 +58,27 @@ BlumFlimFrub(void)
 #endif
 	if (!exists(s))
 	  {
-	     Alert(_("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n"
-		     "\n"
-		     "Enlightenment's utility executable cannot be found at:\n"
-		     "\n"
-		     "%s\n"
-		     "This is a fatal error and Enlightenment will cease to run.\n"
-		     "Please rectify this situation and ensure it is installed\n"
-		     "correctly.\n"
-		     "\n"
-		     "The reason this could be missing is due to badly created\n"
-		     "packages, someone manually deleting that program or perhaps\n"
-		     "an error in installing Enlightenment.\n"), s);
+	     Alert(_
+		   ("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n" "\n"
+		    "Enlightenment's utility executable cannot be found at:\n"
+		    "\n" "%s\n"
+		    "This is a fatal error and Enlightenment will cease to run.\n"
+		    "Please rectify this situation and ensure it is installed\n"
+		    "correctly.\n" "\n"
+		    "The reason this could be missing is due to badly created\n"
+		    "packages, someone manually deleting that program or perhaps\n"
+		    "an error in installing Enlightenment.\n"), s);
 	     EExit(NULL);
 	  }
 	if (!canexec(s))
 	  {
-	     Alert(_("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n"
-		     "\n"
-		     "Enlightenment's dox executable is not able to be executed:\n"
-		     "\n"
-		     "%s\n"
-		     "This is a fatal error and Enlightenment will cease to run.\n"
-		     "Please rectify this situation and ensure dox is installed\n"
-		     "correctly.\n"), s);
+	     Alert(_
+		   ("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n" "\n"
+		    "Enlightenment's dox executable is not able to be executed:\n"
+		    "\n" "%s\n"
+		    "This is a fatal error and Enlightenment will cease to run.\n"
+		    "Please rectify this situation and ensure dox is installed\n"
+		    "correctly.\n"), s);
 	     EExit(NULL);
 	  }
 	Esnprintf(s, sizeof(s), "%s/dox", ENLIGHTENMENT_BIN);
@@ -96,17 +93,16 @@ BlumFlimFrub(void)
 #endif
 	if (!exists(s))
 	  {
-	     Alert(_("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n"
-		     "\n"
-		     "Enlightenment's documentation is not present or correctly installed\n"
-		     "\n"
-		     "This is a fatal error and Enlightenment will cease to run.\n"
-		     "Please rectify this situation and ensure it is installed\n"
-		     "correctly.\n"
-		     "\n"
-		     "The reason this could be missing is due to badly created\n"
-		     "packages, someone manually deleting those files or perhaps\n"
-		     "an error in installing Enlightenment.\n"));
+	     Alert(_
+		   ("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n" "\n"
+		    "Enlightenment's documentation is not present or correctly installed\n"
+		    "\n"
+		    "This is a fatal error and Enlightenment will cease to run.\n"
+		    "Please rectify this situation and ensure it is installed\n"
+		    "correctly.\n" "\n"
+		    "The reason this could be missing is due to badly created\n"
+		    "packages, someone manually deleting those files or perhaps\n"
+		    "an error in installing Enlightenment.\n"));
 	     EExit(NULL);
 	  }
      }
@@ -120,16 +116,15 @@ BlumFlimFrub(void)
 #endif
 	if (!exists(s))
 	  {
-	     Alert(_("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n"
-		     "\n"
-		     "Enlightenment's DEFAULT installed theme is missing or inadequately\n"
-		     "configured to be a useful DEFAULT theme.\n"
-		     "\n"
-		     "This is a fatal error and Enlightenment will cease to run.\n"
-		     "Please rectify this situation and ensure it is installed\n"
-		     "correctly. The DEFAULT theme Enlightenment comes with normally\n"
-		     "is BrushedMetal-Tigert and this theme is adequate for a DEFAULT\n"
-		     "theme.\n"));
+	     Alert(_
+		   ("!!!!!!!! ERROR ERROR ERROR ERROR !!!!!!!!\n" "\n"
+		    "Enlightenment's DEFAULT installed theme is missing or inadequately\n"
+		    "configured to be a useful DEFAULT theme.\n" "\n"
+		    "This is a fatal error and Enlightenment will cease to run.\n"
+		    "Please rectify this situation and ensure it is installed\n"
+		    "correctly. The DEFAULT theme Enlightenment comes with normally\n"
+		    "is BrushedMetal-Tigert and this theme is adequate for a DEFAULT\n"
+		    "theme.\n"));
 	     EExit(NULL);
 	  }
      }
@@ -259,14 +254,18 @@ ShowEdgeWindows(void)
 	w2 = ECreateEventWindow(root.win, root.w - 1, 0, 1, root.h);
 	w3 = ECreateEventWindow(root.win, 0, 0, root.w, 1);
 	w4 = ECreateEventWindow(root.win, 0, root.h - 1, root.w, 1);
-	XSelectInput(disp, w1, EnterWindowMask | LeaveWindowMask |
-		     PointerMotionMask | ButtonPressMask | ButtonReleaseMask);
-	XSelectInput(disp, w2, EnterWindowMask | LeaveWindowMask |
-		     PointerMotionMask | ButtonPressMask | ButtonReleaseMask);
-	XSelectInput(disp, w3, EnterWindowMask | LeaveWindowMask |
-		     PointerMotionMask | ButtonPressMask | ButtonReleaseMask);
-	XSelectInput(disp, w4, EnterWindowMask | LeaveWindowMask |
-		     PointerMotionMask | ButtonPressMask | ButtonReleaseMask);
+	XSelectInput(disp, w1,
+		     EnterWindowMask | LeaveWindowMask | PointerMotionMask |
+		     ButtonPressMask | ButtonReleaseMask);
+	XSelectInput(disp, w2,
+		     EnterWindowMask | LeaveWindowMask | PointerMotionMask |
+		     ButtonPressMask | ButtonReleaseMask);
+	XSelectInput(disp, w3,
+		     EnterWindowMask | LeaveWindowMask | PointerMotionMask |
+		     ButtonPressMask | ButtonReleaseMask);
+	XSelectInput(disp, w4,
+		     EnterWindowMask | LeaveWindowMask | PointerMotionMask |
+		     ButtonPressMask | ButtonReleaseMask);
      }
    GetCurrentArea(&cx, &cy);
    GetAreaSize(&ax, &ay);
