@@ -28,8 +28,8 @@ static void         PagerUpdateTimeout(int val, void *data);
 #define SNAP mode.pager_snap
 
 void
-PagerScaleLine(Pixmap dest, Window src, int dx, int dy, int sw, int pw,
-	       int sy, int sh)
+PagerScaleLine(Pixmap dest, Window src, int dx, int dy, int sw, int pw, int sy,
+	       int sh)
 {
    static GC           gc = 0;
    XGCValues           gcv;
@@ -89,8 +89,8 @@ PagerScaleLine(Pixmap dest, Window src, int dx, int dy, int sw, int pw,
 	     return;
 	  }
 	px_buf =
-	   XCreateImage(disp, root.vis, root.depth, ZPixmap, 0, NULL, pw, 1, 32,
-			0);
+	   XCreateImage(disp, root.vis, root.depth, ZPixmap, 0, NULL, pw, 1,
+			32, 0);
 	if (!px_buf)
 	  {
 	     XDestroyImage(px_grab);
@@ -135,7 +135,8 @@ PagerScaleLine(Pixmap dest, Window src, int dx, int dy, int sw, int pw,
 		  v2 = XGetPixel(xim1, x2 + difx, 0);
 		  v3 = XGetPixel(xim2, x2, 0);
 		  v4 = XGetPixel(xim2, x2 + difx, 0);
-		  v1 = ((v1 >> 2) & 0x3f3f3f3f) + ((v2 >> 2) & 0x3f3f3f3f) +
+		  v1 =
+		     ((v1 >> 2) & 0x3f3f3f3f) + ((v2 >> 2) & 0x3f3f3f3f) +
 		     ((v3 >> 2) & 0x3f3f3f3f) + ((v4 >> 2) & 0x3f3f3f3f) +
 		     (v1 & v2 & v3 & v4 & 0x03030303);
 		  XPutPixel(xim3, x, 0, v1);
@@ -213,8 +214,8 @@ PagerScaleLine(Pixmap dest, Window src, int dx, int dy, int sw, int pw,
 }
 
 void
-PagerScaleRect(Pixmap dest, Window src, int sx, int sy, int dx, int dy,
-	       int sw, int sh, int dw, int dh)
+PagerScaleRect(Pixmap dest, Window src, int sx, int sy, int dx, int dy, int sw,
+	       int sh, int dw, int dh)
 {
    static GC           gc = 0, gc2 = 0;
    XGCValues           gcv;
@@ -523,49 +524,45 @@ CreatePager(void)
 		  if (XShmPixmapFormat(disp) != ZPixmap)
 		    {
 		       SettingsPager();
-		       DIALOG_OK
-			  (_("Warning!"),
-			   _("\n"
-			     "You seem to have an X Server capable of Shared Memory\n"
-			     "but it is incapable of doing ZPixmap Shared pixmaps\n"
-			     "(The server does not claim to be able to do them).\n"
-			     "\n"
-			     "The pager in Enlightenment will run slowly in snapshot\n"
-			     "mode if you continue to use that mode of the pager\n"
-			     "under these conditions.\n"
-			     "\n"
-			     "It is suggested you change the settings on your pager to\n"
-			     "disable snapshots to improve performance.\n"
-			     "\n"));
+		       DIALOG_OK(_("Warning!"),
+				 _("\n"
+				   "You seem to have an X Server capable of Shared Memory\n"
+				   "but it is incapable of doing ZPixmap Shared pixmaps\n"
+				   "(The server does not claim to be able to do them).\n"
+				   "\n"
+				   "The pager in Enlightenment will run slowly in snapshot\n"
+				   "mode if you continue to use that mode of the pager\n"
+				   "under these conditions.\n" "\n"
+				   "It is suggested you change the settings on your pager to\n"
+				   "disable snapshots to improve performance.\n"
+				   "\n"));
 		    }
 		  else
-		     DIALOG_OK
-			(_("Warning!"),
-			 _("\n"
-			   "Your X Server is capable of doing Shared Memory but you do\n"
-			   "not have Shared Pixmaps enabled in your Imlib configuration.\n"
-			   "\n"
-			   "Please enable Shared Pixmaps in your Imlib configuration\n"
-			   "then restart Enlightenment to gain better performance for\n"
-			   "the pagers when snapshot mode is enabled.\n" "\n"));
+		     DIALOG_OK(_("Warning!"),
+			       _("\n"
+				 "Your X Server is capable of doing Shared Memory but you do\n"
+				 "not have Shared Pixmaps enabled in your Imlib configuration.\n"
+				 "\n"
+				 "Please enable Shared Pixmaps in your Imlib configuration\n"
+				 "then restart Enlightenment to gain better performance for\n"
+				 "the pagers when snapshot mode is enabled.\n"
+				 "\n"));
 	       }
 	  }
 	else
 	  {
 	     SettingsPager();
-	     DIALOG_OK
-		(_("Warning!"),
-		 _("\n"
-		   "You seem to be running Enlightenment over a network Connection\n"
-		   "or on an X Server that does not support Shared Memory, or you\n"
-		   "have disabled MIT-SHM Shared memory in your Imlib configuration.\n"
-		   "This means the Enlightenment Pager will perform slowly and use\n"
-		   "more system resources than it would when Shared Memory is\n"
-		   "available.\n"
-		   "\n"
-		   "To improve performance please either enable MIT-SHM Shared Memory\n"
-		   "in your Imlib config, if you disabled it, or disable Pager\n"
-		   "snapshots.\n" "\n"));
+	     DIALOG_OK(_("Warning!"),
+		       _("\n"
+			 "You seem to be running Enlightenment over a network Connection\n"
+			 "or on an X Server that does not support Shared Memory, or you\n"
+			 "have disabled MIT-SHM Shared memory in your Imlib configuration.\n"
+			 "This means the Enlightenment Pager will perform slowly and use\n"
+			 "more system resources than it would when Shared Memory is\n"
+			 "available.\n" "\n"
+			 "To improve performance please either enable MIT-SHM Shared Memory\n"
+			 "in your Imlib config, if you disabled it, or disable Pager\n"
+			 "snapshots.\n" "\n"));
 	  }
 	did_dialog = 1;
      }
@@ -584,13 +581,13 @@ CreatePager(void)
    p->pmap = ECreatePixmap(disp, p->win, p->w, p->h, id->x.depth);
    p->bgpmap = ECreatePixmap(disp, p->win, p->w / ax, p->h / ay, id->x.depth);
    ESetWindowBackgroundPixmap(disp, p->win, p->pmap);
-   XSelectInput(disp, p->win, ButtonPressMask | ButtonReleaseMask |
-		PointerMotionMask);
+   XSelectInput(disp, p->win,
+		ButtonPressMask | ButtonReleaseMask | PointerMotionMask);
    p->hi_win = ECreateWindow(root.win, 0, 0, 3, 3, 0);
    p->hi_visible = 0;
    p->hi_ewin = NULL;
-   XSelectInput(disp, p->hi_win, ButtonPressMask | ButtonReleaseMask |
-		PointerMotionMask);
+   XSelectInput(disp, p->hi_win,
+		ButtonPressMask | ButtonReleaseMask | PointerMotionMask);
    p->desktop = 0;
    p->visible = 0;
    p->update_phase = 0;
@@ -648,8 +645,8 @@ PagerResize(Pager * p, int w, int h)
      {
 	cx = desks.desk[p->desktop].current_area_x;
 	cy = desks.desk[p->desktop].current_area_y;
-	EMoveResizeWindow(disp, p->sel_win, cx * p->dw, cy * p->dh,
-			  p->dw, p->dh);
+	EMoveResizeWindow(disp, p->sel_win, cx * p->dw, cy * p->dh, p->dw,
+			  p->dh);
 	IclassApply(ic, p->sel_win, p->dw, p->dh, 0, 0, STATE_NORMAL, 0);
      }
    queue_up = pq;
@@ -855,8 +852,8 @@ PagerEwinUpdateMini(Pager * p, EWin * ewin)
 	ewin->mini_pmap = 0;
 	ewin->mini_mask = 0;
 
-	if ((ewin->desktop != desks.current) || (ewin->area_x != cx) ||
-	    (ewin->area_y != cy) || (!SNAP))
+	if ((ewin->desktop != desks.current) || (ewin->area_x != cx)
+	    || (ewin->area_y != cy) || (!SNAP))
 	  {
 	     ImageClass         *ic = NULL;
 
@@ -868,16 +865,17 @@ PagerEwinUpdateMini(Pager * p, EWin * ewin)
 	else
 	  {
 	     ewin->mini_pmap = ECreatePixmap(disp, p->win, w, h, root.depth);
-	     PagerScaleRect(ewin->mini_pmap, ewin->win, 0, 0, 0, 0,
-			    ewin->w, ewin->h, w, h);
+	     PagerScaleRect(ewin->mini_pmap, ewin->win, 0, 0, 0, 0, ewin->w,
+			    ewin->h, w, h);
 	  }
      }
    if (p->hi_ewin == ewin)
      {
 	ImlibImage         *im;
 
-	im = Imlib_create_image_from_drawable(id, ewin->mini_pmap, 0, 0, 0,
-					      ewin->mini_w, ewin->mini_h);
+	im =
+	   Imlib_create_image_from_drawable(id, ewin->mini_pmap, 0, 0, 0,
+					    ewin->mini_w, ewin->mini_h);
 	Imlib_apply_image(id, im, p->hi_win);
 	Imlib_kill_image(id, im);
      }
@@ -926,8 +924,9 @@ PagerEwinUpdateFromPager(Pager * p, EWin * ewin)
      {
 	ImlibImage         *im;
 
-	im = Imlib_create_image_from_drawable(id, ewin->mini_pmap, 0, 0, 0,
-					      ewin->mini_w, ewin->mini_h);
+	im =
+	   Imlib_create_image_from_drawable(id, ewin->mini_pmap, 0, 0, 0,
+					    ewin->mini_w, ewin->mini_h);
 	Imlib_apply_image(id, im, p->hi_win);
 	Imlib_kill_image(id, im);
      }
@@ -991,11 +990,12 @@ PagerRedraw(Pager * p, char newbg)
 		  ImageClass         *ic = NULL;
 
 		  EFreePixmap(disp, p->bgpmap);
-		  ic = FindItem("PAGER_BACKGROUND", 0,
-				LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+		  ic =
+		     FindItem("PAGER_BACKGROUND", 0, LIST_FINDBY_NAME,
+			      LIST_TYPE_ICLASS);
 		  if (ic)
-		     IclassApplyCopy(ic, p->win, p->w / ax, p->h / ay,
-				     0, 0, STATE_NORMAL, &(p->bgpmap), NULL);
+		     IclassApplyCopy(ic, p->win, p->w / ax, p->h / ay, 0, 0,
+				     STATE_NORMAL, &(p->bgpmap), NULL);
 	       }
 	     else
 	       {
@@ -1006,8 +1006,7 @@ PagerRedraw(Pager * p, char newbg)
 		       ImlibImage         *im;
 
 		       uniq = GetUniqueBGString(desks.desk[p->desktop].bg);
-		       Esnprintf(s, sizeof(s),
-				 "%s/cached/pager/%s.%i.%i.%s",
+		       Esnprintf(s, sizeof(s), "%s/cached/pager/%s.%i.%i.%s",
 				 UserCacheDir(),
 				 desks.desk[p->desktop].bg->name, (p->w / ax),
 				 (p->h / ay), uniq);
@@ -1025,10 +1024,11 @@ PagerRedraw(Pager * p, char newbg)
 			 {
 			    SetBackgroundTo(id, p->bgpmap,
 					    desks.desk[p->desktop].bg, 0);
-			    im = Imlib_create_image_from_drawable(id, p->bgpmap,
-								  0, 0, 0,
-								  (p->w / ax),
-								  (p->h / ay));
+			    im =
+			       Imlib_create_image_from_drawable(id, p->bgpmap,
+								0, 0, 0,
+								(p->w / ax),
+								(p->h / ay));
 			    Imlib_save_image_to_ppm(id, im, s);
 			    Imlib_changed_image(id, im);
 			    Imlib_kill_image(id, im);
@@ -1039,8 +1039,8 @@ PagerRedraw(Pager * p, char newbg)
 		       XSetForeground(disp, gc, c1);
 		       XDrawRectangle(disp, p->bgpmap, gc, 0, 0, p->dw, p->dh);
 		       XSetForeground(disp, gc, c2);
-		       XFillRectangle(disp, p->bgpmap, gc, 1, 1,
-				      p->dw - 2, p->dh - 2);
+		       XFillRectangle(disp, p->bgpmap, gc, 1, 1, p->dw - 2,
+				      p->dh - 2);
 		    }
 	       }
 	  }
@@ -1202,8 +1202,8 @@ PagerEwinOutsideAreaUpdate(EWin * ewin)
 	ForceUpdatePagersForDesktop(ewin->desktop);
 	return;
      }
-   if ((ewin->x < 0) || (ewin->y < 0) || ((ewin->x + ewin->w) > root.w) ||
-       ((ewin->y + ewin->h) > root.h))
+   if ((ewin->x < 0) || (ewin->y < 0) || ((ewin->x + ewin->w) > root.w)
+       || ((ewin->y + ewin->h) > root.h))
       RedrawPagersForDesktop(ewin->desktop, 3);
    ForceUpdatePagersForDesktop(ewin->desktop);
 }
@@ -1303,25 +1303,25 @@ PagerShowMenu(Pager * p, int x, int y)
    AddItemToMenu(p_menu, mi);
 
    mi =
-      CreateMenuItem(_("Snapshotting On"), NULL, ACTION_SET_PAGER_SNAP,
-		     "1", NULL);
+      CreateMenuItem(_("Snapshotting On"), NULL, ACTION_SET_PAGER_SNAP, "1",
+		     NULL);
    AddItemToMenu(p_menu, mi);
 
    mi =
-      CreateMenuItem(_("Snapshotting Off"), NULL, ACTION_SET_PAGER_SNAP,
-		     "0", NULL);
+      CreateMenuItem(_("Snapshotting Off"), NULL, ACTION_SET_PAGER_SNAP, "0",
+		     NULL);
    AddItemToMenu(p_menu, mi);
 
    if (SNAP)
      {
 	mi =
-	   CreateMenuItem(_("High Quality On"), NULL,
-			  ACTION_SET_PAGER_HIQ, "1", NULL);
+	   CreateMenuItem(_("High Quality On"), NULL, ACTION_SET_PAGER_HIQ,
+			  "1", NULL);
 	AddItemToMenu(p_menu, mi);
 
 	mi =
-	   CreateMenuItem(_("High Quality Off"), NULL,
-			  ACTION_SET_PAGER_HIQ, "0", NULL);
+	   CreateMenuItem(_("High Quality Off"), NULL, ACTION_SET_PAGER_HIQ,
+			  "0", NULL);
 	AddItemToMenu(p_menu, mi);
      }
    AddItem(p_menu, p_menu->name, 0, LIST_TYPE_MENU);
@@ -1434,8 +1434,9 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 	     ImlibImage         *im;
 	     int                 xx, yy, ww, hh, i;
 
-	     im = Imlib_create_image_from_drawable(id, ewin->mini_pmap, 0, 0, 0,
-						   ewin->mini_w, ewin->mini_h);
+	     im =
+		Imlib_create_image_from_drawable(id, ewin->mini_pmap, 0, 0, 0,
+						 ewin->mini_w, ewin->mini_h);
 	     if (w > h)
 	       {
 		  for (i = w; i < (w * 2); i++)
@@ -1496,8 +1497,8 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 		       }
 		    }
 	       }
-	     EMoveResizeWindow(disp, p->hi_win, x - (w / 2), y - (h / 2),
-			       w * 2, h * 2);
+	     EMoveResizeWindow(disp, p->hi_win, x - (w / 2), y - (h / 2), w * 2,
+			       h * 2);
 	     Imlib_apply_image(id, im, p->hi_win);
 	     Imlib_kill_image(id, im);
 	  }
@@ -1558,8 +1559,8 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 		       }
 		    }
 	       }
-	     EMoveResizeWindow(disp, p->hi_win, x - (w / 2), y - (h / 2),
-			       w * 2, h * 2);
+	     EMoveResizeWindow(disp, p->hi_win, x - (w / 2), y - (h / 2), w * 2,
+			       h * 2);
 	     queue_up = pq;
 	  }
 	else
@@ -1639,8 +1640,8 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 		    }
 	       }
 	     EFreePixmap(disp, pmap);
-	     EMoveResizeWindow(disp, p->hi_win, x - (w / 2), y - (h / 2),
-			       w * 2, h * 2);
+	     EMoveResizeWindow(disp, p->hi_win, x - (w / 2), y - (h / 2), w * 2,
+			       h * 2);
 	  }
 	p->hi_visible = 1;
      }
