@@ -1,3 +1,4 @@
+
 /*
  * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
  *
@@ -42,8 +43,9 @@ CreateProgressbar(char *name, int width, int height)
    p->w = width;
    p->h = height;
    p->win = ECreateWindow(root.win, p->x, p->y, p->w - (p->h * 5), p->h, 1);
-   p->n_win = ECreateWindow(root.win, p->x + p->w - (p->h * 5), p->y,
-			    (p->h * 5), p->h, 1);
+   p->n_win =
+      ECreateWindow(root.win, p->x + p->w - (p->h * 5), p->y, (p->h * 5),
+		    p->h, 1);
    p->p_win = ECreateWindow(root.win, p->x, p->y + p->h, 1, p->h, 1);
    /* FIXME: need to use other image and textclasses */
 
@@ -63,8 +65,8 @@ CreateProgressbar(char *name, int width, int height)
    if (p->tc)
       p->tc->ref_count++;
 
-   p->tnc = FindItem("PROGRESS_TEXT_NUMBER", 0, LIST_FINDBY_NAME,
-		     LIST_TYPE_TCLASS);
+   p->tnc =
+      FindItem("PROGRESS_TEXT_NUMBER", 0, LIST_FINDBY_NAME, LIST_TYPE_TCLASS);
    if (p->tnc)
       p->tnc->ref_count++;
 
@@ -93,8 +95,8 @@ SetProgressbar(Progressbar * p, int progress)
    Esnprintf(s, sizeof(s), "%i%%", p->value);
    pq = queue_up;
    queue_up = 0;
-   TclassApply(p->inc, p->n_win, p->h * 5, p->h, 0, 0, STATE_CLICKED,
-	       0, p->tnc, s);
+   TclassApply(p->inc, p->n_win, p->h * 5, p->h, 0, 0, STATE_CLICKED, 0,
+	       p->tnc, s);
    IclassApply(p->inc, p->p_win, w, p->h, 1, 0, STATE_NORMAL, 0);
    EResizeWindow(disp, p->p_win, w, p->h);
    queue_up = pq;
