@@ -207,8 +207,8 @@ SaveWindowStates(void)
 	     for (i = 0; i < num; i++)
 	       {
 		  ewin = lst[i];
-		  if ((!(ewin->internal)) &&
-		      ((ewin->client.command) || (ewin->session_id)))
+		  if ((!(ewin->internal))
+		      && ((ewin->client.command) || (ewin->session_id)))
 		    {
 		       x = 0;
 		       y = 0;
@@ -222,10 +222,9 @@ SaveWindowStates(void)
 			       root.h;
 			 }
 		       fprintf(f, "[CLIENT] %i %i %i %i %i %i %i %i %i\n",
-			       ewin->x + x, ewin->y + y,
-			       ewin->client.w, ewin->client.h,
-			       ewin->desktop, ewin->iconified, ewin->shaded,
-			       ewin->sticky, ewin->layer);
+			       ewin->x + x, ewin->y + y, ewin->client.w,
+			       ewin->client.h, ewin->desktop, ewin->iconified,
+			       ewin->shaded, ewin->sticky, ewin->layer);
 		       if (ewin->session_id)
 			  fprintf(f, "  [SESSION_ID] %s\n", ewin->session_id);
 		       if (ewin->client.name)
@@ -243,12 +242,12 @@ SaveWindowStates(void)
 	     rm(ss);
 	     mv(s, ss);
 	     if (!isfile(ss))
-		Alert(_("There was an error writing the clients "
-			"session save file.\n"
-			"You may have run out of disk "
-			"space, not have permission\n"
-			"to write to your filing system "
-			"or other similar problems.\n"));
+		Alert(_
+		      ("There was an error writing the clients "
+		       "session save file.\n" "You may have run out of disk "
+		       "space, not have permission\n"
+		       "to write to your filing system "
+		       "or other similar problems.\n"));
 	  }
 	Efree(lst);
      }
@@ -358,8 +357,8 @@ MatchEwinToSM(EWin * ewin)
 		   * FIXME: Mozilla DELETES the WM_COMMAND property on 
 		   * a regular basis so is is wise NOT to update 
 		   * this property when it is set to NULL. */
-		  if ((ewin->client.command) && (matches[i].command) &&
-		      strcmp(ewin->client.command, matches[i].command))
+		  if ((ewin->client.command) && (matches[i].command)
+		      && strcmp(ewin->client.command, matches[i].command))
 		     continue;
 	       }
 
@@ -377,11 +376,11 @@ MatchEwinToSM(EWin * ewin)
 	     else
 	       {
 		  /* The WM_CLASS is a stable basis for a test. */
-		  if ((ewin->client.class) && (matches[i].class) &&
-		      (strcmp(ewin->client.class, matches[i].class)))
+		  if ((ewin->client.class) && (matches[i].class)
+		      && (strcmp(ewin->client.class, matches[i].class)))
 		     continue;
-		  if ((ewin->client.name) && (matches[i].name) &&
-		      (strcmp(ewin->client.name, matches[i].name)))
+		  if ((ewin->client.name) && (matches[i].name)
+		      && (strcmp(ewin->client.name, matches[i].name)))
 		     continue;
 
 		  /* Twm also matches on the WM_NAME but only when this value
@@ -402,15 +401,17 @@ MatchEwinToSM(EWin * ewin)
 		  /* if it's NOT (X11R6 and already placed by the client) */
 		  if (!((ewin->client.already_placed) && (ewin->session_id)))
 		    {
-		       ewin->client.x = matches[i].x -
+		       ewin->client.x =
+			  matches[i].x -
 			  (desks.desk[ewin->desktop].current_area_x * root.w);
-		       ewin->client.y = matches[i].y -
+		       ewin->client.y =
+			  matches[i].y -
 			  (desks.desk[ewin->desktop].current_area_y * root.h);
 		       ewin->client.w = matches[i].w;
 		       ewin->client.h = matches[i].h;
-		       EMoveResizeWindow(disp, ewin->client.win,
-					 ewin->client.x, ewin->client.y,
-					 ewin->client.w, ewin->client.h);
+		       EMoveResizeWindow(disp, ewin->client.win, ewin->client.x,
+					 ewin->client.y, ewin->client.w,
+					 ewin->client.h);
 		    }
 	       }
 	     break;
@@ -560,17 +561,16 @@ doSMExit(void *params)
 	       {
 		  Esnprintf(sss, sizeof(sss),
 			    "exec %s -single -ext_init_win %i -theme %s "
-			    "-econfdir %s -ecachedir %s -display %s",
-			    command, w, themename,
-			    UserEDir(), UserCacheDir(), dstr);
+			    "-econfdir %s -ecachedir %s -display %s", command,
+			    w, themename, UserEDir(), UserCacheDir(), dstr);
 		  execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", sss, NULL);
 	       }
 	     else
 	       {
 		  Esnprintf(sss, sizeof(sss),
 			    "exec %s -single -ext_init_win %i "
-			    "-econfdir %s -ecachedir %s -display %s",
-			    command, w, UserEDir(), UserCacheDir(), dstr);
+			    "-econfdir %s -ecachedir %s -display %s", command,
+			    w, UserEDir(), UserCacheDir(), dstr);
 		  execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", sss, NULL);
 	       }
 	  }
@@ -585,8 +585,8 @@ doSMExit(void *params)
 	     sscanf(params, "%*s %1000s", s);
 	     Esnprintf(sss, sizeof(sss),
 		       "exec %s -single -ext_init_win %i -theme %s "
-		       "-econfdir %s -ecachedir %s -display %s",
-		       command, w, s, UserEDir(), UserCacheDir(), dstr);
+		       "-econfdir %s -ecachedir %s -display %s", command, w, s,
+		       UserEDir(), UserCacheDir(), dstr);
 	     execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", sss, NULL);
 	  }
 	else if (!strcmp(s, "restart_wm"))
@@ -602,26 +602,27 @@ doSMExit(void *params)
 	     if (atword(params, 2))
 		strncpy(s, atword(params, 2), 1000);
 	     real_exec = (char *)Emalloc(strlen(s) + 6);
-	     sprintf(real_exec, "exec %s "
-		     "-econfdir %s -ecachedir %s -display %s",
-		     s, UserEDir(), UserCacheDir(), dstr);
-	     execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", "exec",
-		   real_exec, NULL);
+	     sprintf(real_exec,
+		     "exec %s " "-econfdir %s -ecachedir %s -display %s", s,
+		     UserEDir(), UserCacheDir(), dstr);
+	     execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", "exec", real_exec,
+		   NULL);
 	  }
 	else if (!strcmp(s, "logout"))
 	  {
 	     Dialog             *d;
 	     EWin               *ewin;
 
-	     if (!(d = FindItem("LOGOUT_DIALOG", 0, LIST_FINDBY_NAME,
-				LIST_TYPE_DIALOG)))
+	     if (!
+		 (d =
+		  FindItem("LOGOUT_DIALOG", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_DIALOG)))
 	       {
 		  AUDIO_PLAY("SOUND_LOGOUT");
 		  d = CreateDialog("LOGOUT_DIALOG");
 		  DialogSetTitle(d, "Are you sure?");
 		  DialogSetText(d,
-				"\n"
-				"\n"
+				"\n" "\n"
 				"    Are you sure you wish to log out ?    \n"
 				"\n" "\n");
 		  DialogAddButton(d, "  Yes, Log Out  ", LogoutCB, 1);
@@ -656,8 +657,9 @@ doSMExit(void *params)
 				   {
 				      if (pointer_y >= screens[i].y_org)
 					{
-					   if (pointer_y <= (screens[i].height +
-							     screens[i].y_org))
+					   if (pointer_y <=
+					       (screens[i].height +
+						screens[i].y_org))
 					     {
 						ewin->x =
 						   ((screens[i].width - ewin->w)
@@ -928,9 +930,8 @@ callback_save_yourself2(SmcConn smc_conn, SmPointer client_data)
 }
 
 static void
-callback_save_yourself(SmcConn smc_conn, SmPointer client_data,
-		       int save_style, Bool shutdown, int interact_style,
-		       Bool fast)
+callback_save_yourself(SmcConn smc_conn, SmPointer client_data, int save_style,
+		       Bool shutdown, int interact_style, Bool fast)
 {
    if (master_pid == getpid())
      {
@@ -971,8 +972,8 @@ static void
 callback_die(SmcConn smc_conn, SmPointer client_data)
 {
    if (master_pid == getpid())
-      ApplySclass(FindItem("SOUND_EXIT", 0,
-			   LIST_FINDBY_NAME, LIST_TYPE_SCLASS));
+      ApplySclass(FindItem
+		  ("SOUND_EXIT", 0, LIST_FINDBY_NAME, LIST_TYPE_SCLASS));
    EExit(0);
    smc_conn = 0;
    client_data = NULL;
@@ -1021,8 +1022,7 @@ SessionInit(void)
    callbacks.save_complete.callback = callback_save_complete;
    callbacks.shutdown_cancelled.callback = callback_shutdown_cancelled;
 
-   callbacks.save_yourself.client_data =
-      callbacks.die.client_data =
+   callbacks.save_yourself.client_data = callbacks.die.client_data =
       callbacks.save_complete.client_data =
       callbacks.shutdown_cancelled.client_data = (SmPointer) NULL;
    if (getenv("SESSION_MANAGER"))
@@ -1032,12 +1032,12 @@ SessionInit(void)
 
 	if (sm_client_id)
 	   client_id = duplicate(sm_client_id);
-	sm_conn = SmcOpenConnection(NULL, &context, SmProtoMajor, SmProtoMinor,
-				    SmcSaveYourselfProcMask | SmcDieProcMask |
-				    SmcSaveCompleteProcMask |
-				    SmcShutdownCancelledProcMask,
-				    &callbacks, client_id, &sm_client_id,
-				    4096, error_string_ret);
+	sm_conn =
+	   SmcOpenConnection(NULL, &context, SmProtoMajor, SmProtoMinor,
+			     SmcSaveYourselfProcMask | SmcDieProcMask |
+			     SmcSaveCompleteProcMask |
+			     SmcShutdownCancelledProcMask, &callbacks,
+			     client_id, &sm_client_id, 4096, error_string_ret);
 	if (client_id)
 	   Efree(client_id);
 
@@ -1086,15 +1086,13 @@ ProcessICEMSGS(void)
    if (status == IceProcessMessagesIOError)
      {
 	/* Less of the hope.... E survives */
-	DialogAlert(_("ERROR!\n"
-		      "\n"
-		      "Lost the Session Manager that was there?\n"
-		      "Here here session manager... come here... want a bone?\n"
-		      "Oh come now! Stop sulking! Bugger. Oh well. "
-		      "Will continue without\n"
-		      "a session manager.\n"
-		      "\n"
-		      "I'll survive somehow.\n" "\n" "\n" "... I hope.\n"));
+	DialogAlert(_
+		    ("ERROR!\n" "\n"
+		     "Lost the Session Manager that was there?\n"
+		     "Here here session manager... come here... want a bone?\n"
+		     "Oh come now! Stop sulking! Bugger. Oh well. "
+		     "Will continue without\n" "a session manager.\n" "\n"
+		     "I'll survive somehow.\n" "\n" "\n" "... I hope.\n"));
 	SmcCloseConnection(sm_conn, 0, NULL);
 	sm_conn = NULL;
 	sm_fd = -1;
@@ -1120,8 +1118,10 @@ SessionGetInfo(EWin * ewin, Atom atom_change)
 	ewin->session_id = NULL;
      }
    /* We can comply with the ICCCM because gtk is working correctly */
-   if ((atom_change) && (!((atom_change == atom_sm_client_id) ||
-			   (atom_change == atom_wm_client_leader))))
+   if ((atom_change)
+       &&
+       (!((atom_change
+	   == atom_sm_client_id) || (atom_change == atom_wm_client_leader))))
       return;
    w = AtomGet(ewin->client.win, atom_wm_client_leader, XA_WINDOW, &size);
    if (w)
@@ -1151,8 +1151,8 @@ LogoutCB(int val, void *data)
 {
    if (sm_conn)
      {
-	SmcRequestSaveYourself(sm_conn, SmSaveBoth, True,
-			       SmInteractStyleAny, False, True);
+	SmcRequestSaveYourself(sm_conn, SmSaveBoth, True, SmInteractStyleAny,
+			       False, True);
      }
    else
      {
@@ -1220,17 +1220,17 @@ doSMExit(void *params)
 	Dialog             *d;
 	EWin               *ewin;
 
-	if (!(d = FindItem("LOGOUT_DIALOG", 0, LIST_FINDBY_NAME,
-			   LIST_TYPE_DIALOG)))
+	if (!
+	    (d =
+	     FindItem("LOGOUT_DIALOG", 0, LIST_FINDBY_NAME, LIST_TYPE_DIALOG)))
 	  {
 	     AUDIO_PLAY("SOUND_LOGOUT");
 	     d = CreateDialog("LOGOUT_DIALOG");
 	     DialogSetTitle(d, _("Are you sure?"));
 	     DialogSetText(d,
-			   _("\n"
-			     "\n"
-			     "    Are you sure you wish to log out ?    \n"
-			     "\n" "\n"));
+			   _("\n" "\n"
+			     "    Are you sure you wish to log out ?    \n" "\n"
+			     "\n"));
 	     DialogAddButton(d, _("  Yes, Log Out  "), LogoutCB, 1);
 	     DialogAddButton(d, _("  No  "), NULL, 1);
 	     DialogBindKey(d, "Escape", CB_SettingsEscape, 1, d);
@@ -1263,8 +1263,9 @@ doSMExit(void *params)
 			      {
 				 if (pointer_y >= screens[i].y_org)
 				   {
-				      if (pointer_y <= (screens[i].height +
-							screens[i].y_org))
+				      if (pointer_y <=
+					  (screens[i].height +
+					   screens[i].y_org))
 					{
 					   ewin->x =
 					      ((screens[i].width - ewin->w) /
@@ -1323,17 +1324,15 @@ doSMExit(void *params)
 		Esnprintf(s, sizeof(s),
 			  "exec %s -single -ext_init_win %i -theme %s "
 			  "-econfdir %s -ecachedir %s "
-			  "-smfile %s -smid %s -display %s",
-			  command, init_win_ext, themename,
-			  UserEDir(), UserCacheDir(),
+			  "-smfile %s -smid %s -display %s", command,
+			  init_win_ext, themename, UserEDir(), UserCacheDir(),
 			  sm_file, sm_client_id, dstr);
 	     else
 		Esnprintf(s, sizeof(s),
 			  "exec %s -single -ext_init_win %i -theme %s "
 			  "-econfdir %s -ecachedir %s "
-			  "-smfile %s -display %s",
-			  command, init_win_ext, themename,
-			  UserEDir(), UserCacheDir(), sm_file, dstr);
+			  "-smfile %s -display %s", command, init_win_ext,
+			  themename, UserEDir(), UserCacheDir(), sm_file, dstr);
 	     execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", s, NULL);
 	  }
 	else
@@ -1342,16 +1341,14 @@ doSMExit(void *params)
 		Esnprintf(s, sizeof(s),
 			  "exec %s -single -ext_init_win %i "
 			  "-econfdir %s -ecachedir %s "
-			  "-smfile %s -smid %s -display %s",
-			  command, init_win_ext,
-			  UserEDir(), UserCacheDir(),
-			  sm_file, sm_client_id, dstr);
+			  "-smfile %s -smid %s -display %s", command,
+			  init_win_ext, UserEDir(), UserCacheDir(), sm_file,
+			  sm_client_id, dstr);
 	     else
 		Esnprintf(s, sizeof(s),
 			  "exec %s -single -ext_init_win %i"
 			  "-econfdir %s -ecachedir %s "
-			  "-smfile %s -display %s",
-			  command, init_win_ext,
+			  "-smfile %s -display %s", command, init_win_ext,
 			  UserEDir(), UserCacheDir(), sm_file, dstr);
 	     execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", s, NULL);
 	  }
@@ -1374,16 +1371,15 @@ doSMExit(void *params)
 	   Esnprintf(s, sizeof(s),
 		     "exec %s -single -ext_init_win %i -theme %s "
 		     "-econfdir %s -ecachedir %s "
-		     "-smfile %s -smid %s -display %s",
-		     command, init_win_ext, userthemepath,
-		     UserEDir(), UserCacheDir(), sm_file, sm_client_id, dstr);
+		     "-smfile %s -smid %s -display %s", command, init_win_ext,
+		     userthemepath, UserEDir(), UserCacheDir(), sm_file,
+		     sm_client_id, dstr);
 	else
 	   Esnprintf(s, sizeof(s),
 		     "exec %s -ext_init_win %i -theme %s "
 		     "-econfdir %s -ecachedir %s "
-		     "-smfile %s -single -display %s",
-		     command, init_win_ext, userthemepath,
-		     UserEDir(), UserCacheDir(), sm_file, dstr);
+		     "-smfile %s -single -display %s", command, init_win_ext,
+		     userthemepath, UserEDir(), UserCacheDir(), sm_file, dstr);
 	execl(DEFAULT_SH_PATH, DEFAULT_SH_PATH, "-c", s, NULL);
      }
    else if (!strcmp((char *)s, "error"))
