@@ -218,22 +218,22 @@ SetupX()
    /* if cannot connect to display */
    if (!disp)
      {
-	Alert(_("Enlightenment cannot connect to the display nominated by\n"
-		"your shell's DISPLAY environment variable. You may set this\n"
-		"variable to indicate which display name Enlightenment is to\n"
-		"connect to. It may be that you do not have an Xserver already\n"
-		"running to serve that Display connection, or that you do not\n"
-		"have permission to connect to that display. Please make sure\n"
-		"all is correct before trying again. Run an Xserver by running\n"
-		"xdm or startx first, or contact your local system\n"
-		"administrator, or Xserver vendor, or read the X, xdm and\n"
-		"startx manual pages before proceeding.\n"));
+	Alert(_
+	      ("Enlightenment cannot connect to the display nominated by\n"
+	       "your shell's DISPLAY environment variable. You may set this\n"
+	       "variable to indicate which display name Enlightenment is to\n"
+	       "connect to. It may be that you do not have an Xserver already\n"
+	       "running to serve that Display connection, or that you do not\n"
+	       "have permission to connect to that display. Please make sure\n"
+	       "all is correct before trying again. Run an Xserver by running\n"
+	       "xdm or startx first, or contact your local system\n"
+	       "administrator, or Xserver vendor, or read the X, xdm and\n"
+	       "startx manual pages before proceeding.\n"));
 	EExit((void *)1);
      }
    root.scr = DefaultScreen(disp);
    display_screens = ScreenCount(disp);
    master_screen = root.scr;
-
    /* Start up on multiple heads, if appropriate */
    if ((display_screens > 1) && (!single_screen_mode))
      {
@@ -255,8 +255,8 @@ SetupX()
 		  if (pid)
 		    {
 		       child_count++;
-		       e_children = Erealloc(e_children, sizeof(pid_t) *
-					     child_count);
+		       e_children =
+			  Erealloc(e_children, sizeof(pid_t) * child_count);
 		       e_children[child_count - 1] = pid;
 		    }
 		  else
@@ -272,7 +272,7 @@ SetupX()
 			    if (NULL != dispstr)
 			       *dispstr = '\0';
 			 }
-		       Esnprintf(subdisplay + strlen(subdisplay), 255, ".%d",
+		       Esnprintf(subdisplay + strlen(subdisplay), 10, ".%d",
 				 i);
 		       dstr = duplicate(subdisplay);
 		       disp = XOpenDisplay(dstr);
@@ -290,15 +290,14 @@ SetupX()
    /* Check for the Shape Extension */
    if (!XShapeQueryExtension(disp, &shape_event_base, &shape_error_base))
      {
-	ASSIGN_ALERT(_("X server setup error"),
-		     "", "", _("Quit Enlightenment"));
-	Alert(_("FATAL ERROR:\n"
-		"\n"
-		"This Xserver does not support the Shape extension.\n"
-		"This is required for Enlightenment to run.\n"
-		"\n"
-		"Your Xserver probably is too old or mis-configured.\n"
-		"\n" "Exiting.\n"));
+	ASSIGN_ALERT(_("X server setup error"), "", "",
+		     _("Quit Enlightenment"));
+	Alert(_
+	      ("FATAL ERROR:\n" "\n"
+	       "This Xserver does not support the Shape extension.\n"
+	       "This is required for Enlightenment to run.\n" "\n"
+	       "Your Xserver probably is too old or mis-configured.\n" "\n"
+	       "Exiting.\n"));
 	RESET_ALERT;
 	EExit((void *)1);
      }
@@ -324,24 +323,24 @@ SetupX()
    id = Imlib_init(disp);
    if (!id)
      {
-	ASSIGN_ALERT(_("Imlib initialisation error"),
-		     "", "", _("Quit Enlightenment"));
-	Alert(_("FATAL ERROR:\n"
-		"\n"
-		"Enlightenment is unable to initialise Imlib.\n"
-		"\n" "This is unusual. Unable to continue.\n" "Exiting.\n"));
+	ASSIGN_ALERT(_("Imlib initialisation error"), "", "",
+		     _("Quit Enlightenment"));
+	Alert(_
+	      ("FATAL ERROR:\n" "\n"
+	       "Enlightenment is unable to initialise Imlib.\n" "\n"
+	       "This is unusual. Unable to continue.\n" "Exiting.\n"));
 	RESET_ALERT;
 	EExit((void *)1);
      }
    fd = Fnlib_init(id);
    if (!fd)
      {
-	ASSIGN_ALERT(_("X server setup error"),
-		     "", "", _("Quit Enlightenment"));
-	Alert(_("FATAL ERROR:\n"
-		"\n"
-		"Enlightenment is unable to initialise Fnlib.\n"
-		"\n" "This is unusual. Unable to continue.\n" "Exiting.\n"));
+	ASSIGN_ALERT(_("X server setup error"), "", "",
+		     _("Quit Enlightenment"));
+	Alert(_
+	      ("FATAL ERROR:\n" "\n"
+	       "Enlightenment is unable to initialise Fnlib.\n" "\n"
+	       "This is unusual. Unable to continue.\n" "Exiting.\n"));
 	RESET_ALERT;
 	EExit((void *)1);
      }
@@ -371,10 +370,10 @@ SetupX()
    /* slect all the root window events to start managing */
    mode.xselect = 1;
    XSelectInput(disp, root.win,
-		ButtonPressMask | ButtonReleaseMask |
-		EnterWindowMask | LeaveWindowMask | ButtonMotionMask |
-		PropertyChangeMask | SubstructureRedirectMask | KeyPressMask |
-		KeyReleaseMask | PointerMotionMask | ResizeRedirectMask |
+		ButtonPressMask | ButtonReleaseMask | EnterWindowMask |
+		LeaveWindowMask | ButtonMotionMask | PropertyChangeMask |
+		SubstructureRedirectMask | KeyPressMask | KeyReleaseMask |
+		PointerMotionMask | ResizeRedirectMask |
 		SubstructureNotifyMask);
    XSync(disp, False);
    mode.xselect = 0;
@@ -387,10 +386,10 @@ SetupX()
       atom_set = XInternAtom(disp, "_WIN_DESKTOP_BUTTON_PROXY", False);
       bpress_win = ECreateWindow(root.win, -80, -80, 24, 24, 0);
       val = bpress_win;
-      XChangeProperty(disp, root.win, atom_set, XA_CARDINAL,
-		      32, PropModeReplace, (unsigned char *)&val, 1);
-      XChangeProperty(disp, bpress_win, atom_set, XA_CARDINAL,
-		      32, PropModeReplace, (unsigned char *)&val, 1);
+      XChangeProperty(disp, root.win, atom_set, XA_CARDINAL, 32,
+		      PropModeReplace, (unsigned char *)&val, 1);
+      XChangeProperty(disp, bpress_win, atom_set, XA_CARDINAL, 32,
+		      PropModeReplace, (unsigned char *)&val, 1);
    }
 
    XSync(disp, False);
@@ -398,14 +397,15 @@ SetupX()
    /* warn, if necessary about X version problems */
    if (ProtocolVersion(disp) != 11)
      {
-	ASSIGN_ALERT(_("X server version error"),
-		     _("Ignore this error"), "", _("Quit Enlightenment"));
-	Alert(_("WARNING:\n"
-		"This is not an X11 Xserver. It in fact talks the X%i protocol.\n"
-		"This may mean Enlightenment will either not function, or\n"
-		"function incorrectly. If it is later than X11, then your\n"
-		"server is one the author of Enlightenment neither have\n"
-		"access to, nor have heard of.\n"), ProtocolVersion(disp));
+	ASSIGN_ALERT(_("X server version error"), _("Ignore this error"), "",
+		     _("Quit Enlightenment"));
+	Alert(_
+	      ("WARNING:\n"
+	       "This is not an X11 Xserver. It in fact talks the X%i protocol.\n"
+	       "This may mean Enlightenment will either not function, or\n"
+	       "function incorrectly. If it is later than X11, then your\n"
+	       "server is one the author of Enlightenment neither have\n"
+	       "access to, nor have heard of.\n"), ProtocolVersion(disp));
 	RESET_ALERT;
      }
    /* now we'll set the locale */
@@ -496,11 +496,15 @@ SetupX()
    mode.mouse_over_win = NULL;
    mode.click_focus_grabbed = 0;
    mode.movemode = 0;
+   mode.swapmovemode = 0;
+   mode.swapcoord_x = mode.swapcoord_y = 0;
+   mode.dockapp_support = 1;
    mode.dockdirmode = DOCK_DOWN;
    mode.dockstartx = 0;
    mode.dockstarty = 0;
    mode.primaryicondir = ICON_RIGHT;
    mode.resizemode = 1;
+   mode.geominfomode = 1;
    mode.slidemode = 0;
    mode.cleanupslide = 1;
    mode.mapslide = 1;
@@ -596,6 +600,7 @@ SetupX()
    mode.group_config.stick = 1;
    mode.group_config.shade = 1;
    mode.group_config.mirror = 1;
+   mode.group_swapmove = 1;
    mode.area_wraparound = 0;
    mode.dialog_headers = 0;
    mode.clickalways = 0;
@@ -611,11 +616,8 @@ SetupX()
    SetAreaSize(2, 1);
 
 #ifdef HAS_XINERAMA
-   {
-
-      xinerama_active = XineramaIsActive(disp);
-
-   }
+   xinerama_active = XineramaIsActive(disp);
+   mode.extra_head = 0;
 #endif
 
    for (i = 0; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; task_menu[i++] = NULL);
@@ -630,32 +632,34 @@ ChkDir(char *d)
 {
    if (!isdir(d))
      {
-	Alert(_("The directory %s is apparently not a directory\n"
-		"This is a fatal condition.\n" "Please remove this file\n"), d);
+	Alert(_
+	      ("The directory %s is apparently not a directory\n"
+	       "This is a fatal condition.\n" "Please remove this file\n"), d);
 	EExit((void *)1);
      }
    if (!canexec(d))
      {
-	Alert(_("Do not have execute access to %s\n"
-		"This is a fatal condition.\n"
-		"Please check the ownership and permissions of this\n"
-		"directory and take steps to rectify this.\n"), d);
+	Alert(_
+	      ("Do not have execute access to %s\n"
+	       "This is a fatal condition.\n"
+	       "Please check the ownership and permissions of this\n"
+	       "directory and take steps to rectify this.\n"), d);
 	EExit((void *)1);
      }
    if (!canread(d))
      {
-	Alert(_("Do not have read access to %s\n"
-		"This is a fatal condition.\n"
-		"Please check the ownership and permissions of this\n"
-		"directory and take steps to rectify this.\n"), d);
+	Alert(_
+	      ("Do not have read access to %s\n" "This is a fatal condition.\n"
+	       "Please check the ownership and permissions of this\n"
+	       "directory and take steps to rectify this.\n"), d);
 	EExit((void *)1);
      }
    if (!canwrite(d))
      {
-	Alert(_("Do not have write access to %s\n"
-		"This is a fatal condition.\n"
-		"Please check the ownership and permissions of this\n"
-		"directory and take steps to rectify this.\n"), d);
+	Alert(_
+	      ("Do not have write access to %s\n" "This is a fatal condition.\n"
+	       "Please check the ownership and permissions of this\n"
+	       "directory and take steps to rectify this.\n"), d);
 	EExit((void *)1);
      }
 }
@@ -751,8 +755,7 @@ SetupEnv()
    return;
 }
 
-Window
-MakeExtInitWin(void)
+Window MakeExtInitWin(void)
 {
    Display            *d2;
    Window              win;
@@ -820,10 +823,11 @@ MakeExtInitWin(void)
    attr.border_pixel = 0;
    attr.background_pixel = 0;
    attr.save_under = True;
-   win = XCreateWindow(d2, root.win, 0, 0, root.w, root.h, 0, root.depth,
-		       InputOutput, root.vis,
-		       CWOverrideRedirect | CWSaveUnder | CWBackingStore |
-		       CWColormap | CWBackPixel | CWBorderPixel, &attr);
+   win =
+      XCreateWindow(d2, root.win, 0, 0, root.w, root.h, 0, root.depth,
+		    InputOutput, root.vis,
+		    CWOverrideRedirect | CWSaveUnder | CWBackingStore |
+		    CWColormap | CWBackPixel | CWBorderPixel, &attr);
    pmap = ECreatePixmap(d2, win, root.w, root.h, root.depth);
    gcv.subwindow_mode = IncludeInferiors;
    gc = XCreateGC(d2, win, GCSubwindowMode, &gcv);
@@ -834,8 +838,8 @@ MakeExtInitWin(void)
    XFreeGC(d2, gc);
    val = win;
    a = XInternAtom(d2, "ENLIGHTENMENT_RESTART_SCREEN", False);
-   XChangeProperty(d2, root.win, a, XA_CARDINAL, 32,
-		   PropModeReplace, (unsigned char *)&val, 1);
+   XChangeProperty(d2, root.win, a, XA_CARDINAL, 32, PropModeReplace,
+		   (unsigned char *)&val, 1);
    XSelectInput(d2, win, StructureNotifyMask);
    XUngrabServer(d2);
    XSync(d2, False);
@@ -874,10 +878,11 @@ MakeExtInitWin(void)
 	GC                  gc;
 	XGCValues           gcv;
 
-	w2 = XCreateWindow(d2, win, 0, 0, 32, 32, 0, root.depth,
-			   InputOutput, root.vis, CWOverrideRedirect |
-			   CWBackingStore | CWColormap | CWBackPixel |
-			   CWBorderPixel, &attr);
+	w2 =
+	   XCreateWindow(d2, win, 0, 0, 32, 32, 0, root.depth, InputOutput,
+			 root.vis,
+			 CWOverrideRedirect | CWBackingStore | CWColormap |
+			 CWBackPixel | CWBorderPixel, &attr);
 	pmap = ECreatePixmap(d2, w2, 16, 16, 1);
 	gc = XCreateGC(d2, pmap, 0, &gcv);
 	XSetForeground(d2, gc, 0);
@@ -919,10 +924,9 @@ MakeExtInitWin(void)
 		  Imlib_free_pixmap(imd, pmap);
 		  XClearWindow(d2, w2);
 		  XQueryPointer(d2, win, &ww, &ww, &dd, &dd, &x, &y, &mm);
-		  EMoveResizeWindow(d2, w2,
-				    x - (im->rgb_width / 2),
-				    y - (im->rgb_height / 2),
-				    im->rgb_width, im->rgb_height);
+		  EMoveResizeWindow(d2, w2, x - (im->rgb_width / 2),
+				    y - (im->rgb_height / 2), im->rgb_width,
+				    im->rgb_height);
 		  EMapWindow(d2, w2);
 	       }
 	     tv.tv_sec = 0;
@@ -969,8 +973,8 @@ SetupUserInitialization(void)
 	if (fork())
 	   EDBUG_RETURN_;
 	Esnprintf(file, sizeof(file), "exec %s/e_gen_menu", ENLIGHTENMENT_BIN);
-	execl(usershell(getuid()), usershell(getuid()), "-c",
-	      (char *)file, NULL);
+	execl(usershell(getuid()), usershell(getuid()), "-c", (char *)file,
+	      NULL);
 	exit(0);
 
      }
