@@ -1,3 +1,4 @@
+
 /*
  * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
  *
@@ -84,7 +85,8 @@ MaxHeight(EWin * ewin, char *resize_type)
 						if (screens[i].y_org +
 						    screens[i].height < y2)
 						  {
-						     y2 = screens[i].y_org +
+						     y2 =
+							screens[i].y_org +
 							screens[i].height;
 						  }
 					     }
@@ -96,11 +98,10 @@ MaxHeight(EWin * ewin, char *resize_type)
 #endif
 		  for (i = 0; i < num; i++)
 		    {
-		       if (
-			   (((ewin->desktop
-			      == lst[i]->desktop) && !(lst[i]->iconified))
-			    || (lst[i]->sticky)) && (!(lst[i]->floating))
-			   && (lst[i] != ewin) && (!(lst[i]->ignorearrange))
+		       if ((((ewin->desktop == lst[i]->desktop)
+			     && !(lst[i]->iconified)) || (lst[i]->sticky))
+			   && (!(lst[i]->floating)) && (lst[i] != ewin)
+			   && (!(lst[i]->ignorearrange))
 			   && SPANS_COMMON(ewin->x, ewin->w, lst[i]->x,
 					   lst[i]->w))
 			 {
@@ -114,8 +115,9 @@ MaxHeight(EWin * ewin, char *resize_type)
 		    }
 		  Efree(lst);
 		  y = y1;
-		  h = y2 - y1 -
-		     (ewin->border->border.top + ewin->border->border.bottom);
+		  h =
+		     y2 - y1 - (ewin->border->border.top +
+				ewin->border->border.bottom);
 	       }
 	  }
 	else if ((resize_type) && (!strcmp(resize_type, "conservative")))
@@ -165,7 +167,8 @@ MaxHeight(EWin * ewin, char *resize_type)
 						if (screens[i].y_org +
 						    screens[i].height < y2)
 						  {
-						     y2 = screens[i].y_org +
+						     y2 =
+							screens[i].y_org +
 							screens[i].height;
 						  }
 					     }
@@ -177,16 +180,15 @@ MaxHeight(EWin * ewin, char *resize_type)
 #endif
 		  for (i = 0; i < num; i++)
 		    {
-		       if (
-			   (((ewin->desktop == lst[i]->desktop)
+		       if ((((ewin->desktop == lst[i]->desktop)
 			     && !(lst[i]->iconified)) || (lst[i]->sticky))
 			   && (!(lst[i]->floating)) && (lst[i] != ewin)
 			   && (lst[i]->never_use_area)
 			   && SPANS_COMMON(ewin->x, ewin->w, lst[i]->x,
 					   lst[i]->w))
 			 {
-			    if (((lst[i]->y + lst[i]->h) <= y) &&
-				((lst[i]->y + lst[i]->h) >= y1))
+			    if (((lst[i]->y + lst[i]->h) <= y)
+				&& ((lst[i]->y + lst[i]->h) >= y1))
 			       y1 = lst[i]->y + lst[i]->h;
 			    else if (((y + h) <= lst[i]->y)
 				     && (y2 >= lst[i]->y))
@@ -195,8 +197,9 @@ MaxHeight(EWin * ewin, char *resize_type)
 		    }
 		  Efree(lst);
 		  y = y1;
-		  h = y2 - y1 -
-		     (ewin->border->border.top + ewin->border->border.bottom);
+		  h =
+		     y2 - y1 - (ewin->border->border.top +
+				ewin->border->border.bottom);
 	       }
 	  }
 	ewin->lx = ewin->x;
@@ -281,7 +284,8 @@ MaxWidth(EWin * ewin, char *resize_type)
 						if (screens[i].x_org +
 						    screens[i].width < x2)
 						  {
-						     x2 = screens[i].x_org +
+						     x2 =
+							screens[i].x_org +
 							screens[i].width;
 						  }
 					     }
@@ -293,16 +297,15 @@ MaxWidth(EWin * ewin, char *resize_type)
 #endif
 		  for (i = 0; i < num; i++)
 		    {
-		       if (
-			   (((ewin->desktop == lst[i]->desktop)
+		       if ((((ewin->desktop == lst[i]->desktop)
 			     && !(lst[i]->iconified)) || (lst[i]->sticky))
 			   && (!(lst[i]->floating)) && (lst[i] != ewin)
 			   && (!(lst[i]->ignorearrange))
 			   && SPANS_COMMON(ewin->y, ewin->h, lst[i]->y,
 					   lst[i]->h))
 			 {
-			    if (((lst[i]->x + lst[i]->w) <= x) &&
-				((lst[i]->x + lst[i]->w) >= x1))
+			    if (((lst[i]->x + lst[i]->w) <= x)
+				&& ((lst[i]->x + lst[i]->w) >= x1))
 			       x1 = lst[i]->x + lst[i]->w;
 			    else if (((x + w) <= lst[i]->x)
 				     && (x2 >= lst[i]->x))
@@ -311,8 +314,9 @@ MaxWidth(EWin * ewin, char *resize_type)
 		    }
 		  Efree(lst);
 		  x = x1;
-		  w = x2 - x1 -
-		     (ewin->border->border.left + ewin->border->border.right);
+		  w =
+		     x2 - x1 - (ewin->border->border.left +
+				ewin->border->border.right);
 	       }
 	  }
 	else if ((resize_type) && (!strcmp(resize_type, "conservative")))
@@ -362,7 +366,8 @@ MaxWidth(EWin * ewin, char *resize_type)
 						if (screens[i].x_org +
 						    screens[i].width < x2)
 						  {
-						     x2 = screens[i].x_org +
+						     x2 =
+							screens[i].x_org +
 							screens[i].width;
 						  }
 					     }
@@ -374,15 +379,17 @@ MaxWidth(EWin * ewin, char *resize_type)
 #endif
 		  for (i = 0; i < num; i++)
 		    {
-		       if ((lst[i] != ewin) && (!(lst[i]->ignorearrange)) &&
-			   (!(lst[i]->floating)) && !(lst[i]->iconified) &&
-			   (((ewin->desktop == lst[i]->desktop) &&
-			     (lst[i]->fixedpos)) ||
-			    (lst[i]->sticky)) &&
-			   SPANS_COMMON(ewin->y, ewin->h, lst[i]->y, lst[i]->h))
+		       if ((lst[i] != ewin) && (!(lst[i]->ignorearrange))
+			   && (!(lst[i]->floating)) && !(lst[i]->iconified)
+			   &&
+			   (((ewin->desktop
+			      == lst[i]->desktop) && (lst[i]->fixedpos))
+			    || (lst[i]->sticky))
+			   && SPANS_COMMON(ewin->y, ewin->h, lst[i]->y,
+					   lst[i]->h))
 			 {
-			    if (((lst[i]->x + lst[i]->w) <= x) &&
-				((lst[i]->x + lst[i]->w) >= x1))
+			    if (((lst[i]->x + lst[i]->w) <= x)
+				&& ((lst[i]->x + lst[i]->w) >= x1))
 			       x1 = lst[i]->x + lst[i]->w;
 			    else if (((x + w) <= lst[i]->x)
 				     && (x2 >= lst[i]->x))
@@ -391,8 +398,9 @@ MaxWidth(EWin * ewin, char *resize_type)
 		    }
 		  Efree(lst);
 		  x = x1;
-		  w = x2 - x1 -
-		     (ewin->border->border.left + ewin->border->border.right);
+		  w =
+		     x2 - x1 - (ewin->border->border.left +
+				ewin->border->border.right);
 	       }
 	  }
 	ewin->lx = ewin->x;
@@ -483,7 +491,8 @@ MaxSize(EWin * ewin, char *resize_type)
 						if (screens[i].x_org +
 						    screens[i].width < x2)
 						  {
-						     x2 = screens[i].x_org +
+						     x2 =
+							screens[i].x_org +
 							screens[i].width;
 						  }
 						if (screens[i].y_org > y1)
@@ -493,7 +502,8 @@ MaxSize(EWin * ewin, char *resize_type)
 						if (screens[i].y_org +
 						    screens[i].height < y2)
 						  {
-						     y2 = screens[i].y_org +
+						     y2 =
+							screens[i].y_org +
 							screens[i].height;
 						  }
 					     }
@@ -505,16 +515,15 @@ MaxSize(EWin * ewin, char *resize_type)
 #endif
 		  for (i = 0; i < num; i++)
 		    {
-		       if (
-			   (((ewin->desktop == lst[i]->desktop)
+		       if ((((ewin->desktop == lst[i]->desktop)
 			     && !(lst[i]->iconified)) || (lst[i]->sticky))
 			   && (!(lst[i]->floating)) && (lst[i] != ewin)
 			   && (!(lst[i]->ignorearrange))
 			   && SPANS_COMMON(ewin->x, ewin->w, lst[i]->x,
 					   lst[i]->w))
 			 {
-			    if (((lst[i]->y + lst[i]->h) <= y) &&
-				((lst[i]->y + lst[i]->h) >= y1))
+			    if (((lst[i]->y + lst[i]->h) <= y)
+				&& ((lst[i]->y + lst[i]->h) >= y1))
 			       y1 = lst[i]->y + lst[i]->h;
 			    else if (((y + h) <= lst[i]->y)
 				     && (y2 >= lst[i]->y))
@@ -522,19 +531,18 @@ MaxSize(EWin * ewin, char *resize_type)
 			 }
 		    }
 		  y = y1;
-		  h = y2 - y1 -
-		     (ewin->border->border.top + ewin->border->border.bottom);
+		  h =
+		     y2 - y1 - (ewin->border->border.top +
+				ewin->border->border.bottom);
 		  for (i = 0; i < num; i++)
 		    {
-		       if (((ewin->desktop == lst[i]->desktop) ||
-			    (lst[i]->sticky)) &&
-			   (!(lst[i]->floating)) &&
-			   (lst[i] != ewin) &&
-			   (!(lst[i]->ignorearrange)) &&
-			   SPANS_COMMON(y, h, lst[i]->y, lst[i]->h))
+		       if (((ewin->desktop == lst[i]->desktop)
+			    || (lst[i]->sticky)) && (!(lst[i]->floating))
+			   && (lst[i] != ewin) && (!(lst[i]->ignorearrange))
+			   && SPANS_COMMON(y, h, lst[i]->y, lst[i]->h))
 			 {
-			    if (((lst[i]->x + lst[i]->w) <= x) &&
-				((lst[i]->x + lst[i]->w) >= x1))
+			    if (((lst[i]->x + lst[i]->w) <= x)
+				&& ((lst[i]->x + lst[i]->w) >= x1))
 			       x1 = lst[i]->x + lst[i]->w;
 			    else if (((x + w) <= lst[i]->x)
 				     && (x2 >= lst[i]->x))
@@ -542,8 +550,9 @@ MaxSize(EWin * ewin, char *resize_type)
 			 }
 		    }
 		  x = x1;
-		  w = x2 - x1 -
-		     (ewin->border->border.left + ewin->border->border.right);
+		  w =
+		     x2 - x1 - (ewin->border->border.left +
+				ewin->border->border.right);
 		  Efree(lst);
 	       }
 	  }
@@ -600,7 +609,8 @@ MaxSize(EWin * ewin, char *resize_type)
 						if (screens[i].x_org +
 						    screens[i].width < x2)
 						  {
-						     x2 = screens[i].x_org +
+						     x2 =
+							screens[i].x_org +
 							screens[i].width;
 						  }
 						if (screens[i].y_org > y1)
@@ -610,7 +620,8 @@ MaxSize(EWin * ewin, char *resize_type)
 						if (screens[i].y_org +
 						    screens[i].height < y2)
 						  {
-						     y2 = screens[i].y_org +
+						     y2 =
+							screens[i].y_org +
 							screens[i].height;
 						  }
 					     }
@@ -622,8 +633,7 @@ MaxSize(EWin * ewin, char *resize_type)
 #endif
 		  for (i = 0; i < num; i++)
 		    {
-		       if (
-			   ((lst[i] != ewin) && (!(lst[i]->ignorearrange))
+		       if (((lst[i] != ewin) && (!(lst[i]->ignorearrange))
 			    && !(lst[i]->iconified)) && (!(lst[i]->floating))
 			   &&
 			   (((ewin->desktop
@@ -632,8 +642,8 @@ MaxSize(EWin * ewin, char *resize_type)
 			   && SPANS_COMMON(ewin->x, ewin->w, lst[i]->x,
 					   lst[i]->w))
 			 {
-			    if (((lst[i]->y + lst[i]->h) <= y) &&
-				((lst[i]->y + lst[i]->h) >= y1))
+			    if (((lst[i]->y + lst[i]->h) <= y)
+				&& ((lst[i]->y + lst[i]->h) >= y1))
 			       y1 = lst[i]->y + lst[i]->h;
 			    else if (((y + h) <= lst[i]->y)
 				     && (y2 >= lst[i]->y))
@@ -641,19 +651,21 @@ MaxSize(EWin * ewin, char *resize_type)
 			 }
 		    }
 		  y = y1;
-		  h = y2 - y1 -
-		     (ewin->border->border.top + ewin->border->border.bottom);
+		  h =
+		     y2 - y1 - (ewin->border->border.top +
+				ewin->border->border.bottom);
 		  for (i = 0; i < num; i++)
 		    {
-		       if ((lst[i] != ewin) && (!(lst[i]->ignorearrange)) &&
-			   (!(lst[i]->floating)) &&
-			   (((ewin->desktop == lst[i]->desktop) &&
-			     (lst[i]->fixedpos)) ||
-			    (lst[i]->sticky)) &&
-			   SPANS_COMMON(y, h, lst[i]->y, lst[i]->h))
+		       if ((lst[i] != ewin) && (!(lst[i]->ignorearrange))
+			   && (!(lst[i]->floating))
+			   &&
+			   (((ewin->desktop
+			      == lst[i]->desktop) && (lst[i]->fixedpos))
+			    || (lst[i]->sticky))
+			   && SPANS_COMMON(y, h, lst[i]->y, lst[i]->h))
 			 {
-			    if (((lst[i]->x + lst[i]->w) <= x) &&
-				((lst[i]->x + lst[i]->w) >= x1))
+			    if (((lst[i]->x + lst[i]->w) <= x)
+				&& ((lst[i]->x + lst[i]->w) >= x1))
 			       x1 = lst[i]->x + lst[i]->w;
 			    else if (((x + w) <= lst[i]->x)
 				     && (x2 >= lst[i]->x))
@@ -661,8 +673,9 @@ MaxSize(EWin * ewin, char *resize_type)
 			 }
 		    }
 		  x = x1;
-		  w = x2 - x1 -
-		     (ewin->border->border.left + ewin->border->border.right);
+		  w =
+		     x2 - x1 - (ewin->border->border.left +
+				ewin->border->border.right);
 		  Efree(lst);
 	       }
 	  }
