@@ -23,8 +23,8 @@
 #include "E.h"
 
 void
-SlideWindowSizeTo(Window win, int fx, int fy, int tx, int ty,
-		  int fw, int fh, int tw, int th, int speed)
+SlideWindowSizeTo(Window win, int fx, int fy, int tx, int ty, int fw, int fh,
+		  int tw, int th, int speed)
 {
    int                 k, spd, x, y, min, w, h;
    struct timeval      timev1, timev2;
@@ -181,8 +181,8 @@ ShowSlideout(Slideout * s, Window win)
 	EMoveResizeWindow(disp, s->win, xx, yy, 1, 1);
 	XSync(disp, False);
 	EMapRaised(disp, s->win);
-	SlideWindowSizeTo(s->win, xx + s->w, yy, xx, yy,
-			  0, s->h, s->w, s->h, mode.slidespeedmap);
+	SlideWindowSizeTo(s->win, xx + s->w, yy, xx, yy, 0, s->h, s->w, s->h,
+			  mode.slidespeedmap);
 	break;
      case 1:
 	att.win_gravity = NorthWestGravity;
@@ -193,8 +193,8 @@ ShowSlideout(Slideout * s, Window win)
 	EMoveResizeWindow(disp, s->win, xx, yy, 1, 1);
 	XSync(disp, False);
 	EMapRaised(disp, s->win);
-	SlideWindowSizeTo(s->win, xx, yy, xx, yy,
-			  0, s->h, s->w, s->h, mode.slidespeedmap);
+	SlideWindowSizeTo(s->win, xx, yy, xx, yy, 0, s->h, s->w, s->h,
+			  mode.slidespeedmap);
 	break;
      case 2:
 	att.win_gravity = SouthEastGravity;
@@ -205,8 +205,8 @@ ShowSlideout(Slideout * s, Window win)
 	EMoveResizeWindow(disp, s->win, xx, yy, 1, 1);
 	XSync(disp, False);
 	EMapRaised(disp, s->win);
-	SlideWindowSizeTo(s->win, xx, yy + s->h, xx, yy,
-			  s->w, 0, s->w, s->h, mode.slidespeedmap);
+	SlideWindowSizeTo(s->win, xx, yy + s->h, xx, yy, s->w, 0, s->w, s->h,
+			  mode.slidespeedmap);
 	break;
      case 3:
 	att.win_gravity = NorthWestGravity;
@@ -217,8 +217,8 @@ ShowSlideout(Slideout * s, Window win)
 	EMoveResizeWindow(disp, s->win, xx, yy, 1, 1);
 	XSync(disp, False);
 	EMapRaised(disp, s->win);
-	SlideWindowSizeTo(s->win, xx, yy, xx, yy,
-			  s->w, 0, s->w, s->h, mode.slidespeedmap);
+	SlideWindowSizeTo(s->win, xx, yy, xx, yy, s->w, 0, s->w, s->h,
+			  mode.slidespeedmap);
 	break;
      default:
 	break;
@@ -291,12 +291,12 @@ CalcSlideoutSize(Slideout * s)
 	  {
 	  case 2:
 	     y += s->button[i]->h;
-	     EMoveWindow(disp, s->button[i]->win,
-			 (s->w - s->button[i]->w) >> 1, s->h - y);
+	     EMoveWindow(disp, s->button[i]->win, (s->w - s->button[i]->w) >> 1,
+			 s->h - y);
 	     break;
 	  case 3:
-	     EMoveWindow(disp, s->button[i]->win,
-			 (s->w - s->button[i]->w) >> 1, y);
+	     EMoveWindow(disp, s->button[i]->win, (s->w - s->button[i]->w) >> 1,
+			 y);
 	     y += s->button[i]->h;
 	     break;
 	  case 0:
