@@ -1,3 +1,4 @@
+
 /*
  * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
  *
@@ -397,15 +398,15 @@ SnapshotEwinDialog(EWin * ewin)
 
 	     s[0] = 0;
 	     slice = 64;
-	     while ((i <= (int)strlen(ewin->client.command)) &&
-		    (i < (int)(sizeof(s) / 4)))
+	     while ((i <= (int)strlen(ewin->client.command))
+		    && (i < (int)(sizeof(s) / 4)))
 	       {
 		  last = i;
 		  i += 64;
 		  slice = 64;
 		  /* and make sure that we don't cut in the middle of a word. */
-		  while ((ewin->client.command[i++] != ' ') &&
-			 (i < (int)(sizeof(s) / 4)))
+		  while ((ewin->client.command[i++] != ' ')
+			 && (i < (int)(sizeof(s) / 4)))
 		     slice++;
 		  strncat(s, ewin->client.command + last, slice);
 		  if (i < (int)(sizeof(s) / 4))
@@ -961,7 +962,7 @@ LoadSnapInfo(void)
    Esnprintf(buf, sizeof(buf), "%s.snapshots.%i", GetSMFile(), root.scr);
    if (!exists(buf))
       Esnprintf(buf, sizeof(buf), "%s.snapshots.%i", GetGenericSMFile(),
-		root.scr);
+                root.scr);
 #ifndef __EMX__
    f = fopen(buf, "r");
 #else
@@ -1172,9 +1173,8 @@ MatchEwinToSnapInfo(EWin * ewin)
 	  }
 	ewin->x = ewin->client.x;
 	ewin->y = ewin->client.y;
-	EMoveResizeWindow(disp, ewin->client.win,
-			  ewin->client.x, ewin->client.y,
-			  ewin->client.w, ewin->client.h);
+	EMoveResizeWindow(disp, ewin->client.win, ewin->client.x,
+			  ewin->client.y, ewin->client.w, ewin->client.h);
      }
    if (sn->use_layer)
       ewin->layer = sn->layer;
@@ -1196,8 +1196,9 @@ MatchEwinToSnapInfo(EWin * ewin)
      }
    if (sn->border_name)
      {
-	b = (Border *) FindItem(sn->border_name, 0, LIST_FINDBY_NAME,
-				LIST_TYPE_BORDER);
+	b =
+	   (Border *) FindItem(sn->border_name, 0, LIST_FINDBY_NAME,
+			       LIST_TYPE_BORDER);
 	if (b)
 	  {
 	     ewin->border_new = 1;
@@ -1211,8 +1212,9 @@ MatchEwinToSnapInfo(EWin * ewin)
 	  {
 	     Group              *g;
 
-	     g = (Group *) FindItem(NULL, sn->groups[i], LIST_FINDBY_ID,
-				    LIST_TYPE_GROUP);
+	     g =
+		(Group *) FindItem(NULL, sn->groups[i], LIST_FINDBY_ID,
+				   LIST_TYPE_GROUP);
 	     if (!g)
 	       {
 		  BuildWindowGroup(&ewin, 1);
@@ -1300,8 +1302,7 @@ MatchEwinToSnapInfoAfter(EWin * ewin)
    if (sn->use_xy)
      {
 	if ((ewin->pager) || (ewin->ibox))
-	   MoveEwin(ewin,
-		    sn->x - ewin->border->border.left,
+	   MoveEwin(ewin, sn->x - ewin->border->border.left,
 		    sn->y - ewin->border->border.top);
 	else
 	  {
@@ -1314,17 +1315,20 @@ MatchEwinToSnapInfoAfter(EWin * ewin)
 				desks.desk[ewin->desktop].current_area_x) *
 			       root.w),
 			      sn->y +
-			      ((sn->area_y -
+			      ((sn->area_y
+				-
 				desks.desk[ewin->desktop].current_area_y) *
 			       root.h));
 		  else
 		     MoveEwin(ewin,
 			      sn->x +
-			      ((sn->area_x -
+			      ((sn->area_x
+				-
 				desks.desk[desks.current].current_area_x) *
 			       root.w),
 			      sn->y +
-			      ((sn->area_y -
+			      ((sn->area_y
+				-
 				desks.desk[desks.current].current_area_y) *
 			       root.h));
 	       }
@@ -1365,8 +1369,9 @@ MatchEwinToSnapInfoAfter(EWin * ewin)
      }
    if (sn->border_name)
      {
-	b = (Border *) FindItem(sn->border_name, 0, LIST_FINDBY_NAME,
-				LIST_TYPE_BORDER);
+	b =
+	   (Border *) FindItem(sn->border_name, 0, LIST_FINDBY_NAME,
+			       LIST_TYPE_BORDER);
 	if (b)
 	  {
 	     ewin->border_new = 1;
@@ -1382,8 +1387,9 @@ MatchEwinToSnapInfoAfter(EWin * ewin)
 	  {
 	     Group              *g;
 
-	     g = (Group *) FindItem(NULL, sn->groups[i], LIST_FINDBY_ID,
-				    LIST_TYPE_GROUP);
+	     g =
+		(Group *) FindItem(NULL, sn->groups[i], LIST_FINDBY_ID,
+				   LIST_TYPE_GROUP);
 	     if (!g)
 	       {
 		  BuildWindowGroup(&ewin, 1);
