@@ -1,3 +1,4 @@
+
 /*
  * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
  *
@@ -246,8 +247,8 @@ TclassApply(ImageClass * iclass, Window win, int w, int h, int active,
      }
    XClearWindow(disp, win);
 
-   TextDraw(tclass, win, active, sticky, state, text,
-	    iclass->padding.left, iclass->padding.top,
+   TextDraw(tclass, win, active, sticky, state, text, iclass->padding.left,
+	    iclass->padding.top,
 	    w - (iclass->padding.left + iclass->padding.right),
 	    h - (iclass->padding.top + iclass->padding.bottom),
 	    h - (iclass->padding.top + iclass->padding.bottom),
