@@ -180,8 +180,9 @@ TextStateLoadFont(TextState * ts)
 	     char              **missing_list, *def_str, **fn;
 	     XFontStruct       **fs;
 
-	     ts->xfontset = XCreateFontSet(disp, ts->fontname, &missing_list,
-					   &missing_cnt, &def_str);
+	     ts->xfontset =
+		XCreateFontSet(disp, ts->fontname, &missing_list, &missing_cnt,
+			       &def_str);
 	     if (missing_cnt)
 	       {
 		  XFreeStringList(missing_list);
@@ -223,10 +224,9 @@ TextSize(TextClass * tclass, int active, int sticky, int state, char *text,
 	  {
 	     int                 high, wid, dummy;
 
-	     Fnlib_measure(fd, ts->font, 0, 0, 999999, 999999,
-			   0, 0, fsize, &ts->style, (unsigned char *)lines[i],
-			   0, 0, &dummy, &dummy, &wid, &high, &dummy,
-			   &dummy, &dummy, &dummy);
+	     Fnlib_measure(fd, ts->font, 0, 0, 999999, 999999, 0, 0, fsize,
+			   &ts->style, (unsigned char *)lines[i], 0, 0, &dummy,
+			   &dummy, &wid, &high, &dummy, &dummy, &dummy, &dummy);
 	     *height += high;
 	     if (wid > *width)
 		*width = wid;
@@ -238,8 +238,8 @@ TextSize(TextClass * tclass, int active, int sticky, int state, char *text,
 	  {
 	     int                 ascent, descent, wid;
 
-	     Efont_extents(ts->efont, lines[i], &ascent, &descent, &wid,
-			   NULL, NULL, NULL, NULL);
+	     Efont_extents(ts->efont, lines[i], &ascent, &descent, &wid, NULL,
+			   NULL, NULL, NULL);
 	     *height += ascent + descent;
 	     if (wid > *width)
 		*width = wid;
@@ -258,8 +258,8 @@ TextSize(TextClass * tclass, int active, int sticky, int state, char *text,
 		*width = ret2.width;
 	  }
      }
-   else if ((ts->xfont) && (ts->xfont->min_byte1 == 0) &&
-	    (ts->xfont->max_byte1 == 0))
+   else if ((ts->xfont) && (ts->xfont->min_byte1 == 0)
+	    && (ts->xfont->max_byte1 == 0))
      {
 	for (i = 0; i < num_lines; i++)
 	  {
@@ -277,8 +277,9 @@ TextSize(TextClass * tclass, int active, int sticky, int state, char *text,
 	  {
 	     int                 wid;
 
-	     wid = XTextWidth16(ts->xfont, (XChar2b *) lines[i],
-				strlen(lines[i]) / 2);
+	     wid =
+		XTextWidth16(ts->xfont, (XChar2b *) lines[i],
+			     strlen(lines[i]) / 2);
 	     *height += ts->xfont->ascent + ts->xfont->descent;
 	     if (wid > *width)
 		*width = wid;
@@ -317,8 +318,7 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
       gc = XCreateGC(disp, win, 0, &gcv);
 
    if (ts->style.orientation == FONT_TO_RIGHT
-       || ts->style.orientation == FONT_TO_LEFT)
-      textwidth_limit = w;
+       || ts->style.orientation == FONT_TO_LEFT) textwidth_limit = w;
    else
       textwidth_limit = h;
 
@@ -328,16 +328,15 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 	  {
 	     int                 high, wid, dummy;
 
-	     Fnlib_measure(fd, ts->font, 0, 0, 999999, 999999,
-			   0, 0, fsize, &ts->style, (unsigned char *)lines[i],
-			   0, 0, &dummy, &dummy, &wid, &high, &dummy,
-			   &dummy, &dummy, &dummy);
-	     if ((ts->style.orientation == FONT_TO_UP) ||
-		 (ts->style.orientation == FONT_TO_DOWN))
+	     Fnlib_measure(fd, ts->font, 0, 0, 999999, 999999, 0, 0, fsize,
+			   &ts->style, (unsigned char *)lines[i], 0, 0, &dummy,
+			   &dummy, &wid, &high, &dummy, &dummy, &dummy, &dummy);
+	     if ((ts->style.orientation == FONT_TO_UP)
+		 || (ts->style.orientation == FONT_TO_DOWN))
 		fsize = w;
 	     xx = x + (((w - wid) * justification) >> 10);
-	     Fnlib_draw(fd, ts->font, win, 0, xx, yy, w, h,
-			0, 0, fsize, &ts->style, (unsigned char *)lines[i]);
+	     Fnlib_draw(fd, ts->font, win, 0, xx, yy, w, h, 0, 0, fsize,
+			&ts->style, (unsigned char *)lines[i]);
 	     yy += high;
 	  }
      }
@@ -347,8 +346,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 	  {
 	     int                 ascent, descent, wid;
 
-	     Efont_extents(ts->efont, lines[i], &ascent, &descent, &wid,
-			   NULL, NULL, NULL, NULL);
+	     Efont_extents(ts->efont, lines[i], &ascent, &descent, &wid, NULL,
+			   NULL, NULL, NULL);
 	     if (wid > textwidth_limit)
 	       {
 		  char               *new_line;
@@ -437,8 +436,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 	     g = ts->fg_col.g;
 	     b = ts->fg_col.b;
 	     XSetForeground(disp, gc, Imlib_best_color_match(id, &r, &g, &b));
-	     EFont_draw_string(disp, drawable, gc, offset_x, offset_y,
-			       lines[i], ts->efont, Imlib_get_visual(id),
+	     EFont_draw_string(disp, drawable, gc, offset_x, offset_y, lines[i],
+			       ts->efont, Imlib_get_visual(id),
 			       Imlib_get_colormap(id));
 
 	     TextDrawRotBack(win, drawable, xx - 1, yy - 1 - ascent, wid + 2,
@@ -483,8 +482,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 			    int                 mlen;
 
 			    new_line[0] = 0;
-			    if (MB_CUR_MAX > 1 && wc_len > 0)	/* if multibyte locale,... */
-			      {
+			    if (MB_CUR_MAX > 1 && wc_len > 0)
+			      {	/* if multibyte locale,... */
 				 mlen = mblen(lines[i], MB_CUR_MAX);
 				 if (mlen < 0)
 				    mlen = 1;
@@ -510,10 +509,10 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 			    new_line[j] = '\0';
 			    strcat(new_line, "...");
 			    j += 3;
-			    len_mb = wcstombs(new_line + j,
-					      wc_line + (wc_len -
-							 nuke_count) / 2 +
-					      nuke_count, len + 10 - j);
+			    len_mb =
+			       wcstombs(new_line + j,
+					wc_line + (wc_len - nuke_count) / 2 +
+					nuke_count, len + 10 - j);
 			    if (len_mb > 0)
 			       j += len_mb;
 			    new_line[j] = '\0';
@@ -599,8 +598,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 	     yy += ret2.height;
 	  }
      }
-   else if ((ts->xfont) && (ts->xfont->min_byte1 == 0) &&
-	    (ts->xfont->max_byte1 == 0))
+   else if ((ts->xfont) && (ts->xfont->min_byte1 == 0)
+	    && (ts->xfont->max_byte1 == 0))
      {
 	XSetFont(disp, gc, ts->xfont->fid);
 	for (i = 0; i < num_lines; i++)
@@ -691,8 +690,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 	     g = ts->fg_col.g;
 	     b = ts->fg_col.b;
 	     XSetForeground(disp, gc, Imlib_best_color_match(id, &r, &g, &b));
-	     XDrawString(disp, drawable, gc, offset_x, offset_y,
-			 lines[i], strlen(lines[i]));
+	     XDrawString(disp, drawable, gc, offset_x, offset_y, lines[i],
+			 strlen(lines[i]));
 
 	     TextDrawRotBack(win, drawable, xx - 1, yy - 1 - ascent, wid + 2,
 			     ascent + descent + 2, ts);
@@ -708,8 +707,9 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 	  {
 	     int                 wid, ascent, descent;
 
-	     wid = XTextWidth16(ts->xfont, (XChar2b *) lines[i],
-				strlen(lines[i]) / 2);
+	     wid =
+		XTextWidth16(ts->xfont, (XChar2b *) lines[i],
+			     strlen(lines[i]) / 2);
 	     ascent = ts->xfont->ascent;
 	     descent = ts->xfont->descent;
 	     if (wid > textwidth_limit)
