@@ -86,8 +86,8 @@ append_merge_dir(char *dir, char ***list, int *count)
 		       Esnprintf(s, sizeof(s), "%s/%s", dir, str[i]);
 		       if ((isdir(s)) && (SanitiseThemeDir(s)))
 			  ok = 1;
-		       else if ((isfile(s)) && (FileExtension(s)) &&
-				(!strcmp(FileExtension(s), "etheme")))
+		       else if ((isfile(s)) && (FileExtension(s))
+				&& (!strcmp(FileExtension(s), "etheme")))
 			  ok = 1;
 		       if (ok)
 			 {
@@ -345,11 +345,10 @@ BadThemeDialog(void)
       return;
 
    Esnprintf(s, sizeof(s),
-	     _("The theme:\n"
-	       "%s\n"
+	     _("The theme:\n" "%s\n"
 	       "Is a badly formed theme package and is thus not being used.\n"
 	       "Enlightenment has fallen back to using the DEFAULT theme.\n"
-	       "\n"
-	       "The reason this theme is bad is:\n" "%s"), badtheme, badreason);
+	       "\n" "The reason this theme is bad is:\n" "%s"), badtheme,
+	     badreason);
    DIALOG_OK(_("Bad Theme"), s);
 }
