@@ -486,8 +486,9 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		    }
 
-		  temp_w = cols[0] + cols[1] + cols[2] + cols[3] + cols[4] +
-		     cols[5] + cols[6] + cols[7] + cols[8] + cols[9];
+		  temp_w =
+		     cols[0] + cols[1] + cols[2] + cols[3] + cols[4] + cols[5] +
+		     cols[6] + cols[7] + cols[8] + cols[9];
 
 		  if (temp_w > icons_width)
 		     icons_width = temp_w;
@@ -646,8 +647,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
    xx = tt->iclass->padding.left + iw;
 
    /* draw the ordinary tooltip text */
-   TextDraw(tt->tclass, tt->win, 0, 0, STATE_NORMAL, text,
-	    xx, tt->iclass->padding.top, headline_w, headline_h, 17, 512);
+   TextDraw(tt->tclass, tt->win, 0, 0, STATE_NORMAL, text, xx,
+	    tt->iclass->padding.top, headline_w, headline_h, 17, 512);
 
    /* draw the icons and labels, if any */
    if (ac)
