@@ -134,8 +134,8 @@ calc_size(Efont * f, int *width, int *height, char *text)
 }
 
 static void
-render_text(TT_Raster_Map * rmap, TT_Raster_Map * rchr, Efont * f,
-	    char *text, int *xor, int *yor)
+render_text(TT_Raster_Map * rmap, TT_Raster_Map * rchr, Efont * f, char *text,
+	    int *xor, int *yor)
 {
    TT_Glyph_Metrics    metrics;
    TT_Instance_Metrics imetrics;
@@ -193,8 +193,8 @@ render_text(TT_Raster_Map * rmap, TT_Raster_Map * rchr, Efont * f,
 	/* This was the cause of strange misplacements when Bit.rows */
 	/* was unsigned.                                             */
 
-	if (xmin >= (int)rmap->width ||
-	    ymin >= (int)rmap->rows || xmax < 0 || ymax < 0)
+	if (xmin >= (int)rmap->width || ymin >= (int)rmap->rows || xmax < 0
+	    || ymax < 0)
 	   continue;
 
 	/* Note that the clipping check is performed _after_ rendering */
@@ -467,8 +467,8 @@ handle_x_error(Display * d, XErrorEvent * ev)
 }
 
 void
-EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y,
-		  char *text, Efont * font, Visual * vis, Colormap cm)
+EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y, char *text,
+		  Efont * font, Visual * vis, Colormap cm)
 {
    XImage             *xim;
    XShmSegmentInfo     shminfo;
@@ -499,8 +499,7 @@ EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y,
      {
 	x_error = 0;
 	is_pixmap = 1;
-	EGetGeometry(disp, win, &chld, &rx, &rx,
-		     (unsigned int *)&xatt.width,
+	EGetGeometry(disp, win, &chld, &rx, &rx, (unsigned int *)&xatt.width,
 		     (unsigned int *)&xatt.height, (unsigned int *)&rx,
 		     (unsigned int *)&xatt.depth);
 	XFlush(disp);
@@ -595,8 +594,9 @@ EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y,
 	  {
 	     erh = XSetErrorHandler((XErrorHandler) handle_x_error);
 	  }
-	xim = XShmCreateImage(disp, vis, xatt.depth, ZPixmap, NULL,
-			      &shminfo, width, height);
+	xim =
+	   XShmCreateImage(disp, vis, xatt.depth, ZPixmap, NULL, &shminfo,
+			   width, height);
 	if (!shm_checked)
 	  {
 	     XSync(disp, False);
@@ -612,8 +612,9 @@ EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y,
 	       }
 	     else
 	       {
-		  shminfo.shmid = shmget(IPC_PRIVATE, xim->bytes_per_line *
-					 xim->height, IPC_CREAT | 0666);
+		  shminfo.shmid =
+		     shmget(IPC_PRIVATE, xim->bytes_per_line * xim->height,
+			    IPC_CREAT | 0666);
 		  if (shminfo.shmid < 0)
 		    {
 		       shm = 0;
@@ -634,8 +635,9 @@ EFont_draw_string(Display * disp, Drawable win, GC gc, int x, int y,
 	  }
 	else
 	  {
-	     shminfo.shmid = shmget(IPC_PRIVATE, xim->bytes_per_line *
-				    xim->height, IPC_CREAT | 0666);
+	     shminfo.shmid =
+		shmget(IPC_PRIVATE, xim->bytes_per_line * xim->height,
+		       IPC_CREAT | 0666);
 	     if (shminfo.shmid < 0)
 	       {
 		  shm = 0;
@@ -809,8 +811,8 @@ Efont_load(char *file, int size)
    for (i = 0; i < n; i++)
      {
 	TT_Get_CharMap_ID(f->face, i, &platform, &encoding);
-	if ((platform == 3 && encoding == 1) ||
-	    (platform == 0 && encoding == 0))
+	if ((platform == 3 && encoding == 1)
+	    || (platform == 0 && encoding == 0))
 	  {
 	     TT_Get_CharMap(f->face, i, &char_map);
 	     break;
