@@ -60,8 +60,8 @@ WarpFocusInitEvents(void)
    int                 xkbMajor, xkbMinor;
 
 #ifdef WITH_TARTY_WARP
-   if (XkbQueryExtension(disp, &xkbOpCode, &xkbEventBase, &xkbErrorBase,
-			 &xkbMajor, &xkbMinor))
+   if (XkbQueryExtension
+       (disp, &xkbOpCode, &xkbEventBase, &xkbErrorBase, &xkbMajor, &xkbMinor))
      {
 	xkbEventNumber = xkbEventBase + XkbEventCode;
 	XkbSelectEventDetails(disp, XkbUseCoreKbd, XkbStateNotify,
@@ -94,12 +94,12 @@ WarpFocusHandleEvent(XEvent * ev)
 
 	     sn = &xev->state;
 	     keySym = XKeycodeToKeysym(disp, sn->keycode, 0);
-	     if ((keySym == XK_Alt_L) || (keySym == XK_Alt_R) ||
-		 (keySym == XK_Shift_L) || (keySym == XK_Shift_R) ||
-		 (keySym == XK_Control_L) || (keySym == XK_Control_R) ||
-		 (keySym == XK_Meta_L) || (keySym == XK_Meta_R) ||
-		 (keySym == XK_Super_L) || (keySym == XK_Super_R) ||
-		 (keySym == XK_Hyper_L) || (keySym == XK_Hyper_R))
+	     if ((keySym == XK_Alt_L) || (keySym == XK_Alt_R)
+		 || (keySym == XK_Shift_L) || (keySym == XK_Shift_R)
+		 || (keySym == XK_Control_L) || (keySym == XK_Control_R)
+		 || (keySym == XK_Meta_L) || (keySym == XK_Meta_R)
+		 || (keySym == XK_Super_L) || (keySym == XK_Super_R)
+		 || (keySym == XK_Hyper_L) || (keySym == XK_Hyper_R))
 	       {
 		  int                 newAltPressed;
 
@@ -137,13 +137,14 @@ WarpFocus(int delta)
 	     for (i = num0 - 1; i >= 0; --i)
 	       {
 		  ewin = lst0[i];
-		  if (((ewin->sticky) || (ewin->desktop == desks.current)) &&
-		      (ewin->x + ewin->w > 0) && (ewin->x < root.w) &&
-		      (ewin->y + ewin->h > 0) && (ewin->y < root.h) &&
-		      (!ewin->skipfocus) && !(ewin->shaded && !mode.warpshaded)
+		  if (((ewin->sticky) || (ewin->desktop == desks.current))
+		      && (ewin->x + ewin->w > 0) && (ewin->x < root.w)
+		      && (ewin->y + ewin->h > 0) && (ewin->y < root.h)
+		      && (!ewin->skipfocus) && !(ewin->shaded
+						 && !mode.warpshaded)
 		      && (!ewin->menu) && (!ewin->pager) && !(ewin->sticky
-							      &&
-							      !mode.warpsticky)
+							      && !mode.
+							      warpsticky)
 		      && (!ewin->ibox) && !(ewin->iconified
 					    && !mode.warpiconified)
 		      /*&& (ewin->client.mwm_decor_title) &&
@@ -272,10 +273,56 @@ WarpFocusShowTitle(EWin * ewin)
 	h += (ic->padding.top + ic->padding.bottom);
 	x = (root.w - w) / 2;
 	y = (root.h - (h * warptitles_num)) / 2;
+#ifdef HAS_XINERAMA
+	if (xinerama_active)
+	  {
+	     Window              rt, ch;
+	     XineramaScreenInfo *screens;
+	     int                 pointer_x, pointer_y;
+	     int                 num;
+	     int                 d;
+	     unsigned int        ud;
+
+	     XQueryPointer(disp, root.win, &rt, &ch, &pointer_x,
+			   &pointer_y, &d, &d, &ud);
+	     screens = XineramaQueryScreens(disp, &num);
+	     for (i = 0; i < num; i++)
+	       {
+		  for (i = 0; i < num; i++)
+		    {
+		       if (pointer_x >= screens[i].x_org)
+			 {
+			    if (pointer_x <=
+				(screens[i].width + screens[i].x_org))
+			      {
+				 if (pointer_y >= screens[i].y_org)
+				   {
+				      if (pointer_y <=
+					  (screens[i].height +
+					   screens[i].y_org))
+					{
+					   x =
+					      ((screens
+						[i].width -
+						w) / 2) + screens[i].x_org;
+					   y =
+					      ((screens
+						[i].height -
+						h * warptitles_num) / 2) +
+					      screens[i].y_org;
+					}
+				   }
+			      }
+			 }
+		    }
+	       }
+	     XFree(screens);
+	  }
+#endif
 	mw = w;
 	mh = h;
-	EMoveResizeWindow(disp, warpFocusTitleWindow,
-			  x, y, w, (h * warptitles_num));
+	EMoveResizeWindow(disp, warpFocusTitleWindow, x, y, w,
+			  (h * warptitles_num));
 	for (i = 0; i < warptitles_num; i++)
 	  {
 	     EMoveResizeWindow(disp, warptitles[i], 0, (h * i), mw, mh);
@@ -289,9 +336,9 @@ WarpFocusShowTitle(EWin * ewin)
      }
    for (i = 0; i < warptitles_num; i++)
      {
-	if (!FindItem((char *)warptitles_ewin[i], 0,
-		      LIST_FINDBY_POINTER, LIST_TYPE_EWIN))
-	   warptitles_ewin[i] = NULL;
+	if (!FindItem
+	    ((char *)warptitles_ewin[i], 0, LIST_FINDBY_POINTER,
+	     LIST_TYPE_EWIN)) warptitles_ewin[i] = NULL;
 	if (warptitles_ewin[i])
 	  {
 	     if (ewin == warptitles_ewin[i])
