@@ -25,8 +25,8 @@
 #include <X11/Xresource.h>
 
 Pixmap
-ECreatePixmap(Display * display, Drawable d,
-	      unsigned int width, unsigned int height, unsigned depth)
+ECreatePixmap(Display * display, Drawable d, unsigned int width,
+	      unsigned int height, unsigned depth)
 {
    Pixmap              pm;
 
@@ -40,8 +40,7 @@ EFreePixmap(Display * display, Pixmap pixmap)
    XFreePixmap(display, pixmap);
 }
 
-Window
-ECreateWindow(Window parent, int x, int y, int w, int h, int saveunder)
+Window ECreateWindow(Window parent, int x, int y, int w, int h, int saveunder)
 {
    EXID               *xid;
    Window              win;
@@ -60,10 +59,11 @@ ECreateWindow(Window parent, int x, int y, int w, int h, int saveunder)
       attr.save_under = True;
    else
       attr.save_under = False;
-   win = XCreateWindow(disp, parent, x, y, w, h, 0, root.depth,
-		       InputOutput, root.vis, CWOverrideRedirect |
-		       CWSaveUnder | CWBackingStore | CWColormap |
-		       CWBackPixmap | CWBorderPixel, &attr);
+   win =
+      XCreateWindow(disp, parent, x, y, w, h, 0, root.depth, InputOutput,
+		    root.vis,
+		    CWOverrideRedirect | CWSaveUnder | CWBackingStore |
+		    CWColormap | CWBackPixmap | CWBorderPixel, &attr);
    xid = NewXID();
    xid->parent = parent;
    xid->win = win;
@@ -202,8 +202,8 @@ EUnmapWindow(Display * d, Window win)
 }
 
 void
-EShapeCombineMask(Display * d, Window win, int dest, int x, int y,
-		  Pixmap pmap, int op)
+EShapeCombineMask(Display * d, Window win, int dest, int x, int y, Pixmap pmap,
+		  int op)
 {
    EXID               *xid;
 
@@ -222,16 +222,16 @@ EShapeCombineMask(Display * d, Window win, int dest, int x, int y,
 	if (pmap)
 	  {
 	     XShapeCombineMask(d, win, dest, x, y, pmap, op);
-	     xid->rects = XShapeGetRectangles(d, win, dest, &(xid->num_rect),
-					      &(xid->ord));
+	     xid->rects =
+		XShapeGetRectangles(d, win, dest, &(xid->num_rect),
+				    &(xid->ord));
 	     if (xid->rects)
 	       {
 		  if (xid->num_rect == 1)
 		    {
-		       if ((xid->rects[0].x == 0) &&
-			   (xid->rects[0].y == 0) &&
-			   (xid->rects[0].width == xid->w) &&
-			   (xid->rects[0].height == xid->h))
+		       if ((xid->rects[0].x == 0) && (xid->rects[0].y == 0)
+			   && (xid->rects[0].width == xid->w)
+			   && (xid->rects[0].height == xid->h))
 			 {
 			    xid->num_rect = 0;
 			    XFree(xid->rects);
@@ -258,9 +258,8 @@ EShapeCombineRectangles(Display * d, Window win, int dest, int x, int y,
      {
 	if (n_rects == 1)
 	  {
-	     if ((rect[0].x == 0) &&
-		 (rect[0].y == 0) &&
-		 (rect[0].width == xid->w) && (rect[0].height == xid->h))
+	     if ((rect[0].x == 0) && (rect[0].y == 0)
+		 && (rect[0].width == xid->w) && (rect[0].height == xid->h))
 	       {
 		  xid->num_rect = 0;
 		  XFree(xid->rects);
@@ -272,18 +271,17 @@ EShapeCombineRectangles(Display * d, Window win, int dest, int x, int y,
 	xid->num_rect = 0;
 	if (xid->rects)
 	   XFree(xid->rects);
-	XShapeCombineRectangles(d, win, dest, x, y, rect, n_rects,
-				op, ordering);
-	xid->rects = XShapeGetRectangles(d, win, dest, &(xid->num_rect),
-					 &(xid->ord));
+	XShapeCombineRectangles(d, win, dest, x, y, rect, n_rects, op,
+				ordering);
+	xid->rects =
+	   XShapeGetRectangles(d, win, dest, &(xid->num_rect), &(xid->ord));
 	if (xid->rects)
 	  {
 	     if (xid->num_rect == 1)
 	       {
-		  if ((xid->rects[0].x == 0) &&
-		      (xid->rects[0].y == 0) &&
-		      (xid->rects[0].width == xid->w) &&
-		      (xid->rects[0].height == xid->h))
+		  if ((xid->rects[0].x == 0) && (xid->rects[0].y == 0)
+		      && (xid->rects[0].width == xid->w)
+		      && (xid->rects[0].height == xid->h))
 		    {
 		       xid->num_rect = 0;
 		       XFree(xid->rects);
@@ -309,16 +307,15 @@ EShapeCombineShape(Display * d, Window win, int dest, int x, int y,
 	if (xid->rects)
 	   XFree(xid->rects);
 	XShapeCombineShape(d, win, dest, x, y, src_win, src_kind, op);
-	xid->rects = XShapeGetRectangles(d, win, dest, &(xid->num_rect),
-					 &(xid->ord));
+	xid->rects =
+	   XShapeGetRectangles(d, win, dest, &(xid->num_rect), &(xid->ord));
 	if (xid->rects)
 	  {
 	     if (xid->num_rect == 1)
 	       {
-		  if ((xid->rects[0].x == 0) &&
-		      (xid->rects[0].y == 0) &&
-		      (xid->rects[0].width == xid->w) &&
-		      (xid->rects[0].height == xid->h))
+		  if ((xid->rects[0].x == 0) && (xid->rects[0].y == 0)
+		      && (xid->rects[0].width == xid->w)
+		      && (xid->rects[0].height == xid->h))
 		    {
 		       xid->num_rect = 0;
 		       XFree(xid->rects);
@@ -587,16 +584,16 @@ DelXID(Window win)
      }
 }
 
-Window
-ECreateEventWindow(Window parent, int x, int y, int w, int h)
+Window ECreateEventWindow(Window parent, int x, int y, int w, int h)
 {
    Window              win;
    XSetWindowAttributes attr;
 
    EDBUG(6, "ECreateEventWindow");
    attr.override_redirect = False;
-   win = XCreateWindow(disp, parent, x, y, w, h, 0, 0, InputOnly, root.vis,
-		       CWOverrideRedirect, &attr);
+   win =
+      XCreateWindow(disp, parent, x, y, w, h, 0, 0, InputOnly, root.vis,
+		    CWOverrideRedirect, &attr);
    EDBUG_RETURN(win);
 }
 
@@ -604,8 +601,7 @@ ECreateEventWindow(Window parent, int x, int y, int w, int h)
  * create a window which will accept the keyboard focus when no other 
  * windows have it
  */
-Window
-ECreateFocusWindow(Window parent, int x, int y, int w, int h)
+Window ECreateFocusWindow(Window parent, int x, int y, int w, int h)
 {
    Window              win;
    XSetWindowAttributes attr;
@@ -620,10 +616,11 @@ ECreateFocusWindow(Window parent, int x, int y, int w, int h)
    attr.save_under = False;
    attr.event_mask = KeyPressMask | FocusChangeMask;
 
-   win = XCreateWindow(disp, parent, x, y, w, h, 0, 0, InputOnly,
-		       CopyFromParent, CWOverrideRedirect | CWSaveUnder |
-		       CWBackingStore | CWColormap | CWBackPixel |
-		       CWBorderPixel | CWEventMask, &attr);
+   win =
+      XCreateWindow(disp, parent, x, y, w, h, 0, 0, InputOnly, CopyFromParent,
+		    CWOverrideRedirect | CWSaveUnder | CWBackingStore |
+		    CWColormap | CWBackPixel | CWBorderPixel | CWEventMask,
+		    &attr);
 
    XSetWindowBackground(disp, win, 0);
    XMapWindow(disp, win);
@@ -739,8 +736,7 @@ WinExists(Window win)
    EDBUG_RETURN(0);
 }
 
-Window
-WindowAtXY_0(Window base, int bx, int by, int x, int y)
+Window WindowAtXY_0(Window base, int bx, int by, int x, int y)
 {
    Window             *list = NULL;
    XWindowAttributes   att;
@@ -764,8 +760,8 @@ WindowAtXY_0(Window base, int bx, int by, int x, int y)
    wx += bx;
    wy += by;
 
-   if (!((x >= wx) &&
-	 (y >= wy) && (x < (int)(wx + ww)) && (y < (int)(wy + wh))))
+   if (!((x >= wx) && (y >= wy) && (x < (int)(wx + ww))
+	 && (y < (int)(wy + wh))))
       EDBUG_RETURN(0);
 
    if (!XQueryTree(disp, base, &root_win, &parent_win, &list, &num))
@@ -787,8 +783,7 @@ WindowAtXY_0(Window base, int bx, int by, int x, int y)
    EDBUG_RETURN(base);
 }
 
-Window
-WindowAtXY(int x, int y)
+Window WindowAtXY(int x, int y)
 {
    Window             *list = NULL;
    Window              child = 0, parent_win = 0, root_win = 0;
