@@ -44,8 +44,8 @@ static char         XHasDGA(void);
 static void
 FillStdVidModes(void)
 {
-   XF86VidModeGetAllModeLines(disp, root.scr,
-			      &std_vid_modes_num, &std_vid_modes);
+   XF86VidModeGetAllModeLines(disp, root.scr, &std_vid_modes_num,
+			      &std_vid_modes);
 }
 
 static XF86VidModeModeInfo *
@@ -58,10 +58,11 @@ FindMode(int w, int h)
      {
 	int                 close = 0x7fffffff;
 
-	if ((std_vid_modes[i]->hdisplay >= w) &&
-	    (std_vid_modes[i]->vdisplay >= h))
-	   close = ((std_vid_modes[i]->hdisplay - w) +
-		    (std_vid_modes[i]->vdisplay - h));
+	if ((std_vid_modes[i]->hdisplay >= w)
+	    && (std_vid_modes[i]->vdisplay >= h))
+	   close =
+	      ((std_vid_modes[i]->hdisplay - w) +
+	       (std_vid_modes[i]->vdisplay - h));
 	if (close < closest)
 	  {
 	     closest = close;
@@ -79,8 +80,8 @@ GetModeJumpCount(XF86VidModeModeInfo * new)
    next = 0;
    for (i = 0; i < std_vid_modes_num; i++)
      {
-	if ((new->hdisplay == std_vid_modes[i]->hdisplay) &&
-	    (new->vdisplay == std_vid_modes[i]->vdisplay))
+	if ((new->hdisplay == std_vid_modes[i]->hdisplay)
+	    && (new->vdisplay == std_vid_modes[i]->vdisplay))
 	   next = i;
      }
    return next;
@@ -211,10 +212,10 @@ Zoom(EWin * ewin)
  * GrabModeAsync, GrabModeAsync, None, 
  * ewin->client.win, None, 
  * CurrentTime); */
-	zoom_mask_1 = ECreateWindow(root.win, ewin->client.w, 0,
-				    root.w, root.h, 0);
-	zoom_mask_2 = ECreateWindow(root.win, 0, ewin->client.h,
-				    root.w, root.h, 0);
+	zoom_mask_1 =
+	   ECreateWindow(root.win, ewin->client.w, 0, root.w, root.h, 0);
+	zoom_mask_2 =
+	   ECreateWindow(root.win, 0, ewin->client.h, root.w, root.h, 0);
 	XSetWindowBackgroundPixmap(disp, zoom_mask_1, None);
 	XSetWindowBackgroundPixmap(disp, zoom_mask_2, None);
 	XSetWindowBackground(disp, zoom_mask_1, BlackPixel(disp, root.scr));
@@ -261,4 +262,5 @@ Zoom(EWin * ewin)
 {
    ewin = NULL;
 }
+
 #endif
